/****************************************************************************
** Meta object code from reading C++ file 'PlayBackDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwave-26.04.3/plugins/playback/PlayBackDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PlayBackDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave14PlayBackDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::PlayBackDialog::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave14PlayBackDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::PlayBackDialog",
        "sigMethodChanged",
        "",
        "Kwave::playback_method_t",
        "method",
        "sigTestPlayback",
        "setFileFilter",
        "filter",
        "setDevice",
        "device",
        "setBitsPerSample",
        "bits",
        "setChannels",
        "channels",
        "methodSelected",
        "index",
        "setBufferSize",
        "exp",
        "selectPlaybackDevice",
        "listEntrySelected",
        "QTreeWidgetItem*",
        "current",
        "previous",
        "listItemExpanded",
        "item",
        "updateListSelection",
        "bitsPerSampleSelected",
        "text",
        "invokeHelp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigMethodChanged'
        QtMocHelpers::SignalData<void(Kwave::playback_method_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigTestPlayback'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFileFilter'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'setDevice'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'setBitsPerSample'
        QtMocHelpers::SlotData<void(unsigned int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'setChannels'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'methodSelected'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setBufferSize'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'selectPlaybackDevice'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'listEntrySelected'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, QTreeWidgetItem *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 20, 22 },
        }}),
        // Slot 'listItemExpanded'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 24 },
        }}),
        // Slot 'updateListSelection'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bitsPerSampleSelected'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'invokeHelp'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlayBackDialog, qt_meta_tag_ZN5Kwave14PlayBackDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::PlayBackDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14PlayBackDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14PlayBackDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave14PlayBackDialogE_t>.metaTypes,
    nullptr
} };

void Kwave::PlayBackDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlayBackDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigMethodChanged((*reinterpret_cast<std::add_pointer_t<Kwave::playback_method_t>>(_a[1]))); break;
        case 1: _t->sigTestPlayback(); break;
        case 2: _t->setFileFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->setDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setBitsPerSample((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: _t->setChannels((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->methodSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setBufferSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->selectPlaybackDevice(); break;
        case 9: _t->listEntrySelected((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[2]))); break;
        case 10: _t->listItemExpanded((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 11: _t->updateListSelection(); break;
        case 12: _t->bitsPerSampleSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->invokeHelp(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlayBackDialog::*)(Kwave::playback_method_t )>(_a, &PlayBackDialog::sigMethodChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayBackDialog::*)()>(_a, &PlayBackDialog::sigTestPlayback, 1))
            return;
    }
}

const QMetaObject *Kwave::PlayBackDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::PlayBackDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14PlayBackDialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::PlayBackDlg"))
        return static_cast< Ui::PlayBackDlg*>(this);
    return QDialog::qt_metacast(_clname);
}

int Kwave::PlayBackDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Kwave::PlayBackDialog::sigMethodChanged(Kwave::playback_method_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::PlayBackDialog::sigTestPlayback()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
