/********************************************************************************
** Form generated from reading UI file 'RecordDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECORDDLG_H
#define UI_RECORDDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "LevelMeter.h"
#include "libgui/HMSTimeWidget.h"
#include "libgui/TreeWidgetWrapper.h"

QT_BEGIN_NAMESPACE

class Ui_RecordDlg
{
public:
    QVBoxLayout *vboxLayout;
    QFrame *frame7;
    QVBoxLayout *vboxLayout1;
    QTabWidget *tabRecord;
    QWidget *tab_record;
    QVBoxLayout *vboxLayout2;
    QGroupBox *grpRecording;
    QGridLayout *gridLayout;
    QCheckBox *chkRecordPre;
    QCheckBox *chkRecordTime;
    QCheckBox *chkRecordTrigger;
    QFrame *frame5;
    QHBoxLayout *hboxLayout;
    QPushButton *btNew;
    QPushButton *btStop;
    QPushButton *btPause;
    QPushButton *btRecord;
    QFrame *frame5_2;
    QSpacerItem *spacerItem;
    QSlider *slRecordPre;
    QSpinBox *sbRecordPre;
    QSlider *slRecordTrigger;
    QSpinBox *sbRecordTrigger;
    Kwave::HMSTimeWidget *sbRecordTime;
    QSpacerItem *spacerItem1;
    QCheckBox *chkRecordStartTime;
    QDateTimeEdit *startTime;
    QWidget *tab_level;
    QVBoxLayout *vboxLayout3;
    QGroupBox *grpLevel;
    QGridLayout *gridLayout1;
    QSlider *slLevelAmplify;
    QCheckBox *chkLevelAGC;
    QCheckBox *chkLevelAmplify;
    QSpinBox *sbLevelAmplify;
    QSpinBox *sbLevelAGC;
    QSlider *slLevelAGC;
    QGroupBox *grpFading;
    QGridLayout *gridLayout2;
    QCheckBox *chkLevelFadeIn;
    QCheckBox *chkLevelFadeOut;
    QSpinBox *sbLevelFadeOut;
    QSpinBox *sbLevelFadeIn;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;
    QWidget *tab_format;
    QVBoxLayout *vboxLayout4;
    QGroupBox *grpFormat;
    QGridLayout *gridLayout3;
    QSpacerItem *spacerItem4;
    KComboBox *cbFormatSampleRate;
    QHBoxLayout *hboxLayout1;
    QLabel *lblSamplesPerSecond;
    QSpacerItem *spacerItem5;
    QLabel *lblRate;
    QLabel *lblChannels;
    QSpinBox *sbFormatTracks;
    QSpacerItem *spacerItem6;
    QHBoxLayout *hboxLayout2;
    QLabel *lblTracksVerbose;
    QSpacerItem *spacerItem7;
    QLabel *lblFormatCompression;
    KComboBox *cbFormatCompression;
    QSpacerItem *spacerItem8;
    QSpacerItem *spacerItem9;
    QSpacerItem *spacerItem10;
    KComboBox *cbFormatSampleFormat;
    QSpacerItem *spacerItem11;
    QLabel *lblSampleFormat;
    QSpinBox *sbFormatResolution;
    QLabel *lblResolution;
    QSpacerItem *spacerItem12;
    QHBoxLayout *hboxLayout3;
    QLabel *lblBits;
    QSpacerItem *spacerItem13;
    QWidget *tab_source;
    QGridLayout *gridLayout4;
    QGroupBox *grpSource;
    QGridLayout *gridLayout5;
    QLabel *textLabel2;
    QLabel *textLabel1_4;
    KComboBox *cbMethod;
    QLabel *textLabel1_5;
    QHBoxLayout *hboxLayout4;
    KComboBox *cbDevice;
    QPushButton *btSourceSelect;
    QGridLayout *gridLayout6;
    QSlider *slSourceBufferSize;
    QSlider *slSourceBufferCount;
    QLabel *txtSourceBuffer;
    QSpinBox *sbSourceBuffer;
    QLabel *textLabel1;
    Kwave::TreeWidgetWrapper *listDevices;
    QGridLayout *gridLayout7;
    QLabel *textLabel1_2;
    Kwave::LevelMeter *level_meter;
    QLabel *lbl_level_meter;
    QProgressBar *progress_bar;
    QHBoxLayout *hboxLayout5;
    QDialogButtonBox *buttonBox;
    QFrame *frame8;
    QHBoxLayout *hboxLayout6;
    QStatusBar *lbl_state;

    void setupUi(QDialog *RecordDlg)
    {
        if (RecordDlg->objectName().isEmpty())
            RecordDlg->setObjectName("RecordDlg");
        RecordDlg->resize(757, 600);
        RecordDlg->setFocusPolicy(Qt::ClickFocus);
        vboxLayout = new QVBoxLayout(RecordDlg);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        frame7 = new QFrame(RecordDlg);
        frame7->setObjectName("frame7");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame7->sizePolicy().hasHeightForWidth());
        frame7->setSizePolicy(sizePolicy);
        frame7->setFrameShape(QFrame::NoFrame);
        frame7->setFrameShadow(QFrame::Plain);
        vboxLayout1 = new QVBoxLayout(frame7);
        vboxLayout1->setSpacing(10);
        vboxLayout1->setContentsMargins(10, 10, 10, 10);
        vboxLayout1->setObjectName("vboxLayout1");
        tabRecord = new QTabWidget(frame7);
        tabRecord->setObjectName("tabRecord");
        tab_record = new QWidget();
        tab_record->setObjectName("tab_record");
        vboxLayout2 = new QVBoxLayout(tab_record);
        vboxLayout2->setSpacing(10);
        vboxLayout2->setContentsMargins(10, 10, 10, 10);
        vboxLayout2->setObjectName("vboxLayout2");
        grpRecording = new QGroupBox(tab_record);
        grpRecording->setObjectName("grpRecording");
        gridLayout = new QGridLayout(grpRecording);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        chkRecordPre = new QCheckBox(grpRecording);
        chkRecordPre->setObjectName("chkRecordPre");
        chkRecordPre->setChecked(false);

        gridLayout->addWidget(chkRecordPre, 0, 0, 1, 1);

        chkRecordTime = new QCheckBox(grpRecording);
        chkRecordTime->setObjectName("chkRecordTime");
        chkRecordTime->setEnabled(true);
        chkRecordTime->setChecked(false);

        gridLayout->addWidget(chkRecordTime, 1, 0, 1, 1);

        chkRecordTrigger = new QCheckBox(grpRecording);
        chkRecordTrigger->setObjectName("chkRecordTrigger");
        chkRecordTrigger->setEnabled(true);
        chkRecordTrigger->setChecked(false);

        gridLayout->addWidget(chkRecordTrigger, 5, 0, 1, 1);

        frame5 = new QFrame(grpRecording);
        frame5->setObjectName("frame5");
        frame5->setMinimumSize(QSize(0, 10));
        frame5->setFrameShape(QFrame::NoFrame);
        frame5->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(frame5, 3, 0, 1, 3);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setObjectName("hboxLayout");
        btNew = new QPushButton(grpRecording);
        btNew->setObjectName("btNew");
        btNew->setEnabled(true);
        btNew->setMinimumSize(QSize(30, 30));

        hboxLayout->addWidget(btNew);

        btStop = new QPushButton(grpRecording);
        btStop->setObjectName("btStop");
        btStop->setEnabled(false);
        btStop->setMinimumSize(QSize(30, 30));

        hboxLayout->addWidget(btStop);

        btPause = new QPushButton(grpRecording);
        btPause->setObjectName("btPause");
        btPause->setEnabled(false);
        btPause->setMinimumSize(QSize(30, 30));

        hboxLayout->addWidget(btPause);

        btRecord = new QPushButton(grpRecording);
        btRecord->setObjectName("btRecord");
        btRecord->setMinimumSize(QSize(30, 35));

        hboxLayout->addWidget(btRecord);


        gridLayout->addLayout(hboxLayout, 8, 0, 1, 3);

        frame5_2 = new QFrame(grpRecording);
        frame5_2->setObjectName("frame5_2");
        frame5_2->setMinimumSize(QSize(0, 10));
        frame5_2->setFrameShape(QFrame::NoFrame);
        frame5_2->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(frame5_2, 7, 0, 1, 3);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 6, 1, 1, 1);

        slRecordPre = new QSlider(grpRecording);
        slRecordPre->setObjectName("slRecordPre");
        slRecordPre->setEnabled(false);
        slRecordPre->setMinimumSize(QSize(150, 0));
        slRecordPre->setMinimum(1);
        slRecordPre->setMaximum(60);
        slRecordPre->setValue(10);
        slRecordPre->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(slRecordPre, 0, 2, 1, 1);

        sbRecordPre = new QSpinBox(grpRecording);
        sbRecordPre->setObjectName("sbRecordPre");
        sbRecordPre->setEnabled(false);
        sbRecordPre->setMinimumSize(QSize(100, 0));
        sbRecordPre->setValue(10);
        sbRecordPre->setProperty("maxValue", QVariant(60));
        sbRecordPre->setProperty("minValue", QVariant(1));

        gridLayout->addWidget(sbRecordPre, 0, 1, 1, 1);

        slRecordTrigger = new QSlider(grpRecording);
        slRecordTrigger->setObjectName("slRecordTrigger");
        slRecordTrigger->setEnabled(false);
        slRecordTrigger->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(slRecordTrigger, 5, 2, 1, 1);

        sbRecordTrigger = new QSpinBox(grpRecording);
        sbRecordTrigger->setObjectName("sbRecordTrigger");
        sbRecordTrigger->setEnabled(false);
        sbRecordTrigger->setMinimum(1);
        sbRecordTrigger->setValue(27);

        gridLayout->addWidget(sbRecordTrigger, 5, 1, 1, 1);

        sbRecordTime = new Kwave::HMSTimeWidget(grpRecording);
        sbRecordTime->setObjectName("sbRecordTime");
        sbRecordTime->setEnabled(false);
        sbRecordTime->setFocusPolicy(Qt::WheelFocus);

        gridLayout->addWidget(sbRecordTime, 1, 1, 1, 1);

        spacerItem1 = new QSpacerItem(411, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 1, 2, 1, 1);

        chkRecordStartTime = new QCheckBox(grpRecording);
        chkRecordStartTime->setObjectName("chkRecordStartTime");

        gridLayout->addWidget(chkRecordStartTime, 4, 0, 1, 1);

        startTime = new QDateTimeEdit(grpRecording);
        startTime->setObjectName("startTime");
        startTime->setEnabled(false);
        startTime->setFocusPolicy(Qt::WheelFocus);

        gridLayout->addWidget(startTime, 4, 1, 1, 2);


        vboxLayout2->addWidget(grpRecording);

        tabRecord->addTab(tab_record, QString());
        tab_level = new QWidget();
        tab_level->setObjectName("tab_level");
        vboxLayout3 = new QVBoxLayout(tab_level);
        vboxLayout3->setSpacing(10);
        vboxLayout3->setContentsMargins(10, 10, 10, 10);
        vboxLayout3->setObjectName("vboxLayout3");
        grpLevel = new QGroupBox(tab_level);
        grpLevel->setObjectName("grpLevel");
        grpLevel->setEnabled(false);
        gridLayout1 = new QGridLayout(grpLevel);
        gridLayout1->setSpacing(10);
        gridLayout1->setContentsMargins(10, 10, 10, 10);
        gridLayout1->setObjectName("gridLayout1");
        slLevelAmplify = new QSlider(grpLevel);
        slLevelAmplify->setObjectName("slLevelAmplify");
        slLevelAmplify->setEnabled(false);
        slLevelAmplify->setMinimum(-42);
        slLevelAmplify->setMaximum(42);
        slLevelAmplify->setValue(3);
        slLevelAmplify->setOrientation(Qt::Horizontal);
        slLevelAmplify->setTickInterval(3);

        gridLayout1->addWidget(slLevelAmplify, 0, 2, 1, 1);

        chkLevelAGC = new QCheckBox(grpLevel);
        chkLevelAGC->setObjectName("chkLevelAGC");
        chkLevelAGC->setEnabled(false);
        chkLevelAGC->setChecked(false);

        gridLayout1->addWidget(chkLevelAGC, 1, 0, 1, 1);

        chkLevelAmplify = new QCheckBox(grpLevel);
        chkLevelAmplify->setObjectName("chkLevelAmplify");
        chkLevelAmplify->setEnabled(false);
        chkLevelAmplify->setChecked(false);

        gridLayout1->addWidget(chkLevelAmplify, 0, 0, 1, 1);

        sbLevelAmplify = new QSpinBox(grpLevel);
        sbLevelAmplify->setObjectName("sbLevelAmplify");
        sbLevelAmplify->setEnabled(false);
        sbLevelAmplify->setMinimumSize(QSize(90, 0));
        sbLevelAmplify->setValue(3);
        sbLevelAmplify->setProperty("maxValue", QVariant(42));
        sbLevelAmplify->setProperty("minValue", QVariant(-42));

        gridLayout1->addWidget(sbLevelAmplify, 0, 1, 1, 1);

        sbLevelAGC = new QSpinBox(grpLevel);
        sbLevelAGC->setObjectName("sbLevelAGC");
        sbLevelAGC->setEnabled(false);
        sbLevelAGC->setValue(50);
        sbLevelAGC->setProperty("maxValue", QVariant(1000));
        sbLevelAGC->setProperty("minValue", QVariant(10));
        sbLevelAGC->setProperty("lineStep", QVariant(10));

        gridLayout1->addWidget(sbLevelAGC, 1, 1, 1, 1);

        slLevelAGC = new QSlider(grpLevel);
        slLevelAGC->setObjectName("slLevelAGC");
        slLevelAGC->setEnabled(false);
        slLevelAGC->setMinimum(10);
        slLevelAGC->setMaximum(1000);
        slLevelAGC->setSingleStep(10);
        slLevelAGC->setValue(50);
        slLevelAGC->setOrientation(Qt::Horizontal);
        slLevelAGC->setTickInterval(50);

        gridLayout1->addWidget(slLevelAGC, 1, 2, 1, 1);


        vboxLayout3->addWidget(grpLevel);

        grpFading = new QGroupBox(tab_level);
        grpFading->setObjectName("grpFading");
        grpFading->setEnabled(false);
        gridLayout2 = new QGridLayout(grpFading);
        gridLayout2->setSpacing(10);
        gridLayout2->setContentsMargins(10, 10, 10, 10);
        gridLayout2->setObjectName("gridLayout2");
        chkLevelFadeIn = new QCheckBox(grpFading);
        chkLevelFadeIn->setObjectName("chkLevelFadeIn");
        chkLevelFadeIn->setEnabled(false);
        chkLevelFadeIn->setChecked(false);

        gridLayout2->addWidget(chkLevelFadeIn, 0, 0, 1, 1);

        chkLevelFadeOut = new QCheckBox(grpFading);
        chkLevelFadeOut->setObjectName("chkLevelFadeOut");
        chkLevelFadeOut->setEnabled(false);
        chkLevelFadeOut->setChecked(false);

        gridLayout2->addWidget(chkLevelFadeOut, 1, 0, 1, 1);

        sbLevelFadeOut = new QSpinBox(grpFading);
        sbLevelFadeOut->setObjectName("sbLevelFadeOut");
        sbLevelFadeOut->setEnabled(false);
        sbLevelFadeOut->setProperty("maxValue", QVariant(30));
        sbLevelFadeOut->setProperty("minValue", QVariant(1));

        gridLayout2->addWidget(sbLevelFadeOut, 1, 1, 1, 1);

        sbLevelFadeIn = new QSpinBox(grpFading);
        sbLevelFadeIn->setObjectName("sbLevelFadeIn");
        sbLevelFadeIn->setEnabled(false);
        sbLevelFadeIn->setProperty("maxValue", QVariant(30));
        sbLevelFadeIn->setProperty("minValue", QVariant(1));

        gridLayout2->addWidget(sbLevelFadeIn, 0, 1, 1, 1);

        spacerItem2 = new QSpacerItem(60, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem2, 0, 2, 1, 1);

        spacerItem3 = new QSpacerItem(60, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(spacerItem3, 1, 2, 1, 1);


        vboxLayout3->addWidget(grpFading);

        tabRecord->addTab(tab_level, QString());
        tab_format = new QWidget();
        tab_format->setObjectName("tab_format");
        vboxLayout4 = new QVBoxLayout(tab_format);
        vboxLayout4->setSpacing(10);
        vboxLayout4->setContentsMargins(10, 10, 10, 10);
        vboxLayout4->setObjectName("vboxLayout4");
        grpFormat = new QGroupBox(tab_format);
        grpFormat->setObjectName("grpFormat");
        gridLayout3 = new QGridLayout(grpFormat);
        gridLayout3->setSpacing(6);
        gridLayout3->setContentsMargins(11, 11, 11, 11);
        gridLayout3->setObjectName("gridLayout3");
        spacerItem4 = new QSpacerItem(20, 21, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem4, 0, 1, 1, 1);

        cbFormatSampleRate = new KComboBox(grpFormat);
        cbFormatSampleRate->setObjectName("cbFormatSampleRate");

        gridLayout3->addWidget(cbFormatSampleRate, 0, 2, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        lblSamplesPerSecond = new QLabel(grpFormat);
        lblSamplesPerSecond->setObjectName("lblSamplesPerSecond");
        lblSamplesPerSecond->setWordWrap(false);

        hboxLayout1->addWidget(lblSamplesPerSecond);

        spacerItem5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem5);


        gridLayout3->addLayout(hboxLayout1, 0, 3, 1, 1);

        lblRate = new QLabel(grpFormat);
        lblRate->setObjectName("lblRate");
        lblRate->setWordWrap(false);

        gridLayout3->addWidget(lblRate, 0, 0, 1, 1);

        lblChannels = new QLabel(grpFormat);
        lblChannels->setObjectName("lblChannels");
        lblChannels->setWordWrap(false);

        gridLayout3->addWidget(lblChannels, 1, 0, 1, 1);

        sbFormatTracks = new QSpinBox(grpFormat);
        sbFormatTracks->setObjectName("sbFormatTracks");
        sbFormatTracks->setMinimum(1);
        sbFormatTracks->setValue(1);

        gridLayout3->addWidget(sbFormatTracks, 1, 2, 1, 1);

        spacerItem6 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem6, 1, 1, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        lblTracksVerbose = new QLabel(grpFormat);
        lblTracksVerbose->setObjectName("lblTracksVerbose");
        lblTracksVerbose->setWordWrap(false);

        hboxLayout2->addWidget(lblTracksVerbose);

        spacerItem7 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem7);


        gridLayout3->addLayout(hboxLayout2, 1, 3, 1, 1);

        lblFormatCompression = new QLabel(grpFormat);
        lblFormatCompression->setObjectName("lblFormatCompression");
        lblFormatCompression->setWordWrap(false);

        gridLayout3->addWidget(lblFormatCompression, 2, 0, 1, 1);

        cbFormatCompression = new KComboBox(grpFormat);
        cbFormatCompression->setObjectName("cbFormatCompression");
        cbFormatCompression->setMinimumSize(QSize(200, 0));

        gridLayout3->addWidget(cbFormatCompression, 2, 2, 1, 1);

        spacerItem8 = new QSpacerItem(20, 21, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem8, 2, 1, 1, 1);

        spacerItem9 = new QSpacerItem(239, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem9, 2, 3, 1, 1);

        spacerItem10 = new QSpacerItem(20, 21, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem10, 4, 1, 1, 1);

        cbFormatSampleFormat = new KComboBox(grpFormat);
        cbFormatSampleFormat->setObjectName("cbFormatSampleFormat");
        cbFormatSampleFormat->setMinimumSize(QSize(200, 0));

        gridLayout3->addWidget(cbFormatSampleFormat, 4, 2, 1, 1);

        spacerItem11 = new QSpacerItem(311, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem11, 4, 3, 1, 1);

        lblSampleFormat = new QLabel(grpFormat);
        lblSampleFormat->setObjectName("lblSampleFormat");
        lblSampleFormat->setWordWrap(false);

        gridLayout3->addWidget(lblSampleFormat, 4, 0, 1, 1);

        sbFormatResolution = new QSpinBox(grpFormat);
        sbFormatResolution->setObjectName("sbFormatResolution");
        sbFormatResolution->setMinimum(8);
        sbFormatResolution->setMaximum(24);
        sbFormatResolution->setSingleStep(1);
        sbFormatResolution->setValue(16);

        gridLayout3->addWidget(sbFormatResolution, 3, 2, 1, 1);

        lblResolution = new QLabel(grpFormat);
        lblResolution->setObjectName("lblResolution");
        lblResolution->setWordWrap(false);

        gridLayout3->addWidget(lblResolution, 3, 0, 1, 1);

        spacerItem12 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout3->addItem(spacerItem12, 3, 1, 1, 1);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        lblBits = new QLabel(grpFormat);
        lblBits->setObjectName("lblBits");
        lblBits->setWordWrap(false);

        hboxLayout3->addWidget(lblBits);

        spacerItem13 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem13);


        gridLayout3->addLayout(hboxLayout3, 3, 3, 1, 1);


        vboxLayout4->addWidget(grpFormat);

        tabRecord->addTab(tab_format, QString());
        tab_source = new QWidget();
        tab_source->setObjectName("tab_source");
        gridLayout4 = new QGridLayout(tab_source);
        gridLayout4->setSpacing(10);
        gridLayout4->setContentsMargins(10, 10, 10, 10);
        gridLayout4->setObjectName("gridLayout4");
        grpSource = new QGroupBox(tab_source);
        grpSource->setObjectName("grpSource");
        gridLayout5 = new QGridLayout(grpSource);
        gridLayout5->setSpacing(10);
        gridLayout5->setContentsMargins(10, 10, 10, 10);
        gridLayout5->setObjectName("gridLayout5");
        textLabel2 = new QLabel(grpSource);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout5->addWidget(textLabel2, 4, 0, 1, 1);

        textLabel1_4 = new QLabel(grpSource);
        textLabel1_4->setObjectName("textLabel1_4");
        textLabel1_4->setWordWrap(false);

        gridLayout5->addWidget(textLabel1_4, 3, 0, 1, 1);

        cbMethod = new KComboBox(grpSource);
        cbMethod->setObjectName("cbMethod");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbMethod->sizePolicy().hasHeightForWidth());
        cbMethod->setSizePolicy(sizePolicy1);
        cbMethod->setMinimumSize(QSize(130, 30));

        gridLayout5->addWidget(cbMethod, 0, 1, 1, 1);

        textLabel1_5 = new QLabel(grpSource);
        textLabel1_5->setObjectName("textLabel1_5");
        textLabel1_5->setWordWrap(false);

        gridLayout5->addWidget(textLabel1_5, 0, 0, 1, 1);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(10);
        hboxLayout4->setObjectName("hboxLayout4");
        cbDevice = new KComboBox(grpSource);
        cbDevice->setObjectName("cbDevice");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(10);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbDevice->sizePolicy().hasHeightForWidth());
        cbDevice->setSizePolicy(sizePolicy2);
        cbDevice->setEditable(true);

        hboxLayout4->addWidget(cbDevice);

        btSourceSelect = new QPushButton(grpSource);
        btSourceSelect->setObjectName("btSourceSelect");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(btSourceSelect->sizePolicy().hasHeightForWidth());
        btSourceSelect->setSizePolicy(sizePolicy3);

        hboxLayout4->addWidget(btSourceSelect);


        gridLayout5->addLayout(hboxLayout4, 1, 1, 1, 1);

        gridLayout6 = new QGridLayout();
        gridLayout6->setSpacing(10);
        gridLayout6->setObjectName("gridLayout6");
        slSourceBufferSize = new QSlider(grpSource);
        slSourceBufferSize->setObjectName("slSourceBufferSize");
        slSourceBufferSize->setMinimum(10);
        slSourceBufferSize->setMaximum(18);
        slSourceBufferSize->setPageStep(1);
        slSourceBufferSize->setValue(12);
        slSourceBufferSize->setOrientation(Qt::Horizontal);
        slSourceBufferSize->setTickInterval(1);

        gridLayout6->addWidget(slSourceBufferSize, 1, 1, 1, 1);

        slSourceBufferCount = new QSlider(grpSource);
        slSourceBufferCount->setObjectName("slSourceBufferCount");
        slSourceBufferCount->setMinimum(4);
        slSourceBufferCount->setMaximum(64);
        slSourceBufferCount->setSingleStep(10);
        slSourceBufferCount->setValue(32);
        slSourceBufferCount->setOrientation(Qt::Horizontal);
        slSourceBufferCount->setTickInterval(5);

        gridLayout6->addWidget(slSourceBufferCount, 0, 1, 1, 1);

        txtSourceBuffer = new QLabel(grpSource);
        txtSourceBuffer->setObjectName("txtSourceBuffer");
        txtSourceBuffer->setWordWrap(false);

        gridLayout6->addWidget(txtSourceBuffer, 1, 0, 1, 1);

        sbSourceBuffer = new QSpinBox(grpSource);
        sbSourceBuffer->setObjectName("sbSourceBuffer");
        sbSourceBuffer->setMinimum(4);
        sbSourceBuffer->setMaximum(64);
        sbSourceBuffer->setValue(32);

        gridLayout6->addWidget(sbSourceBuffer, 0, 0, 1, 1);


        gridLayout5->addLayout(gridLayout6, 3, 1, 2, 1);

        textLabel1 = new QLabel(grpSource);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout5->addWidget(textLabel1, 1, 0, 1, 1);

        listDevices = new Kwave::TreeWidgetWrapper(grpSource);
        listDevices->setObjectName("listDevices");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(100);
        sizePolicy4.setHeightForWidth(listDevices->sizePolicy().hasHeightForWidth());
        listDevices->setSizePolicy(sizePolicy4);
        listDevices->setMinimumSize(QSize(0, 120));

        gridLayout5->addWidget(listDevices, 2, 0, 1, 2);


        gridLayout4->addWidget(grpSource, 0, 0, 1, 1);

        tabRecord->addTab(tab_source, QString());

        vboxLayout1->addWidget(tabRecord);

        gridLayout7 = new QGridLayout();
        gridLayout7->setSpacing(10);
        gridLayout7->setObjectName("gridLayout7");
        textLabel1_2 = new QLabel(frame7);
        textLabel1_2->setObjectName("textLabel1_2");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(textLabel1_2->sizePolicy().hasHeightForWidth());
        textLabel1_2->setSizePolicy(sizePolicy5);
        textLabel1_2->setWordWrap(false);

        gridLayout7->addWidget(textLabel1_2, 0, 0, 1, 1);

        level_meter = new Kwave::LevelMeter(frame7);
        level_meter->setObjectName("level_meter");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(level_meter->sizePolicy().hasHeightForWidth());
        level_meter->setSizePolicy(sizePolicy6);
        level_meter->setMinimumSize(QSize(100, 30));

        gridLayout7->addWidget(level_meter, 1, 1, 1, 1);

        lbl_level_meter = new QLabel(frame7);
        lbl_level_meter->setObjectName("lbl_level_meter");
        sizePolicy5.setHeightForWidth(lbl_level_meter->sizePolicy().hasHeightForWidth());
        lbl_level_meter->setSizePolicy(sizePolicy5);
        lbl_level_meter->setWordWrap(false);

        gridLayout7->addWidget(lbl_level_meter, 1, 0, 1, 1);

        progress_bar = new QProgressBar(frame7);
        progress_bar->setObjectName("progress_bar");
        progress_bar->setMinimumSize(QSize(0, 20));
        progress_bar->setTextVisible(false);

        gridLayout7->addWidget(progress_bar, 0, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout7);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(10);
        hboxLayout5->setObjectName("hboxLayout5");
        buttonBox = new QDialogButtonBox(frame7);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout5->addWidget(buttonBox);


        vboxLayout1->addLayout(hboxLayout5);


        vboxLayout->addWidget(frame7);

        frame8 = new QFrame(RecordDlg);
        frame8->setObjectName("frame8");
        frame8->setFrameShape(QFrame::NoFrame);
        frame8->setFrameShadow(QFrame::Plain);
        hboxLayout6 = new QHBoxLayout(frame8);
        hboxLayout6->setSpacing(0);
        hboxLayout6->setContentsMargins(2, 2, 2, 2);
        hboxLayout6->setObjectName("hboxLayout6");
        lbl_state = new QStatusBar(frame8);
        lbl_state->setObjectName("lbl_state");
        sizePolicy1.setHeightForWidth(lbl_state->sizePolicy().hasHeightForWidth());
        lbl_state->setSizePolicy(sizePolicy1);
        lbl_state->setMinimumSize(QSize(0, 30));

        hboxLayout6->addWidget(lbl_state);


        vboxLayout->addWidget(frame8);

        QWidget::setTabOrder(btRecord, tabRecord);
        QWidget::setTabOrder(tabRecord, chkRecordPre);
        QWidget::setTabOrder(chkRecordPre, sbRecordPre);
        QWidget::setTabOrder(sbRecordPre, slRecordPre);
        QWidget::setTabOrder(slRecordPre, chkRecordTime);
        QWidget::setTabOrder(chkRecordTime, sbRecordTime);
        QWidget::setTabOrder(sbRecordTime, chkRecordStartTime);
        QWidget::setTabOrder(chkRecordStartTime, startTime);
        QWidget::setTabOrder(startTime, chkRecordTrigger);
        QWidget::setTabOrder(chkRecordTrigger, sbRecordTrigger);
        QWidget::setTabOrder(sbRecordTrigger, slRecordTrigger);
        QWidget::setTabOrder(slRecordTrigger, btNew);
        QWidget::setTabOrder(btNew, btStop);
        QWidget::setTabOrder(btStop, btPause);
        QWidget::setTabOrder(btPause, chkLevelAmplify);
        QWidget::setTabOrder(chkLevelAmplify, sbLevelAmplify);
        QWidget::setTabOrder(sbLevelAmplify, slLevelAmplify);
        QWidget::setTabOrder(slLevelAmplify, chkLevelAGC);
        QWidget::setTabOrder(chkLevelAGC, sbLevelAGC);
        QWidget::setTabOrder(sbLevelAGC, slLevelAGC);
        QWidget::setTabOrder(slLevelAGC, chkLevelFadeIn);
        QWidget::setTabOrder(chkLevelFadeIn, sbLevelFadeIn);
        QWidget::setTabOrder(sbLevelFadeIn, chkLevelFadeOut);
        QWidget::setTabOrder(chkLevelFadeOut, sbLevelFadeOut);
        QWidget::setTabOrder(sbLevelFadeOut, cbFormatSampleRate);
        QWidget::setTabOrder(cbFormatSampleRate, sbFormatTracks);
        QWidget::setTabOrder(sbFormatTracks, cbFormatCompression);
        QWidget::setTabOrder(cbFormatCompression, sbFormatResolution);
        QWidget::setTabOrder(sbFormatResolution, cbFormatSampleFormat);
        QWidget::setTabOrder(cbFormatSampleFormat, cbMethod);
        QWidget::setTabOrder(cbMethod, cbDevice);
        QWidget::setTabOrder(cbDevice, btSourceSelect);
        QWidget::setTabOrder(btSourceSelect, listDevices);
        QWidget::setTabOrder(listDevices, sbSourceBuffer);
        QWidget::setTabOrder(sbSourceBuffer, slSourceBufferCount);
        QWidget::setTabOrder(slSourceBufferCount, slSourceBufferSize);

        retranslateUi(RecordDlg);
        QObject::connect(chkRecordPre, &QCheckBox::toggled, sbRecordPre, &QSpinBox::setEnabled);
        QObject::connect(chkRecordPre, &QCheckBox::toggled, slRecordPre, &QSlider::setEnabled);
        QObject::connect(sbRecordPre, &QSpinBox::valueChanged, slRecordPre, &QSlider::setValue);
        QObject::connect(slRecordPre, &QSlider::valueChanged, sbRecordPre, &QSpinBox::setValue);
        QObject::connect(chkRecordTrigger, &QCheckBox::toggled, sbRecordTrigger, &QSpinBox::setEnabled);
        QObject::connect(chkRecordTrigger, &QCheckBox::toggled, slRecordTrigger, &QSlider::setEnabled);
        QObject::connect(sbRecordTrigger, &QSpinBox::valueChanged, slRecordTrigger, &QSlider::setValue);
        QObject::connect(slRecordTrigger, &QSlider::valueChanged, sbRecordTrigger, &QSpinBox::setValue);
        QObject::connect(chkLevelAmplify, &QCheckBox::toggled, sbLevelAmplify, &QSpinBox::setEnabled);
        QObject::connect(chkLevelAmplify, &QCheckBox::toggled, slLevelAmplify, &QSlider::setEnabled);
        QObject::connect(chkLevelAGC, &QCheckBox::toggled, sbLevelAGC, &QSpinBox::setEnabled);
        QObject::connect(sbLevelAmplify, &QSpinBox::valueChanged, slLevelAmplify, &QSlider::setValue);
        QObject::connect(slLevelAmplify, &QSlider::valueChanged, sbLevelAmplify, &QSpinBox::setValue);
        QObject::connect(sbLevelAGC, &QSpinBox::valueChanged, slLevelAGC, &QSlider::setValue);
        QObject::connect(slLevelAGC, &QSlider::valueChanged, sbLevelAGC, &QSpinBox::setValue);
        QObject::connect(chkLevelAGC, &QCheckBox::toggled, slLevelAGC, &QSlider::setEnabled);
        QObject::connect(chkLevelFadeIn, &QCheckBox::toggled, sbLevelFadeIn, &QSpinBox::setEnabled);
        QObject::connect(chkLevelFadeOut, &QCheckBox::toggled, sbLevelFadeOut, &QSpinBox::setEnabled);
        QObject::connect(chkRecordTime, SIGNAL(toggled(bool)), sbRecordTime, SLOT(setEnabled(bool)));
        QObject::connect(sbSourceBuffer, &QSpinBox::valueChanged, slSourceBufferCount, &QSlider::setValue);
        QObject::connect(slSourceBufferCount, &QSlider::valueChanged, sbSourceBuffer, &QSpinBox::setValue);
        QObject::connect(chkRecordStartTime, &QCheckBox::clicked, startTime, &QDateTimeEdit::setEnabled);

        tabRecord->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(RecordDlg);
    } // setupUi

    void retranslateUi(QDialog *RecordDlg)
    {
        RecordDlg->setWindowTitle(tr2i18n("Record", nullptr));
        grpRecording->setTitle(tr2i18n("Record Control", nullptr));
#if QT_CONFIG(tooltip)
        chkRecordPre->setToolTip(tr2i18n("Enable Pre-recording", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        chkRecordPre->setWhatsThis(tr2i18n("When using <b>Pre-recording</b>, Kwave internally already records before the real recording starts. This feature is useful if you want to start recording already a few seconds before you press the record button. <i>(For example when recording from radio)</i>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkRecordPre->setText(tr2i18n("Pre-record:", nullptr));
#if QT_CONFIG(tooltip)
        chkRecordTime->setToolTip(tr2i18n("Limit the recording time", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        chkRecordTime->setWhatsThis(tr2i18n("If checked, the <b>Record time</b> is limited and recording will automatically stop when the selected time is reached.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkRecordTime->setText(tr2i18n("Record &time:", nullptr));
#if QT_CONFIG(tooltip)
        chkRecordTrigger->setToolTip(tr2i18n("Trigger level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        chkRecordTrigger->setWhatsThis(tr2i18n("If the <b>Record trigger</b> is enabled, recording will start as soon as the volume of the input signal goes over the selected level.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkRecordTrigger->setText(tr2i18n("Record trigger:", nullptr));
#if QT_CONFIG(tooltip)
        btNew->setToolTip(tr2i18n("New File", nullptr));
#endif // QT_CONFIG(tooltip)
        btNew->setText(QString());
#if QT_CONFIG(tooltip)
        btStop->setToolTip(tr2i18n("Stop Recording", nullptr));
#endif // QT_CONFIG(tooltip)
        btStop->setText(QString());
#if QT_CONFIG(tooltip)
        btPause->setToolTip(tr2i18n("Pause/Continue", nullptr));
#endif // QT_CONFIG(tooltip)
        btPause->setText(QString());
#if QT_CONFIG(tooltip)
        btRecord->setToolTip(tr2i18n("Record", nullptr));
#endif // QT_CONFIG(tooltip)
        btRecord->setText(QString());
        sbRecordPre->setSuffix(tr2i18n(" s", nullptr));
        sbRecordTrigger->setSuffix(tr2i18n("%", nullptr));
#if QT_CONFIG(tooltip)
        chkRecordStartTime->setToolTip(tr2i18n("Start at a given date and time", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        chkRecordStartTime->setWhatsThis(tr2i18n("When checked, the recording will be started at the given date and time. Please note that if the time is in the past, the recording will be started immediately or as soon as the defined trigger level is reached (if enabled).", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkRecordStartTime->setText(tr2i18n("Start &at:", nullptr));
        tabRecord->setTabText(tabRecord->indexOf(tab_record), tr2i18n("Recording", nullptr));
        grpLevel->setTitle(tr2i18n("Level", nullptr));
        chkLevelAGC->setText(tr2i18n("AGC:", nullptr));
        chkLevelAmplify->setText(tr2i18n("Amplify:", nullptr));
        sbLevelAmplify->setSuffix(tr2i18n(" dB", nullptr));
        sbLevelAGC->setSuffix(tr2i18n(" ms", nullptr));
        grpFading->setTitle(tr2i18n("Fading", nullptr));
        chkLevelFadeIn->setText(tr2i18n("Fade In", nullptr));
        chkLevelFadeOut->setText(tr2i18n("Fade Out", nullptr));
        sbLevelFadeOut->setSuffix(tr2i18n(" sec", nullptr));
        sbLevelFadeIn->setSuffix(tr2i18n(" sec", nullptr));
        tabRecord->setTabText(tabRecord->indexOf(tab_level), tr2i18n("Level", nullptr));
        grpFormat->setTitle(tr2i18n("Format", nullptr));
#if QT_CONFIG(whatsthis)
        cbFormatSampleRate->setWhatsThis(tr2i18n("<b>Sample rate</b><br>Here you can select one of the predefined well-known sample rates that your sound card supports.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblSamplesPerSecond->setText(tr2i18n("Samples per second", nullptr));
        lblRate->setText(tr2i18n("Sample rate:", nullptr));
        lblChannels->setText(tr2i18n("Tracks:", nullptr));
#if QT_CONFIG(whatsthis)
        sbFormatTracks->setWhatsThis(tr2i18n("<b>Number of channels</b><br>Select a number of channels, e.g. for mono or stereo recording.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblTracksVerbose->setText(tr2i18n("?", nullptr));
        lblFormatCompression->setText(tr2i18n("Compression:", nullptr));
#if QT_CONFIG(whatsthis)
        cbFormatCompression->setWhatsThis(tr2i18n("<b>Compression</b><br>Here you can select one of the compression types if your audio hardware supports it.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        cbFormatSampleFormat->setWhatsThis(tr2i18n("<b>Sample format</b><br>Here you can select one of the sample formats that your audio hardware supports. This normally has no big influence on the result, so you can just leave it as it is.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblSampleFormat->setText(tr2i18n("Sample format:", nullptr));
#if QT_CONFIG(whatsthis)
        sbFormatResolution->setWhatsThis(tr2i18n("<b>Resolution</b><br>Select a resolution in bits in which the file will be recorded. Higher values give better quality but also more system load.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblResolution->setText(tr2i18n("Resolution:", nullptr));
        lblBits->setText(tr2i18n("bit", nullptr));
        tabRecord->setTabText(tabRecord->indexOf(tab_format), tr2i18n("For&mat", nullptr));
        grpSource->setTitle(tr2i18n("Source", nullptr));
        textLabel2->setText(tr2i18n("Buffer size:", nullptr));
        textLabel1_4->setText(tr2i18n("Buffer count:", nullptr));
#if QT_CONFIG(tooltip)
        cbMethod->setToolTip(tr2i18n("Method or system used for recording", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbMethod->setWhatsThis(tr2i18n("<b>Recording method:</b><p>Choose a method or system used for\n"
"recording. Depending on the compilation options you can select one of the following methods:</p>\n"
"<p><b><i>OSS (Open Sound System)</i></b>: The oldest linux implementation, only capable of mono and stereo input. Deprecated since linux kernel 2.6, but still wide spread.</p>\n"
"<p><b><i>ALSA (Advanced Linux Sound Architecture)</i></b>: Supercedes OSS, supports more features and more hardware.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_5->setText(tr2i18n("Recording method:", nullptr));
#if QT_CONFIG(tooltip)
        cbDevice->setToolTip(tr2i18n("Recording device", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cbDevice->setWhatsThis(tr2i18n("<b>Device:</b><p>This list shows a selection of some known recording devices suitable for the chosen recording method. If your device is not listed here, you can enter a device name on your own or search through the filesystem.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        btSourceSelect->setToolTip(tr2i18n("Search on the filesystem for a device", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btSourceSelect->setWhatsThis(tr2i18n("<b>Select...</b><p>Choose a device name on the harddisk, if your device is not already listed in the list of devices.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        btSourceSelect->setText(tr2i18n("Selec&t...", nullptr));
        txtSourceBuffer->setText(tr2i18n("%1 samples", nullptr));
        textLabel1->setText(tr2i18n("Device:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = listDevices->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Device", nullptr));
        tabRecord->setTabText(tabRecord->indexOf(tab_source), tr2i18n("Source", nullptr));
        textLabel1_2->setText(tr2i18n("Buffer:", nullptr));
        lbl_level_meter->setText(tr2i18n("Level:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RecordDlg: public Ui_RecordDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RECORDDLG_H

