/****************************************************************************
** Meta object code from reading C++ file 'PlaybackController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/libkwave/PlaybackController.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PlaybackController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave18PlaybackControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::PlaybackController::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave18PlaybackControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::PlaybackController",
        "sigPlaybackStarted",
        "",
        "sigPlaybackPaused",
        "sigPlaybackStopped",
        "sigPlaybackPos",
        "sample_index_t",
        "pos",
        "sigSeekDone",
        "sigDevicePlaybackDone",
        "sigDevicePlaybackPos",
        "sigDeviceSeekDone",
        "playbackStart",
        "playbackLoop",
        "playbackPause",
        "playbackContinue",
        "playbackStop",
        "reload",
        "seekTo",
        "seekDone",
        "updatePlaybackPos",
        "playbackDone",
        "closeDevice",
        "trackSelectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigPlaybackStarted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigPlaybackPaused'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigPlaybackStopped'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigPlaybackPos'
        QtMocHelpers::SignalData<void(sample_index_t)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigSeekDone'
        QtMocHelpers::SignalData<void(sample_index_t)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigDevicePlaybackDone'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigDevicePlaybackPos'
        QtMocHelpers::SignalData<void(sample_index_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigDeviceSeekDone'
        QtMocHelpers::SignalData<void(sample_index_t)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'playbackStart'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playbackLoop'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playbackPause'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playbackContinue'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playbackStop'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekTo'
        QtMocHelpers::SlotData<void(sample_index_t)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'seekDone'
        QtMocHelpers::SlotData<void(sample_index_t)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'updatePlaybackPos'
        QtMocHelpers::SlotData<void(sample_index_t)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'playbackDone'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeDevice'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'trackSelectionChanged'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaybackController, qt_meta_tag_ZN5Kwave18PlaybackControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::PlaybackController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave18PlaybackControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave18PlaybackControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave18PlaybackControllerE_t>.metaTypes,
    nullptr
} };

void Kwave::PlaybackController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaybackController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigPlaybackStarted(); break;
        case 1: _t->sigPlaybackPaused(); break;
        case 2: _t->sigPlaybackStopped(); break;
        case 3: _t->sigPlaybackPos((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 4: _t->sigSeekDone((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 5: _t->sigDevicePlaybackDone(); break;
        case 6: _t->sigDevicePlaybackPos((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 7: _t->sigDeviceSeekDone((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 8: _t->playbackStart(); break;
        case 9: _t->playbackLoop(); break;
        case 10: _t->playbackPause(); break;
        case 11: _t->playbackContinue(); break;
        case 12: _t->playbackStop(); break;
        case 13: _t->reload(); break;
        case 14: _t->seekTo((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 15: _t->seekDone((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 16: _t->updatePlaybackPos((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 17: _t->playbackDone(); break;
        case 18: _t->closeDevice(); break;
        case 19: _t->trackSelectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)()>(_a, &PlaybackController::sigPlaybackStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)()>(_a, &PlaybackController::sigPlaybackPaused, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)()>(_a, &PlaybackController::sigPlaybackStopped, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)(sample_index_t )>(_a, &PlaybackController::sigPlaybackPos, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)(sample_index_t )>(_a, &PlaybackController::sigSeekDone, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)()>(_a, &PlaybackController::sigDevicePlaybackDone, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)(sample_index_t )>(_a, &PlaybackController::sigDevicePlaybackPos, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaybackController::*)(sample_index_t )>(_a, &PlaybackController::sigDeviceSeekDone, 7))
            return;
    }
}

const QMetaObject *Kwave::PlaybackController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::PlaybackController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave18PlaybackControllerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Kwave::Runnable"))
        return static_cast< Kwave::Runnable*>(this);
    return QObject::qt_metacast(_clname);
}

int Kwave::PlaybackController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Kwave::PlaybackController::sigPlaybackStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kwave::PlaybackController::sigPlaybackPaused()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kwave::PlaybackController::sigPlaybackStopped()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kwave::PlaybackController::sigPlaybackPos(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kwave::PlaybackController::sigSeekDone(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Kwave::PlaybackController::sigDevicePlaybackDone()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Kwave::PlaybackController::sigDevicePlaybackPos(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Kwave::PlaybackController::sigDeviceSeekDone(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
