/****************************************************************************
** Meta object code from reading C++ file 'SaveBlocksDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwave-26.04.3/plugins/saveblocks/SaveBlocksDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SaveBlocksDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::SaveBlocksDialog::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::SaveBlocksDialog",
        "sigSelectionChanged",
        "",
        "filename",
        "pattern",
        "Kwave::SaveBlocksPlugin::numbering_mode_t",
        "mode",
        "ext",
        "selection_only",
        "accept",
        "setNewExample",
        "example",
        "emitUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigSelectionChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, Kwave::SaveBlocksPlugin::numbering_mode_t, const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setNewExample'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'emitUpdate'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SaveBlocksDialog, qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::SaveBlocksDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t>.metaTypes,
    nullptr
} };

void Kwave::SaveBlocksDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SaveBlocksDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigSelectionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Kwave::SaveBlocksPlugin::numbering_mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 1: _t->accept(); break;
        case 2: _t->setNewExample((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->emitUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SaveBlocksDialog::*)(const QString & , const QString & , Kwave::SaveBlocksPlugin::numbering_mode_t , const QString & , bool )>(_a, &SaveBlocksDialog::sigSelectionChanged, 0))
            return;
    }
}

const QMetaObject *Kwave::SaveBlocksDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::SaveBlocksDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16SaveBlocksDialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::SaveBlocksDialogBase"))
        return static_cast< Ui::SaveBlocksDialogBase*>(this);
    return QDialog::qt_metacast(_clname);
}

int Kwave::SaveBlocksDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Kwave::SaveBlocksDialog::sigSelectionChanged(const QString & _t1, const QString & _t2, Kwave::SaveBlocksPlugin::numbering_mode_t _t3, const QString & _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5);
}
QT_WARNING_POP
