/********************************************************************************
** Form generated from reading UI file 'KeywordWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYWORDWIDGETBASE_H
#define UI_KEYWORDWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KeywordWidgetBase
{
public:
    QGridLayout *gridLayout;
    QLineEdit *edKeyword;
    QPushButton *btRemove;
    QSpacerItem *Spacer40_2;
    QPushButton *btAdd;
    QPushButton *btAuto;
    QListWidget *lstKeywords;

    void setupUi(QWidget *KeywordWidgetBase)
    {
        if (KeywordWidgetBase->objectName().isEmpty())
            KeywordWidgetBase->setObjectName("KeywordWidgetBase");
        KeywordWidgetBase->resize(245, 179);
        gridLayout = new QGridLayout(KeywordWidgetBase);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        edKeyword = new QLineEdit(KeywordWidgetBase);
        edKeyword->setObjectName("edKeyword");

        gridLayout->addWidget(edKeyword, 0, 0, 1, 2);

        btRemove = new QPushButton(KeywordWidgetBase);
        btRemove->setObjectName("btRemove");

        gridLayout->addWidget(btRemove, 2, 1, 1, 1);

        Spacer40_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(Spacer40_2, 3, 1, 1, 1);

        btAdd = new QPushButton(KeywordWidgetBase);
        btAdd->setObjectName("btAdd");
        btAdd->setAutoDefault(true);

        gridLayout->addWidget(btAdd, 1, 1, 1, 1);

        btAuto = new QPushButton(KeywordWidgetBase);
        btAuto->setObjectName("btAuto");

        gridLayout->addWidget(btAuto, 4, 1, 1, 1);

        lstKeywords = new QListWidget(KeywordWidgetBase);
        lstKeywords->setObjectName("lstKeywords");
        lstKeywords->setMinimumSize(QSize(150, 100));

        gridLayout->addWidget(lstKeywords, 1, 0, 4, 1);

        QWidget::setTabOrder(edKeyword, lstKeywords);
        QWidget::setTabOrder(lstKeywords, btAdd);
        QWidget::setTabOrder(btAdd, btRemove);
        QWidget::setTabOrder(btRemove, btAuto);

        retranslateUi(KeywordWidgetBase);

        QMetaObject::connectSlotsByName(KeywordWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *KeywordWidgetBase)
    {
        KeywordWidgetBase->setWindowTitle(tr2i18n("Keywords", nullptr));
        btRemove->setText(tr2i18n("&Remove", nullptr));
        btAdd->setText(tr2i18n("&Add", nullptr));
#if QT_CONFIG(tooltip)
        btAuto->setToolTip(tr2i18n("auto-generate keywords", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btAuto->setWhatsThis(tr2i18n("<b>Auto-Generate Keywords</b><br>\n"
"Create a list of keywords by going through all present file information and merge it with the current list of keywords.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btAuto->setText(tr2i18n("A&uto", nullptr));
#if QT_CONFIG(tooltip)
        lstKeywords->setToolTip(tr2i18n("List of keywords.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class KeywordWidgetBase: public Ui_KeywordWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYWORDWIDGETBASE_H

