/********************************************************************************
** Form generated from reading UI file 'HMSTimeWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HMSTIMEWIDGETBASE_H
#define UI_HMSTIMEWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_HMSTimeWidgetBase
{
public:
    QHBoxLayout *hboxLayout;
    QSpinBox *sbHours;
    QSpinBox *sbMinutes;
    QSpinBox *sbSeconds;

    void setupUi(QWidget *HMSTimeWidgetBase)
    {
        if (HMSTimeWidgetBase->objectName().isEmpty())
            HMSTimeWidgetBase->setObjectName("HMSTimeWidgetBase");
        HMSTimeWidgetBase->resize(250, 36);
        hboxLayout = new QHBoxLayout(HMSTimeWidgetBase);
        hboxLayout->setSpacing(10);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        sbHours = new QSpinBox(HMSTimeWidgetBase);
        sbHours->setObjectName("sbHours");
        sbHours->setEnabled(true);
        sbHours->setValue(99);

        hboxLayout->addWidget(sbHours);

        sbMinutes = new QSpinBox(HMSTimeWidgetBase);
        sbMinutes->setObjectName("sbMinutes");
        sbMinutes->setEnabled(true);
        sbMinutes->setMinimum(-1);
        sbMinutes->setMaximum(60);
        sbMinutes->setValue(59);

        hboxLayout->addWidget(sbMinutes);

        sbSeconds = new QSpinBox(HMSTimeWidgetBase);
        sbSeconds->setObjectName("sbSeconds");
        sbSeconds->setEnabled(true);
        sbSeconds->setMinimum(-1);
        sbSeconds->setMaximum(60);
        sbSeconds->setValue(59);

        hboxLayout->addWidget(sbSeconds);


        retranslateUi(HMSTimeWidgetBase);

        QMetaObject::connectSlotsByName(HMSTimeWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *HMSTimeWidgetBase)
    {
        sbHours->setSuffix(tr2i18n(" h", nullptr));
        sbMinutes->setSuffix(tr2i18n(" min", nullptr));
        sbSeconds->setSuffix(tr2i18n(" sec", nullptr));
        (void)HMSTimeWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class HMSTimeWidgetBase: public Ui_HMSTimeWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HMSTIMEWIDGETBASE_H

