/********************************************************************************
** Form generated from reading UI file 'K3BExportDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_K3BEXPORTDIALOGBASE_H
#define UI_K3BEXPORTDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_K3BExportDialogBase
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *grpInputSettings;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *lblLabelFormat;
    KComboBox *cbLabelPattern;
    QCheckBox *chkSelectionOnly;
    QGroupBox *grpOutputSettings;
    QFormLayout *formLayout;
    QLabel *lblOverwritePolicy;
    KComboBox *cbOverwritePolicy;
    QLabel *lblDirectory;
    QLabel *lblFilename;
    KUrlRequester *fileUrlRequester;
    KUrlRequester *dirUrlRequester;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *K3BExportDialogBase)
    {
        if (K3BExportDialogBase->objectName().isEmpty())
            K3BExportDialogBase->setObjectName("K3BExportDialogBase");
        K3BExportDialogBase->resize(410, 326);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(K3BExportDialogBase->sizePolicy().hasHeightForWidth());
        K3BExportDialogBase->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(K3BExportDialogBase);
        verticalLayout->setSpacing(10);
        verticalLayout->setContentsMargins(10, 10, 10, 10);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, 6, 6, 6);
        grpInputSettings = new QGroupBox(K3BExportDialogBase);
        grpInputSettings->setObjectName("grpInputSettings");
        verticalLayout_2 = new QVBoxLayout(grpInputSettings);
        verticalLayout_2->setSpacing(10);
        verticalLayout_2->setContentsMargins(10, 10, 10, 10);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(10);
        horizontalLayout->setObjectName("horizontalLayout");
        lblLabelFormat = new QLabel(grpInputSettings);
        lblLabelFormat->setObjectName("lblLabelFormat");
        lblLabelFormat->setWordWrap(false);

        horizontalLayout->addWidget(lblLabelFormat);

        cbLabelPattern = new KComboBox(grpInputSettings);
        cbLabelPattern->setObjectName("cbLabelPattern");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbLabelPattern->sizePolicy().hasHeightForWidth());
        cbLabelPattern->setSizePolicy(sizePolicy1);
        cbLabelPattern->setEditable(true);
        cbLabelPattern->setDuplicatesEnabled(false);

        horizontalLayout->addWidget(cbLabelPattern);


        verticalLayout_2->addLayout(horizontalLayout);

        chkSelectionOnly = new QCheckBox(grpInputSettings);
        chkSelectionOnly->setObjectName("chkSelectionOnly");
        sizePolicy1.setHeightForWidth(chkSelectionOnly->sizePolicy().hasHeightForWidth());
        chkSelectionOnly->setSizePolicy(sizePolicy1);
        chkSelectionOnly->setChecked(true);

        verticalLayout_2->addWidget(chkSelectionOnly);


        verticalLayout->addWidget(grpInputSettings);

        grpOutputSettings = new QGroupBox(K3BExportDialogBase);
        grpOutputSettings->setObjectName("grpOutputSettings");
        formLayout = new QFormLayout(grpOutputSettings);
        formLayout->setSpacing(10);
        formLayout->setContentsMargins(10, 10, 10, 10);
        formLayout->setObjectName("formLayout");
        lblOverwritePolicy = new QLabel(grpOutputSettings);
        lblOverwritePolicy->setObjectName("lblOverwritePolicy");
        sizePolicy.setHeightForWidth(lblOverwritePolicy->sizePolicy().hasHeightForWidth());
        lblOverwritePolicy->setSizePolicy(sizePolicy);
        lblOverwritePolicy->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lblOverwritePolicy);

        cbOverwritePolicy = new KComboBox(grpOutputSettings);
        cbOverwritePolicy->addItem(QString());
        cbOverwritePolicy->addItem(QString());
        cbOverwritePolicy->setObjectName("cbOverwritePolicy");
        sizePolicy1.setHeightForWidth(cbOverwritePolicy->sizePolicy().hasHeightForWidth());
        cbOverwritePolicy->setSizePolicy(sizePolicy1);
        cbOverwritePolicy->setDuplicatesEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, cbOverwritePolicy);

        lblDirectory = new QLabel(grpOutputSettings);
        lblDirectory->setObjectName("lblDirectory");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lblDirectory);

        lblFilename = new QLabel(grpOutputSettings);
        lblFilename->setObjectName("lblFilename");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lblFilename);

        fileUrlRequester = new KUrlRequester(grpOutputSettings);
        fileUrlRequester->setObjectName("fileUrlRequester");
        fileUrlRequester->setMode(KFile::Mode::File|KFile::Mode::LocalOnly);
        fileUrlRequester->setAcceptMode(QFileDialog::AcceptMode::AcceptSave);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, fileUrlRequester);

        dirUrlRequester = new KUrlRequester(grpOutputSettings);
        dirUrlRequester->setObjectName("dirUrlRequester");
        dirUrlRequester->setMode(KFile::Mode::Directory|KFile::Mode::LocalOnly);
        dirUrlRequester->setAcceptMode(QFileDialog::AcceptMode::AcceptSave);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, dirUrlRequester);


        verticalLayout->addWidget(grpOutputSettings);

        buttonBox = new QDialogButtonBox(K3BExportDialogBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(cbLabelPattern, chkSelectionOnly);
        QWidget::setTabOrder(chkSelectionOnly, cbOverwritePolicy);

        retranslateUi(K3BExportDialogBase);

        QMetaObject::connectSlotsByName(K3BExportDialogBase);
    } // setupUi

    void retranslateUi(QDialog *K3BExportDialogBase)
    {
        grpInputSettings->setTitle(tr2i18n("Input Settings", nullptr));
        lblLabelFormat->setText(tr2i18n("Format of Labels:", nullptr));
#if QT_CONFIG(whatsthis)
        cbLabelPattern->setWhatsThis(tr2i18n("<html><head/><body><p>Select a pattern for detecting title and artist from the text of a label.<br/>It currently understands the following placeholders:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Courier New,courier'; font-weight:600;\">[%title] </span>title of the song</li><li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Courier New,courier'; font-weight:600;\">[%artist]</span> name of the artist</li></ul></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        chkSelectionOnly->setWhatsThis(tr2i18n("If checked, <b>save only the blocks that overlap with the current selection</b>, otherwise the whole file. <br><i>Please note that this option is disabled if nothing is selected or the selection already covers the whole file.</i>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkSelectionOnly->setText(tr2i18n("Use Selection only", nullptr));
        grpOutputSettings->setTitle(tr2i18n("Output Settings", nullptr));
        lblOverwritePolicy->setText(tr2i18n("Overwrite Policy:", nullptr));
        cbOverwritePolicy->setItemText(0, tr2i18n("Overwrite Existing Files", nullptr));
        cbOverwritePolicy->setItemText(1, tr2i18n("Use new File Names", nullptr));

#if QT_CONFIG(whatsthis)
        cbOverwritePolicy->setWhatsThis(tr2i18n("Select whether existing files are overwritten or new file names are used when exporting the files to use as tracks of the audio CD.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblDirectory->setText(tr2i18n("Export Location:", nullptr));
        lblFilename->setText(tr2i18n("K3b Project File:", nullptr));
#if QT_CONFIG(whatsthis)
        fileUrlRequester->setWhatsThis(tr2i18n("Location to save the K3b project file", nullptr));
#endif // QT_CONFIG(whatsthis)
        fileUrlRequester->setNameFilters(QStringList{});
        fileUrlRequester->setPlaceholderText(tr2i18n("Project File", nullptr));
#if QT_CONFIG(whatsthis)
        dirUrlRequester->setWhatsThis(tr2i18n("Location to export the audio files to", nullptr));
#endif // QT_CONFIG(whatsthis)
        dirUrlRequester->setPlaceholderText(tr2i18n("Export Location", nullptr));
        (void)K3BExportDialogBase;
    } // retranslateUi

};

namespace Ui {
    class K3BExportDialogBase: public Ui_K3BExportDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // K3BEXPORTDIALOGBASE_H

