/****************************************************************************
** Meta object code from reading C++ file 'MainWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/kwave/MainWidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave10MainWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::MainWidget::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave10MainWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::MainWidget",
        "sigZoomChanged",
        "",
        "zoom",
        "sigCommand",
        "command",
        "sigVisibleRangeChanged",
        "sample_index_t",
        "offset",
        "visible",
        "total",
        "updateViewRange",
        "executeCommand",
        "setOffset",
        "new_offset",
        "scrollTo",
        "pos",
        "setZoom",
        "new_zoom",
        "zoomSelection",
        "zoomAll",
        "zoomNormal",
        "zoomIn",
        "zoomOut",
        "slotTrackInserted",
        "index",
        "Kwave::Track*",
        "track",
        "slotTrackDeleted",
        "refreshHorizontalScrollBar",
        "horizontalScrollBarMoved",
        "newval"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigZoomChanged'
        QtMocHelpers::SignalData<void(double)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'sigCommand'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'sigVisibleRangeChanged'
        QtMocHelpers::SignalData<void(sample_index_t, sample_index_t, sample_index_t)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 }, { 0x80000000 | 7, 10 },
        }}),
        // Slot 'updateViewRange'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'executeCommand'
        QtMocHelpers::SlotData<int(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setOffset'
        QtMocHelpers::SlotData<void(sample_index_t)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 14 },
        }}),
        // Slot 'scrollTo'
        QtMocHelpers::SlotData<void(sample_index_t)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 16 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(double)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Slot 'zoomSelection'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomAll'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomNormal'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotTrackInserted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'slotTrackDeleted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'refreshHorizontalScrollBar'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'horizontalScrollBarMoved'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWidget, qt_meta_tag_ZN5Kwave10MainWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::MainWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave10MainWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave10MainWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave10MainWidgetE_t>.metaTypes,
    nullptr
} };

void Kwave::MainWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigZoomChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 1: _t->sigCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->sigVisibleRangeChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 3: _t->updateViewRange(); break;
        case 4: { int _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setOffset((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 6: _t->scrollTo((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 7: _t->setZoom((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->zoomSelection(); break;
        case 9: _t->zoomAll(); break;
        case 10: _t->zoomNormal(); break;
        case 11: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->zoomIn(); break;
        case 13: _t->zoomOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->zoomOut(); break;
        case 15: _t->slotTrackInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 16: _t->slotTrackDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 17: _t->refreshHorizontalScrollBar(); break;
        case 18: _t->horizontalScrollBarMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWidget::*)(double )>(_a, &MainWidget::sigZoomChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWidget::*)(const QString & )>(_a, &MainWidget::sigCommand, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWidget::*)(sample_index_t , sample_index_t , sample_index_t )>(_a, &MainWidget::sigVisibleRangeChanged, 2))
            return;
    }
}

const QMetaObject *Kwave::MainWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::MainWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave10MainWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "CommandHandler"))
        return static_cast< CommandHandler*>(this);
    if (!strcmp(_clname, "Zoomable"))
        return static_cast< Zoomable*>(this);
    return QWidget::qt_metacast(_clname);
}

int Kwave::MainWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Kwave::MainWidget::sigZoomChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::MainWidget::sigCommand(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kwave::MainWidget::sigVisibleRangeChanged(sample_index_t _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
