/********************************************************************************
** Form generated from reading UI file 'SonagramDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SONAGRAMDLG_H
#define UI_SONAGRAMDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_SonagramDlg
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;
    QGroupBox *buttonGroup1;
    QVBoxLayout *vboxLayout;
    QRadioButton *rbColor;
    QRadioButton *rbGreyScale;
    QGroupBox *groupBox3;
    QVBoxLayout *vboxLayout1;
    QCheckBox *cbTrackChanges;
    QCheckBox *cbFollowSelection;
    QGroupBox *groupBox1;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout1;
    QLabel *m_pointlabel;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout2;
    QLabel *Label2;
    QSpacerItem *spacerItem1;
    KComboBox *windowtypebox;
    KComboBox *pointbox;
    QSlider *pointslider;
    QLabel *bitmaplabel;
    QLabel *windowlabel;

    void setupUi(QDialog *SonagramDlg)
    {
        if (SonagramDlg->objectName().isEmpty())
            SonagramDlg->setObjectName("SonagramDlg");
        SonagramDlg->resize(518, 319);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SonagramDlg->sizePolicy().hasHeightForWidth());
        SonagramDlg->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(SonagramDlg);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        buttonBox = new QDialogButtonBox(SonagramDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 2);

        buttonGroup1 = new QGroupBox(SonagramDlg);
        buttonGroup1->setObjectName("buttonGroup1");
        vboxLayout = new QVBoxLayout(buttonGroup1);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        rbColor = new QRadioButton(buttonGroup1);
        rbColor->setObjectName("rbColor");
        rbColor->setChecked(true);

        vboxLayout->addWidget(rbColor);

        rbGreyScale = new QRadioButton(buttonGroup1);
        rbGreyScale->setObjectName("rbGreyScale");

        vboxLayout->addWidget(rbGreyScale);


        gridLayout->addWidget(buttonGroup1, 1, 0, 1, 1);

        groupBox3 = new QGroupBox(SonagramDlg);
        groupBox3->setObjectName("groupBox3");
        vboxLayout1 = new QVBoxLayout(groupBox3);
        vboxLayout1->setSpacing(10);
        vboxLayout1->setContentsMargins(10, 10, 10, 10);
        vboxLayout1->setObjectName("vboxLayout1");
        cbTrackChanges = new QCheckBox(groupBox3);
        cbTrackChanges->setObjectName("cbTrackChanges");

        vboxLayout1->addWidget(cbTrackChanges);

        cbFollowSelection = new QCheckBox(groupBox3);
        cbFollowSelection->setObjectName("cbFollowSelection");
        cbFollowSelection->setEnabled(false);

        vboxLayout1->addWidget(cbFollowSelection);


        gridLayout->addWidget(groupBox3, 1, 1, 1, 1);

        groupBox1 = new QGroupBox(SonagramDlg);
        groupBox1->setObjectName("groupBox1");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox1->sizePolicy().hasHeightForWidth());
        groupBox1->setSizePolicy(sizePolicy1);
        gridLayout1 = new QGridLayout(groupBox1);
        gridLayout1->setSpacing(10);
        gridLayout1->setContentsMargins(10, 10, 10, 10);
        gridLayout1->setObjectName("gridLayout1");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(10);
        hboxLayout1->setObjectName("hboxLayout1");
        m_pointlabel = new QLabel(groupBox1);
        m_pointlabel->setObjectName("m_pointlabel");
        m_pointlabel->setWordWrap(false);

        hboxLayout1->addWidget(m_pointlabel);

        spacerItem = new QSpacerItem(61, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);


        gridLayout1->addLayout(hboxLayout1, 0, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(10);
        hboxLayout2->setObjectName("hboxLayout2");
        Label2 = new QLabel(groupBox1);
        Label2->setObjectName("Label2");
        Label2->setWordWrap(false);

        hboxLayout2->addWidget(Label2);

        spacerItem1 = new QSpacerItem(111, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem1);


        gridLayout1->addLayout(hboxLayout2, 1, 0, 1, 1);

        windowtypebox = new KComboBox(groupBox1);
        windowtypebox->setObjectName("windowtypebox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(50);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(windowtypebox->sizePolicy().hasHeightForWidth());
        windowtypebox->setSizePolicy(sizePolicy2);
        windowtypebox->setMinimumSize(QSize(150, 0));

        gridLayout1->addWidget(windowtypebox, 1, 1, 1, 1);

        pointbox = new KComboBox(groupBox1);
        pointbox->addItem(QString());
        pointbox->addItem(QString());
        pointbox->addItem(QString());
        pointbox->addItem(QString());
        pointbox->addItem(QString());
        pointbox->addItem(QString());
        pointbox->addItem(QString());
        pointbox->setObjectName("pointbox");
        sizePolicy2.setHeightForWidth(pointbox->sizePolicy().hasHeightForWidth());
        pointbox->setSizePolicy(sizePolicy2);
        pointbox->setEditable(true);
        pointbox->setDuplicatesEnabled(false);
        pointbox->setProperty("currentItem", QVariant(3));

        gridLayout1->addWidget(pointbox, 0, 1, 1, 1);

        pointslider = new QSlider(groupBox1);
        pointslider->setObjectName("pointslider");
        sizePolicy2.setHeightForWidth(pointslider->sizePolicy().hasHeightForWidth());
        pointslider->setSizePolicy(sizePolicy2);
        pointslider->setMinimumSize(QSize(0, 20));
        pointslider->setMinimum(2);
        pointslider->setMaximum(2);
        pointslider->setOrientation(Qt::Horizontal);

        gridLayout1->addWidget(pointslider, 2, 1, 1, 1);

        bitmaplabel = new QLabel(groupBox1);
        bitmaplabel->setObjectName("bitmaplabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(bitmaplabel->sizePolicy().hasHeightForWidth());
        bitmaplabel->setSizePolicy(sizePolicy3);
        bitmaplabel->setMinimumSize(QSize(320, 20));
        bitmaplabel->setWordWrap(false);

        gridLayout1->addWidget(bitmaplabel, 2, 0, 1, 1);

        windowlabel = new QLabel(groupBox1);
        windowlabel->setObjectName("windowlabel");
        windowlabel->setWordWrap(false);

        gridLayout1->addWidget(windowlabel, 3, 0, 1, 2);


        gridLayout->addWidget(groupBox1, 0, 0, 1, 2);

        QWidget::setTabOrder(pointbox, windowtypebox);
        QWidget::setTabOrder(windowtypebox, pointslider);
        QWidget::setTabOrder(pointslider, rbColor);
        QWidget::setTabOrder(rbColor, cbTrackChanges);
        QWidget::setTabOrder(cbTrackChanges, cbFollowSelection);

        retranslateUi(SonagramDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SonagramDlg, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SonagramDlg, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(SonagramDlg);
    } // setupUi

    void retranslateUi(QDialog *SonagramDlg)
    {
        SonagramDlg->setWindowTitle(tr2i18n("Set FFT/Time Resolution Parameters", nullptr));
        buttonGroup1->setTitle(tr2i18n("display", nullptr));
#if QT_CONFIG(tooltip)
        rbColor->setToolTip(tr2i18n("Use different colors for amplitude", nullptr));
#endif // QT_CONFIG(tooltip)
        rbColor->setText(tr2i18n("Use colors", nullptr));
#if QT_CONFIG(tooltip)
        rbGreyScale->setToolTip(tr2i18n("Use grayscale only for amplitude", nullptr));
#endif // QT_CONFIG(tooltip)
        rbGreyScale->setText(tr2i18n("Grayscale", nullptr));
        groupBox3->setTitle(tr2i18n("Update", nullptr));
#if QT_CONFIG(tooltip)
        cbTrackChanges->setToolTip(tr2i18n("Automatically update the sonagram <br>if the signal data has changed", nullptr));
#endif // QT_CONFIG(tooltip)
        cbTrackChanges->setText(tr2i18n("On modifications", nullptr));
#if QT_CONFIG(tooltip)
        cbFollowSelection->setToolTip(tr2i18n("Automatically update the sonagram if the selection<br>has been enlarged, reduced or moved", nullptr));
#endif // QT_CONFIG(tooltip)
        cbFollowSelection->setText(tr2i18n("Follow selection", nullptr));
        groupBox1->setTitle(tr2i18n("FFT settings", nullptr));
        m_pointlabel->setText(tr2i18n("Number of FFT points:", nullptr));
        Label2->setText(tr2i18n("Window function:", nullptr));
#if QT_CONFIG(tooltip)
        windowtypebox->setToolTip(tr2i18n("Choose windowing function here.<br>\n"
"If the transformation should stay reversible, use the type \"None\".", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        windowtypebox->setWhatsThis(tr2i18n("Choose windowing function here.<br>\n"
"If the transformation should stay reversible, use the type \"None\".", nullptr));
#endif // QT_CONFIG(whatsthis)
        pointbox->setItemText(0, tr2i18n("64", nullptr));
        pointbox->setItemText(1, tr2i18n("128", nullptr));
        pointbox->setItemText(2, tr2i18n("256", nullptr));
        pointbox->setItemText(3, tr2i18n("512", nullptr));
        pointbox->setItemText(4, tr2i18n("1024", nullptr));
        pointbox->setItemText(5, tr2i18n("2048", nullptr));
        pointbox->setItemText(6, tr2i18n("4096", nullptr));

#if QT_CONFIG(tooltip)
        pointbox->setToolTip(tr2i18n("<b>Number of FFT points:</b><p></p>Try to choose numbers with small prime factors,<br>\n"
"if choosing big window sizes.<br>\n"
"The computation will be much faster!", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        pointbox->setWhatsThis(tr2i18n("<b>Number of FFT points:</b><p></p>Try to choose numbers with small prime factors,<br>\n"
"if choosing big window sizes.<br>\n"
"The computation will be much faster!", nullptr));
#endif // QT_CONFIG(whatsthis)
        bitmaplabel->setText(tr2i18n("?:", nullptr));
        windowlabel->setText(tr2i18n("?:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SonagramDlg: public Ui_SonagramDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SONAGRAMDLG_H

