/****************************************************************************
** Meta object code from reading C++ file 'SignalManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/libkwave/SignalManager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SignalManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave13SignalManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::SignalManager::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave13SignalManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::SignalManager",
        "sigSelectionChanged",
        "",
        "sample_index_t",
        "offset",
        "length",
        "sigTrackInserted",
        "index",
        "Kwave::Track*",
        "track",
        "sigTrackDeleted",
        "sigTrackSelectionChanged",
        "enabled",
        "sigSamplesInserted",
        "sigSamplesDeleted",
        "sigSamplesModified",
        "sigMetaDataChanged",
        "Kwave::MetaDataList",
        "meta",
        "sigUndoRedoInfo",
        "undo",
        "redo",
        "sigModified",
        "slotTrackInserted",
        "slotTrackDeleted",
        "slotSamplesInserted",
        "slotSamplesDeleted",
        "slotSamplesModified",
        "closeUndoTransaction",
        "emitUndoRedoInfo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigSelectionChanged'
        QtMocHelpers::SignalData<void(sample_index_t, sample_index_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Signal 'sigTrackInserted'
        QtMocHelpers::SignalData<void(unsigned int, Kwave::Track *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'sigTrackDeleted'
        QtMocHelpers::SignalData<void(unsigned int, Kwave::Track *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'sigTrackSelectionChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'sigSamplesInserted'
        QtMocHelpers::SignalData<void(unsigned int, sample_index_t, sample_index_t)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Signal 'sigSamplesDeleted'
        QtMocHelpers::SignalData<void(unsigned int, sample_index_t, sample_index_t)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Signal 'sigSamplesModified'
        QtMocHelpers::SignalData<void(unsigned int, sample_index_t, sample_index_t)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Signal 'sigMetaDataChanged'
        QtMocHelpers::SignalData<void(Kwave::MetaDataList)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'sigUndoRedoInfo'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Signal 'sigModified'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTrackInserted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotTrackDeleted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotSamplesInserted'
        QtMocHelpers::SlotData<void(unsigned int, sample_index_t, sample_index_t)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'slotSamplesDeleted'
        QtMocHelpers::SlotData<void(unsigned int, sample_index_t, sample_index_t)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'slotSamplesModified'
        QtMocHelpers::SlotData<void(unsigned int, sample_index_t, sample_index_t)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 9 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'closeUndoTransaction'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitUndoRedoInfo'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignalManager, qt_meta_tag_ZN5Kwave13SignalManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::SignalManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave13SignalManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave13SignalManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave13SignalManagerE_t>.metaTypes,
    nullptr
} };

void Kwave::SignalManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignalManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigSelectionChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2]))); break;
        case 1: _t->sigTrackInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 2: _t->sigTrackDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 3: _t->sigTrackSelectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->sigSamplesInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 5: _t->sigSamplesDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 6: _t->sigSamplesModified((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 7: _t->sigMetaDataChanged((*reinterpret_cast<std::add_pointer_t<Kwave::MetaDataList>>(_a[1]))); break;
        case 8: _t->sigUndoRedoInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->sigModified(); break;
        case 10: _t->undo(); break;
        case 11: _t->redo(); break;
        case 12: _t->slotTrackInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 13: _t->slotTrackDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 14: _t->slotSamplesInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 15: _t->slotSamplesDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 16: _t->slotSamplesModified((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 17: _t->closeUndoTransaction(); break;
        case 18: _t->emitUndoRedoInfo(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(sample_index_t , sample_index_t )>(_a, &SignalManager::sigSelectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(unsigned int , Kwave::Track * )>(_a, &SignalManager::sigTrackInserted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(unsigned int , Kwave::Track * )>(_a, &SignalManager::sigTrackDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(bool )>(_a, &SignalManager::sigTrackSelectionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(unsigned int , sample_index_t , sample_index_t )>(_a, &SignalManager::sigSamplesInserted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(unsigned int , sample_index_t , sample_index_t )>(_a, &SignalManager::sigSamplesDeleted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(unsigned int , sample_index_t , sample_index_t )>(_a, &SignalManager::sigSamplesModified, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(Kwave::MetaDataList )>(_a, &SignalManager::sigMetaDataChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)(const QString & , const QString & )>(_a, &SignalManager::sigUndoRedoInfo, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalManager::*)()>(_a, &SignalManager::sigModified, 9))
            return;
    }
}

const QMetaObject *Kwave::SignalManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::SignalManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave13SignalManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kwave::SignalManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Kwave::SignalManager::sigSelectionChanged(sample_index_t _t1, sample_index_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Kwave::SignalManager::sigTrackInserted(unsigned int _t1, Kwave::Track * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Kwave::SignalManager::sigTrackDeleted(unsigned int _t1, Kwave::Track * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Kwave::SignalManager::sigTrackSelectionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kwave::SignalManager::sigSamplesInserted(unsigned int _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void Kwave::SignalManager::sigSamplesDeleted(unsigned int _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Kwave::SignalManager::sigSamplesModified(unsigned int _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void Kwave::SignalManager::sigMetaDataChanged(Kwave::MetaDataList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Kwave::SignalManager::sigUndoRedoInfo(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Kwave::SignalManager::sigModified()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
