/********************************************************************************
** Form generated from reading UI file 'AmplifyFreeDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AMPLIFYFREEDLG_H
#define UI_AMPLIFYFREEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include <libgui/CurveWidget.h>
#include <libgui/ScaleWidget.h>
#include "libgui/CurveWidget.h"
#include "libgui/ScaleWidget.h"

QT_BEGIN_NAMESPACE

class Ui_AmplifyFreeDlg
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    Kwave::ScaleWidget *xScale;
    Kwave::ScaleWidget *yScale;
    Kwave::CurveWidget *curveWidget;
    QFrame *Line1;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox_Help;
    QSpacerItem *Spacer1;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AmplifyFreeDlg)
    {
        if (AmplifyFreeDlg->objectName().isEmpty())
            AmplifyFreeDlg->setObjectName("AmplifyFreeDlg");
        AmplifyFreeDlg->resize(324, 218);
        vboxLayout = new QVBoxLayout(AmplifyFreeDlg);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        xScale = new Kwave::ScaleWidget(AmplifyFreeDlg);
        xScale->setObjectName("xScale");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(xScale->sizePolicy().hasHeightForWidth());
        xScale->setSizePolicy(sizePolicy);
        xScale->setMinimumSize(QSize(150, 30));

        gridLayout->addWidget(xScale, 1, 1, 1, 1);

        yScale = new Kwave::ScaleWidget(AmplifyFreeDlg);
        yScale->setObjectName("yScale");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(yScale->sizePolicy().hasHeightForWidth());
        yScale->setSizePolicy(sizePolicy1);
        yScale->setMinimumSize(QSize(30, 100));

        gridLayout->addWidget(yScale, 0, 0, 1, 1);

        curveWidget = new Kwave::CurveWidget(AmplifyFreeDlg);
        curveWidget->setObjectName("curveWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(curveWidget->sizePolicy().hasHeightForWidth());
        curveWidget->setSizePolicy(sizePolicy2);
        curveWidget->setMinimumSize(QSize(150, 100));

        gridLayout->addWidget(curveWidget, 0, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        Line1 = new QFrame(AmplifyFreeDlg);
        Line1->setObjectName("Line1");
        Line1->setMinimumSize(QSize(0, 20));
        Line1->setFrameShape(QFrame::HLine);
        Line1->setFrameShadow(QFrame::Sunken);

        vboxLayout->addWidget(Line1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        buttonBox_Help = new QDialogButtonBox(AmplifyFreeDlg);
        buttonBox_Help->setObjectName("buttonBox_Help");
        buttonBox_Help->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout->addWidget(buttonBox_Help);

        Spacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(Spacer1);

        buttonBox = new QDialogButtonBox(AmplifyFreeDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(AmplifyFreeDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AmplifyFreeDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AmplifyFreeDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AmplifyFreeDlg);
    } // setupUi

    void retranslateUi(QDialog *AmplifyFreeDlg)
    {
        AmplifyFreeDlg->setWindowTitle(tr2i18n("Amplify Free", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AmplifyFreeDlg: public Ui_AmplifyFreeDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AMPLIFYFREEDLG_H

