/********************************************************************************
** Form generated from reading UI file 'GotoDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GOTODLG_H
#define UI_GOTODLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "libgui/SelectTimeWidget.h"

QT_BEGIN_NAMESPACE

class Ui_GotoDlg
{
public:
    QGridLayout *gridLayout;
    Kwave::SelectTimeWidget *select_pos;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox_Help;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *GotoDlg)
    {
        if (GotoDlg->objectName().isEmpty())
            GotoDlg->setObjectName("GotoDlg");
        GotoDlg->resize(340, 162);
        gridLayout = new QGridLayout(GotoDlg);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        select_pos = new Kwave::SelectTimeWidget(GotoDlg);
        select_pos->setObjectName("select_pos");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(select_pos->sizePolicy().hasHeightForWidth());
        select_pos->setSizePolicy(sizePolicy);
        select_pos->setMinimumSize(QSize(200, 100));

        gridLayout->addWidget(select_pos, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        buttonBox_Help = new QDialogButtonBox(GotoDlg);
        buttonBox_Help->setObjectName("buttonBox_Help");
        buttonBox_Help->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout->addWidget(buttonBox_Help);

        spacerItem = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(GotoDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);


        retranslateUi(GotoDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, GotoDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, GotoDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(GotoDlg);
    } // setupUi

    void retranslateUi(QDialog *GotoDlg)
    {
        GotoDlg->setWindowTitle(tr2i18n("Go to Position", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GotoDlg: public Ui_GotoDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GOTODLG_H

