/****************************************************************************
** Meta object code from reading C++ file 'SelectionTracker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/libgui/SelectionTracker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SelectionTracker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave16SelectionTrackerE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::SelectionTracker::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave16SelectionTrackerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::SelectionTracker",
        "sigTrackInserted",
        "",
        "QUuid",
        "uuid",
        "sigTrackDeleted",
        "sigOffsetChanged",
        "sample_index_t",
        "offset",
        "sigLengthChanged",
        "length",
        "sigInvalidated",
        "const QUuid*",
        "track",
        "first",
        "last",
        "slotTrackInserted",
        "index",
        "Kwave::Track*",
        "slotTrackDeleted",
        "slotSamplesInserted",
        "slotSamplesDeleted",
        "slotSamplesModified"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigTrackInserted'
        QtMocHelpers::SignalData<void(const QUuid &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigTrackDeleted'
        QtMocHelpers::SignalData<void(const QUuid &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigOffsetChanged'
        QtMocHelpers::SignalData<void(sample_index_t)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'sigLengthChanged'
        QtMocHelpers::SignalData<void(sample_index_t)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 10 },
        }}),
        // Signal 'sigInvalidated'
        QtMocHelpers::SignalData<void(const QUuid *, sample_index_t, sample_index_t)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 7, 14 }, { 0x80000000 | 7, 15 },
        }}),
        // Slot 'slotTrackInserted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 17 }, { 0x80000000 | 18, 13 },
        }}),
        // Slot 'slotTrackDeleted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 17 }, { 0x80000000 | 18, 13 },
        }}),
        // Slot 'slotSamplesInserted'
        QtMocHelpers::SlotData<void(unsigned int, sample_index_t, sample_index_t)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 13 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 10 },
        }}),
        // Slot 'slotSamplesDeleted'
        QtMocHelpers::SlotData<void(unsigned int, sample_index_t, sample_index_t)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 13 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 10 },
        }}),
        // Slot 'slotSamplesModified'
        QtMocHelpers::SlotData<void(unsigned int, sample_index_t, sample_index_t)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 13 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SelectionTracker, qt_meta_tag_ZN5Kwave16SelectionTrackerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::SelectionTracker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16SelectionTrackerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16SelectionTrackerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave16SelectionTrackerE_t>.metaTypes,
    nullptr
} };

void Kwave::SelectionTracker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SelectionTracker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigTrackInserted((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 1: _t->sigTrackDeleted((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 2: _t->sigOffsetChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 3: _t->sigLengthChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 4: _t->sigInvalidated((*reinterpret_cast<std::add_pointer_t<const QUuid*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 5: _t->slotTrackInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 6: _t->slotTrackDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 7: _t->slotSamplesInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 8: _t->slotSamplesDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 9: _t->slotSamplesModified((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SelectionTracker::*)(const QUuid & )>(_a, &SelectionTracker::sigTrackInserted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionTracker::*)(const QUuid & )>(_a, &SelectionTracker::sigTrackDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionTracker::*)(sample_index_t )>(_a, &SelectionTracker::sigOffsetChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionTracker::*)(sample_index_t )>(_a, &SelectionTracker::sigLengthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SelectionTracker::*)(const QUuid * , sample_index_t , sample_index_t )>(_a, &SelectionTracker::sigInvalidated, 4))
            return;
    }
}

const QMetaObject *Kwave::SelectionTracker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::SelectionTracker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16SelectionTrackerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kwave::SelectionTracker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Kwave::SelectionTracker::sigTrackInserted(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::SelectionTracker::sigTrackDeleted(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kwave::SelectionTracker::sigOffsetChanged(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kwave::SelectionTracker::sigLengthChanged(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kwave::SelectionTracker::sigInvalidated(const QUuid * _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
