/********************************************************************************
** Form generated from reading UI file 'NoiseDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOISEDLG_H
#define UI_NOISEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "libgui/ImageView.h"
#include "libgui/InvertableSpinBox.h"

QT_BEGIN_NAMESPACE

class Ui_NoiseDlg
{
public:
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *ButtonGroup1;
    QVBoxLayout *verticalLayout;
    QRadioButton *rbPercentage;
    QRadioButton *rbLogarithmic;
    QSpacerItem *spacer;
    Kwave::ImageView *preview;
    Kwave::InvertableSpinBox *spinbox;
    QSlider *slider;
    QFrame *Line1;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox_Help;
    QPushButton *btListen;
    QSpacerItem *spacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NoiseDlg)
    {
        if (NoiseDlg->objectName().isEmpty())
            NoiseDlg->setObjectName("NoiseDlg");
        NoiseDlg->setWindowModality(Qt::ApplicationModal);
        NoiseDlg->resize(583, 292);
        verticalLayout_3 = new QVBoxLayout(NoiseDlg);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        ButtonGroup1 = new QGroupBox(NoiseDlg);
        ButtonGroup1->setObjectName("ButtonGroup1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ButtonGroup1->sizePolicy().hasHeightForWidth());
        ButtonGroup1->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(ButtonGroup1);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(10, 10, 10, -1);
        rbPercentage = new QRadioButton(ButtonGroup1);
        rbPercentage->setObjectName("rbPercentage");
        sizePolicy.setHeightForWidth(rbPercentage->sizePolicy().hasHeightForWidth());
        rbPercentage->setSizePolicy(sizePolicy);
        rbPercentage->setChecked(true);

        verticalLayout->addWidget(rbPercentage);

        rbLogarithmic = new QRadioButton(ButtonGroup1);
        rbLogarithmic->setObjectName("rbLogarithmic");
        sizePolicy.setHeightForWidth(rbLogarithmic->sizePolicy().hasHeightForWidth());
        rbLogarithmic->setSizePolicy(sizePolicy);
        rbLogarithmic->setChecked(false);

        verticalLayout->addWidget(rbLogarithmic);


        verticalLayout_2->addWidget(ButtonGroup1);

        spacer = new QSpacerItem(152, 58, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacer);


        gridLayout->addLayout(verticalLayout_2, 0, 0, 1, 1);

        preview = new Kwave::ImageView(NoiseDlg);
        preview->setObjectName("preview");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(100);
        sizePolicy1.setVerticalStretch(100);
        sizePolicy1.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy1);
        preview->setMinimumSize(QSize(400, 150));

        gridLayout->addWidget(preview, 0, 1, 1, 1);

        spinbox = new Kwave::InvertableSpinBox(NoiseDlg);
        spinbox->setObjectName("spinbox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(spinbox->sizePolicy().hasHeightForWidth());
        spinbox->setSizePolicy(sizePolicy2);
        spinbox->setMinimumSize(QSize(40, 30));

        gridLayout->addWidget(spinbox, 1, 0, 1, 1);

        slider = new QSlider(NoiseDlg);
        slider->setObjectName("slider");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(slider->sizePolicy().hasHeightForWidth());
        slider->setSizePolicy(sizePolicy3);
        slider->setMaximum(42);
        slider->setPageStep(6);
        slider->setValue(0);
        slider->setOrientation(Qt::Horizontal);
        slider->setInvertedAppearance(true);
        slider->setInvertedControls(true);
        slider->setTickPosition(QSlider::TicksBothSides);
        slider->setTickInterval(6);

        gridLayout->addWidget(slider, 1, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout);

        Line1 = new QFrame(NoiseDlg);
        Line1->setObjectName("Line1");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(Line1->sizePolicy().hasHeightForWidth());
        Line1->setSizePolicy(sizePolicy4);
        Line1->setMinimumSize(QSize(0, 20));
        Line1->setFrameShape(QFrame::HLine);
        Line1->setFrameShadow(QFrame::Sunken);

        verticalLayout_3->addWidget(Line1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonBox_Help = new QDialogButtonBox(NoiseDlg);
        buttonBox_Help->setObjectName("buttonBox_Help");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(buttonBox_Help->sizePolicy().hasHeightForWidth());
        buttonBox_Help->setSizePolicy(sizePolicy5);
        buttonBox_Help->setStandardButtons(QDialogButtonBox::Help);

        horizontalLayout->addWidget(buttonBox_Help);

        btListen = new QPushButton(NoiseDlg);
        btListen->setObjectName("btListen");
        sizePolicy5.setHeightForWidth(btListen->sizePolicy().hasHeightForWidth());
        btListen->setSizePolicy(sizePolicy5);
        btListen->setCheckable(true);

        horizontalLayout->addWidget(btListen);

        spacer_2 = new QSpacerItem(218, 27, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacer_2);

        buttonBox = new QDialogButtonBox(NoiseDlg);
        buttonBox->setObjectName("buttonBox");
        sizePolicy.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout_3->addLayout(horizontalLayout);

        QWidget::setTabOrder(buttonBox, buttonBox_Help);
        QWidget::setTabOrder(buttonBox_Help, btListen);
        QWidget::setTabOrder(btListen, rbPercentage);
        QWidget::setTabOrder(rbPercentage, rbLogarithmic);
        QWidget::setTabOrder(rbLogarithmic, slider);

        retranslateUi(NoiseDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NoiseDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NoiseDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(NoiseDlg);
    } // setupUi

    void retranslateUi(QDialog *NoiseDlg)
    {
        NoiseDlg->setWindowTitle(tr2i18n("Add Noise", nullptr));
        ButtonGroup1->setTitle(tr2i18n("Mode", nullptr));
#if QT_CONFIG(tooltip)
        rbPercentage->setToolTip(tr2i18n("add a noise level by percentage", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbPercentage->setWhatsThis(tr2i18n("Adds a noise level given as a percentage relative to the maximum volume level.\n"
"For example: \"1 %\", \"15%\" or \"100%\"", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbPercentage->setText(tr2i18n("&Percentage", nullptr));
#if QT_CONFIG(tooltip)
        rbLogarithmic->setToolTip(tr2i18n("add a noise level in dB", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbLogarithmic->setWhatsThis(tr2i18n("adds a noise level in logarithmic scale (decibel).\n"
"For example: \"-3 dB\", \"- 6 dB\".", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbLogarithmic->setText(tr2i18n("&Logarithmic", nullptr));
#if QT_CONFIG(tooltip)
        spinbox->setToolTip(tr2i18n("Volume", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        slider->setToolTip(tr2i18n("Noise Level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        btListen->setToolTip(tr2i18n("start/stop pre-listening", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btListen->setWhatsThis(tr2i18n("Start or stop the pre-listening of the current settings. If pre-listening is enabled, you will nearly immediately hear any change in the selected parameters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btListen->setText(tr2i18n("&Listen", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NoiseDlg: public Ui_NoiseDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NOISEDLG_H

