/********************************************************************************
** Form generated from reading UI file 'FileInfoDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILEINFODLG_H
#define UI_FILEINFODLG_H

#include <KComboBox>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDateEdit>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "CompressionWidget.h"
#include "KComboBox"
#include "KeywordWidget.h"

QT_BEGIN_NAMESPACE

class Ui_FileInfoDlg
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *InfoTab;
    QWidget *tab_file;
    QGridLayout *gridLayout;
    QLineEdit *edFileName;
    QLabel *lblFileName;
    QSpacerItem *Spacer95_3_3;
    QSpacerItem *Spacer38_2;
    QHBoxLayout *hboxLayout;
    KComboBox *cbSampleFormat;
    QSpacerItem *Spacer98_2_2;
    QLabel *lblLength;
    QLabel *lblChannels;
    QHBoxLayout *hboxLayout1;
    QSpinBox *sbChannels;
    QLabel *lblChannelsVerbose;
    QSpacerItem *Spacer99_2;
    QLabel *lblResolution;
    QLabel *lblSampleRate;
    QLabel *lblSampleFormat;
    QHBoxLayout *hboxLayout2;
    QSpinBox *sbResolution;
    QLabel *lblBits_2;
    QSpacerItem *Spacer100_2;
    QHBoxLayout *hboxLayout3;
    KComboBox *cbSampleRate;
    QLabel *lblSamplesPerSecond_2;
    QSpacerItem *Spacer98_2;
    QFrame *Frame3_2;
    QLineEdit *txtLength;
    QFrame *Frame3;
    QLabel *lblFileSize;
    QSpacerItem *Spacer95_3_3_2;
    QLineEdit *edFileSize;
    QSpacerItem *Spacer95_3_3_2_2;
    QLabel *lblFileFormat;
    QLineEdit *edFileFormat;
    QSpacerItem *Spacer95;
    QSpacerItem *Spacer95_2;
    QSpacerItem *Spacer95_3;
    QSpacerItem *Spacer95_3_2;
    QSpacerItem *Spacer95_3_2_2;
    QWidget *tab_compression;
    QGridLayout *gridLayout1;
    QSpacerItem *Spacer95_3_2_3;
    QLabel *lblCompression;
    QHBoxLayout *hboxLayout4;
    KComboBox *cbCompression;
    QSpacerItem *Spacer98_2_2_2_2;
    QSpacerItem *Spacer95_3_2_3_2;
    QLabel *lblCompression_2;
    QSpacerItem *Spacer38_2_2;
    Kwave::CompressionWidget *compressionWidget;
    QWidget *tab_mpeg;
    QGridLayout *gridLayout2;
    QSpacerItem *Spacer95_3_3_3_13_2;
    QSpacerItem *Spacer95_3_3_3_13_2_2_2_2_2;
    QHBoxLayout *hboxLayout5;
    QCheckBox *chkMpegIntensityStereo;
    QCheckBox *chkMpegMSStereo;
    QCheckBox *chkMpegOriginal;
    QLabel *lblMpegVersion;
    QSpacerItem *Spacer95_3_3_3_13_2_2_2_2_4;
    QLabel *lblMpegEmphasis;
    KComboBox *cbMpegModeExt;
    QSpacerItem *Spacer95_3_3_3_13_2_2_2_2_3;
    QSpacerItem *Spacer95_3_3_3_13_2_2_2_2;
    QCheckBox *chkMpegCopyrighted;
    QSpacerItem *Spacer95_3_3_3_13_2_2_2_2_2_2_2;
    QLabel *lblMpegCopyrighted;
    QLabel *lblMpegLayer;
    QSpacerItem *Spacer95_3_3_3_13_2_2;
    QSpacerItem *Spacer42;
    KComboBox *cbMpegEmphasis;
    KComboBox *cbMpegVersion;
    QLabel *lblMpegModeExt;
    KComboBox *cbMpegLayer;
    QLabel *lblMpegOriginal;
    QSpacerItem *Spacer95_3_3_3_13_2_2_2_2_2_2;
    QWidget *tab_content;
    QGridLayout *gridLayout3;
    QLabel *lblName;
    QSpacerItem *Spacer95_3_3_3_11;
    QLineEdit *edName;
    KComboBox *cbGenre;
    QFrame *Frame3_3;
    QSpacerItem *Spacer95_3_3_3_15;
    QLabel *lblGenre;
    QLabel *lblSubject;
    QSpacerItem *Spacer95_3_3_3_10;
    QLineEdit *edSubject;
    QSpacerItem *Spacer95_3_3_3_10_2;
    QLabel *lblVersion;
    QLineEdit *edVersion;
    QSpacerItem *Spacer16;
    QLabel *lblDate;
    QHBoxLayout *hboxLayout6;
    QDateEdit *dateEdit;
    QPushButton *btSelectDate;
    QPushButton *btSelectDateNow;
    QSpacerItem *Spacer35;
    QSpacerItem *Spacer95_3_3_3_4;
    QWidget *tab_source;
    QGridLayout *gridLayout4;
    QLabel *lblCD;
    QLabel *lblSourceForm;
    QLineEdit *edSource;
    QHBoxLayout *hboxLayout7;
    QSpinBox *sbTrack;
    QLabel *label_2;
    QSpinBox *sbTracks;
    QFrame *Frame3_3_2_2;
    QHBoxLayout *hboxLayout8;
    QSpinBox *sbCD;
    QLabel *label_3;
    QSpinBox *sbCDs;
    QSpacerItem *Spacer95_3_3_3_6;
    QLabel *lblAlbum;
    QLabel *lblSource;
    QLabel *lblTrack;
    QLineEdit *edAlbum;
    QSpacerItem *Spacer95_3_3_3_7_3;
    QSpacerItem *Spacer95_3_3_3_7_2;
    QLineEdit *edSourceForm;
    QSpacerItem *Spacer95_3_3_3_7;
    QSpacerItem *Spacer95_3_3_3_7_4;
    QFrame *Frame3_3_2_2_2;
    QSpacerItem *Spacer16_3;
    QLabel *lblSoftware;
    QLabel *lblEngineer;
    QLineEdit *edSoftware;
    QSpacerItem *Spacer95_3_3_3_16;
    QLineEdit *edEngineer;
    QSpacerItem *Spacer95_3_3_3_13;
    QLabel *lblTechnican;
    QLineEdit *edTechnican;
    QSpacerItem *Spacer95_3_3_3_9;
    QWidget *tab_author;
    QGridLayout *gridLayout5;
    QLabel *lblAuthor;
    QLabel *lblOrganization;
    QLineEdit *edAuthor;
    QLabel *lblCopyright;
    QLabel *lblLicense;
    QSpacerItem *Spacer16_2;
    QLineEdit *edOrganization;
    QLineEdit *edCopyright;
    QLineEdit *edLicense;
    QSpacerItem *Spacer95_3_3_3_14_2;
    QSpacerItem *Spacer95_3_3_3_14;
    QFrame *Frame3_3_2_3;
    QLabel *lblContact;
    QLineEdit *edArchival;
    QLineEdit *edContact;
    QLineEdit *edProduct;
    QSpacerItem *Spacer95_3_3_3_8;
    QLabel *lblProduct;
    QLabel *lblArchival;
    QLineEdit *edISRC;
    QLabel *lblISRC;
    QSpacerItem *Spacer95_3_3_3_12_2;
    QSpacerItem *Spacer95_3_3_3_2_2;
    QSpacerItem *Spacer95_3_3_3_3;
    QSpacerItem *Spacer95_3_3_3_3_2;
    QSpacerItem *Spacer95_3_3_3_2;
    QWidget *tab;
    QGridLayout *gridLayout6;
    QFrame *Frame3_3_2;
    QSpacerItem *Spacer95_3_3_3_12;
    QSpacerItem *Spacer95_3_3_3_5;
    Kwave::KeywordWidget *lstKeywords;
    QLabel *lblKeywords;
    QLabel *lblCommissioned;
    QLineEdit *edCommissioned;
    QHBoxLayout *hboxLayout9;
    QDialogButtonBox *btHelp;
    QSpacerItem *Spacer1;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *FileInfoDlg)
    {
        if (FileInfoDlg->objectName().isEmpty())
            FileInfoDlg->setObjectName("FileInfoDlg");
        FileInfoDlg->resize(802, 495);
        FileInfoDlg->setMinimumSize(QSize(540, 300));
        FileInfoDlg->setSizeGripEnabled(true);
        vboxLayout = new QVBoxLayout(FileInfoDlg);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        InfoTab = new QTabWidget(FileInfoDlg);
        InfoTab->setObjectName("InfoTab");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InfoTab->sizePolicy().hasHeightForWidth());
        InfoTab->setSizePolicy(sizePolicy);
        tab_file = new QWidget();
        tab_file->setObjectName("tab_file");
        gridLayout = new QGridLayout(tab_file);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        edFileName = new QLineEdit(tab_file);
        edFileName->setObjectName("edFileName");
        edFileName->setReadOnly(true);

        gridLayout->addWidget(edFileName, 0, 2, 1, 1);

        lblFileName = new QLabel(tab_file);
        lblFileName->setObjectName("lblFileName");
        lblFileName->setWordWrap(false);

        gridLayout->addWidget(lblFileName, 0, 0, 1, 1);

        Spacer95_3_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_3_3, 0, 1, 1, 1);

        Spacer38_2 = new QSpacerItem(0, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(Spacer38_2, 10, 2, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        cbSampleFormat = new KComboBox(tab_file);
        cbSampleFormat->setObjectName("cbSampleFormat");
        cbSampleFormat->setMinimumSize(QSize(100, 0));
        cbSampleFormat->setDuplicatesEnabled(false);

        hboxLayout->addWidget(cbSampleFormat);

        Spacer98_2_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout->addItem(Spacer98_2_2);


        gridLayout->addLayout(hboxLayout, 9, 2, 1, 1);

        lblLength = new QLabel(tab_file);
        lblLength->setObjectName("lblLength");
        lblLength->setWordWrap(false);

        gridLayout->addWidget(lblLength, 7, 0, 1, 1);

        lblChannels = new QLabel(tab_file);
        lblChannels->setObjectName("lblChannels");
        lblChannels->setWordWrap(false);

        gridLayout->addWidget(lblChannels, 6, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(10);
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        sbChannels = new QSpinBox(tab_file);
        sbChannels->setObjectName("sbChannels");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sbChannels->sizePolicy().hasHeightForWidth());
        sbChannels->setSizePolicy(sizePolicy1);
        sbChannels->setMinimumSize(QSize(100, 0));
        sbChannels->setMinimum(1);
        sbChannels->setValue(2);

        hboxLayout1->addWidget(sbChannels);

        lblChannelsVerbose = new QLabel(tab_file);
        lblChannelsVerbose->setObjectName("lblChannelsVerbose");
        lblChannelsVerbose->setWordWrap(false);

        hboxLayout1->addWidget(lblChannelsVerbose);

        Spacer99_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout1->addItem(Spacer99_2);


        gridLayout->addLayout(hboxLayout1, 6, 2, 1, 1);

        lblResolution = new QLabel(tab_file);
        lblResolution->setObjectName("lblResolution");
        lblResolution->setWordWrap(false);

        gridLayout->addWidget(lblResolution, 5, 0, 1, 1);

        lblSampleRate = new QLabel(tab_file);
        lblSampleRate->setObjectName("lblSampleRate");
        lblSampleRate->setWordWrap(false);

        gridLayout->addWidget(lblSampleRate, 4, 0, 1, 1);

        lblSampleFormat = new QLabel(tab_file);
        lblSampleFormat->setObjectName("lblSampleFormat");
        lblSampleFormat->setWordWrap(false);

        gridLayout->addWidget(lblSampleFormat, 9, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(10);
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        sbResolution = new QSpinBox(tab_file);
        sbResolution->setObjectName("sbResolution");
        sbResolution->setMinimumSize(QSize(100, 0));
        sbResolution->setMinimum(8);
        sbResolution->setMaximum(24);
        sbResolution->setSingleStep(8);
        sbResolution->setValue(16);

        hboxLayout2->addWidget(sbResolution);

        lblBits_2 = new QLabel(tab_file);
        lblBits_2->setObjectName("lblBits_2");
        lblBits_2->setWordWrap(false);

        hboxLayout2->addWidget(lblBits_2);

        Spacer100_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout2->addItem(Spacer100_2);


        gridLayout->addLayout(hboxLayout2, 5, 2, 1, 1);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(10);
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        cbSampleRate = new KComboBox(tab_file);
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->setObjectName("cbSampleRate");
        cbSampleRate->setMinimumSize(QSize(100, 0));
        cbSampleRate->setEditable(true);
        cbSampleRate->setDuplicatesEnabled(false);

        hboxLayout3->addWidget(cbSampleRate);

        lblSamplesPerSecond_2 = new QLabel(tab_file);
        lblSamplesPerSecond_2->setObjectName("lblSamplesPerSecond_2");
        lblSamplesPerSecond_2->setWordWrap(false);

        hboxLayout3->addWidget(lblSamplesPerSecond_2);

        Spacer98_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout3->addItem(Spacer98_2);


        gridLayout->addLayout(hboxLayout3, 4, 2, 1, 1);

        Frame3_2 = new QFrame(tab_file);
        Frame3_2->setObjectName("Frame3_2");
        Frame3_2->setMinimumSize(QSize(0, 10));
        Frame3_2->setFrameShape(QFrame::HLine);
        Frame3_2->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(Frame3_2, 8, 0, 1, 3);

        txtLength = new QLineEdit(tab_file);
        txtLength->setObjectName("txtLength");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(txtLength->sizePolicy().hasHeightForWidth());
        txtLength->setSizePolicy(sizePolicy2);
        txtLength->setAlignment(Qt::AlignLeading);
        txtLength->setReadOnly(true);

        gridLayout->addWidget(txtLength, 7, 2, 1, 1);

        Frame3 = new QFrame(tab_file);
        Frame3->setObjectName("Frame3");
        Frame3->setMinimumSize(QSize(0, 10));
        Frame3->setFrameShape(QFrame::HLine);
        Frame3->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(Frame3, 3, 0, 1, 3);

        lblFileSize = new QLabel(tab_file);
        lblFileSize->setObjectName("lblFileSize");
        lblFileSize->setWordWrap(false);

        gridLayout->addWidget(lblFileSize, 1, 0, 1, 1);

        Spacer95_3_3_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_3_3_2, 1, 1, 1, 1);

        edFileSize = new QLineEdit(tab_file);
        edFileSize->setObjectName("edFileSize");
        edFileSize->setReadOnly(true);

        gridLayout->addWidget(edFileSize, 1, 2, 1, 1);

        Spacer95_3_3_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_3_3_2_2, 2, 1, 1, 1);

        lblFileFormat = new QLabel(tab_file);
        lblFileFormat->setObjectName("lblFileFormat");
        lblFileFormat->setWordWrap(false);

        gridLayout->addWidget(lblFileFormat, 2, 0, 1, 1);

        edFileFormat = new QLineEdit(tab_file);
        edFileFormat->setObjectName("edFileFormat");
        edFileFormat->setReadOnly(true);

        gridLayout->addWidget(edFileFormat, 2, 2, 1, 1);

        Spacer95 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95, 4, 1, 1, 1);

        Spacer95_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_2, 5, 1, 1, 1);

        Spacer95_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_3, 6, 1, 1, 1);

        Spacer95_3_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_3_2, 7, 1, 1, 1);

        Spacer95_3_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(Spacer95_3_2_2, 9, 1, 1, 1);

        InfoTab->addTab(tab_file, QString());
        tab_compression = new QWidget();
        tab_compression->setObjectName("tab_compression");
        gridLayout1 = new QGridLayout(tab_compression);
        gridLayout1->setSpacing(10);
        gridLayout1->setContentsMargins(10, 10, 10, 10);
        gridLayout1->setObjectName("gridLayout1");
        Spacer95_3_2_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout1->addItem(Spacer95_3_2_3, 0, 1, 1, 1);

        lblCompression = new QLabel(tab_compression);
        lblCompression->setObjectName("lblCompression");
        lblCompression->setWordWrap(false);

        gridLayout1->addWidget(lblCompression, 0, 0, 1, 1);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(10);
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        hboxLayout4->setObjectName("hboxLayout4");
        cbCompression = new KComboBox(tab_compression);
        cbCompression->setObjectName("cbCompression");
        cbCompression->setMinimumSize(QSize(100, 0));
        cbCompression->setDuplicatesEnabled(false);

        hboxLayout4->addWidget(cbCompression);

        Spacer98_2_2_2_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout4->addItem(Spacer98_2_2_2_2);


        gridLayout1->addLayout(hboxLayout4, 0, 2, 1, 1);

        Spacer95_3_2_3_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout1->addItem(Spacer95_3_2_3_2, 1, 1, 1, 1);

        lblCompression_2 = new QLabel(tab_compression);
        lblCompression_2->setObjectName("lblCompression_2");
        lblCompression_2->setAlignment(Qt::AlignTop);
        lblCompression_2->setWordWrap(false);

        gridLayout1->addWidget(lblCompression_2, 1, 0, 1, 1);

        Spacer38_2_2 = new QSpacerItem(16, 147, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(Spacer38_2_2, 2, 2, 1, 1);

        compressionWidget = new Kwave::CompressionWidget(tab_compression);
        compressionWidget->setObjectName("compressionWidget");
        compressionWidget->setMinimumSize(QSize(0, 160));

        gridLayout1->addWidget(compressionWidget, 1, 2, 1, 1);

        InfoTab->addTab(tab_compression, QString());
        tab_mpeg = new QWidget();
        tab_mpeg->setObjectName("tab_mpeg");
        gridLayout2 = new QGridLayout(tab_mpeg);
        gridLayout2->setSpacing(10);
        gridLayout2->setContentsMargins(10, 10, 10, 10);
        gridLayout2->setObjectName("gridLayout2");
        Spacer95_3_3_3_13_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2, 0, 1, 1, 1);

        Spacer95_3_3_3_13_2_2_2_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2_2_2_2, 4, 1, 1, 1);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(10);
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        hboxLayout5->setObjectName("hboxLayout5");
        chkMpegIntensityStereo = new QCheckBox(tab_mpeg);
        chkMpegIntensityStereo->setObjectName("chkMpegIntensityStereo");

        hboxLayout5->addWidget(chkMpegIntensityStereo);

        chkMpegMSStereo = new QCheckBox(tab_mpeg);
        chkMpegMSStereo->setObjectName("chkMpegMSStereo");

        hboxLayout5->addWidget(chkMpegMSStereo);


        gridLayout2->addLayout(hboxLayout5, 3, 2, 1, 2);

        chkMpegOriginal = new QCheckBox(tab_mpeg);
        chkMpegOriginal->setObjectName("chkMpegOriginal");
        chkMpegOriginal->setChecked(true);

        gridLayout2->addWidget(chkMpegOriginal, 6, 2, 1, 1);

        lblMpegVersion = new QLabel(tab_mpeg);
        lblMpegVersion->setObjectName("lblMpegVersion");
        lblMpegVersion->setWordWrap(false);

        gridLayout2->addWidget(lblMpegVersion, 1, 0, 1, 1);

        Spacer95_3_3_3_13_2_2_2_2_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2_2_2_4, 3, 0, 1, 1);

        lblMpegEmphasis = new QLabel(tab_mpeg);
        lblMpegEmphasis->setObjectName("lblMpegEmphasis");
        lblMpegEmphasis->setWordWrap(false);

        gridLayout2->addWidget(lblMpegEmphasis, 4, 0, 1, 1);

        cbMpegModeExt = new KComboBox(tab_mpeg);
        cbMpegModeExt->addItem(QString());
        cbMpegModeExt->addItem(QString());
        cbMpegModeExt->addItem(QString());
        cbMpegModeExt->addItem(QString());
        cbMpegModeExt->setObjectName("cbMpegModeExt");

        gridLayout2->addWidget(cbMpegModeExt, 2, 2, 1, 2);

        Spacer95_3_3_3_13_2_2_2_2_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2_2_2_3, 3, 1, 1, 1);

        Spacer95_3_3_3_13_2_2_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2_2_2, 2, 1, 1, 1);

        chkMpegCopyrighted = new QCheckBox(tab_mpeg);
        chkMpegCopyrighted->setObjectName("chkMpegCopyrighted");
        chkMpegCopyrighted->setChecked(true);

        gridLayout2->addWidget(chkMpegCopyrighted, 5, 2, 1, 1);

        Spacer95_3_3_3_13_2_2_2_2_2_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2_2_2_2_2_2, 6, 1, 1, 1);

        lblMpegCopyrighted = new QLabel(tab_mpeg);
        lblMpegCopyrighted->setObjectName("lblMpegCopyrighted");
        lblMpegCopyrighted->setWordWrap(false);

        gridLayout2->addWidget(lblMpegCopyrighted, 5, 0, 1, 1);

        lblMpegLayer = new QLabel(tab_mpeg);
        lblMpegLayer->setObjectName("lblMpegLayer");
        lblMpegLayer->setWordWrap(false);

        gridLayout2->addWidget(lblMpegLayer, 0, 0, 1, 1);

        Spacer95_3_3_3_13_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2, 1, 1, 1, 1);

        Spacer42 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout2->addItem(Spacer42, 7, 3, 1, 1);

        cbMpegEmphasis = new KComboBox(tab_mpeg);
        cbMpegEmphasis->addItem(QString());
        cbMpegEmphasis->addItem(QString());
        cbMpegEmphasis->addItem(QString());
        cbMpegEmphasis->setObjectName("cbMpegEmphasis");

        gridLayout2->addWidget(cbMpegEmphasis, 4, 2, 1, 2);

        cbMpegVersion = new KComboBox(tab_mpeg);
        cbMpegVersion->addItem(QString());
        cbMpegVersion->addItem(QString());
        cbMpegVersion->addItem(QString());
        cbMpegVersion->setObjectName("cbMpegVersion");

        gridLayout2->addWidget(cbMpegVersion, 1, 2, 1, 2);

        lblMpegModeExt = new QLabel(tab_mpeg);
        lblMpegModeExt->setObjectName("lblMpegModeExt");
        lblMpegModeExt->setWordWrap(false);

        gridLayout2->addWidget(lblMpegModeExt, 2, 0, 1, 1);

        cbMpegLayer = new KComboBox(tab_mpeg);
        cbMpegLayer->addItem(QString());
        cbMpegLayer->addItem(QString());
        cbMpegLayer->addItem(QString());
        cbMpegLayer->setObjectName("cbMpegLayer");

        gridLayout2->addWidget(cbMpegLayer, 0, 2, 1, 2);

        lblMpegOriginal = new QLabel(tab_mpeg);
        lblMpegOriginal->setObjectName("lblMpegOriginal");
        lblMpegOriginal->setWordWrap(false);

        gridLayout2->addWidget(lblMpegOriginal, 6, 0, 1, 1);

        Spacer95_3_3_3_13_2_2_2_2_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(Spacer95_3_3_3_13_2_2_2_2_2_2, 5, 1, 1, 1);

        InfoTab->addTab(tab_mpeg, QString());
        tab_content = new QWidget();
        tab_content->setObjectName("tab_content");
        gridLayout3 = new QGridLayout(tab_content);
        gridLayout3->setSpacing(10);
        gridLayout3->setContentsMargins(10, 10, 10, 10);
        gridLayout3->setObjectName("gridLayout3");
        lblName = new QLabel(tab_content);
        lblName->setObjectName("lblName");
        lblName->setWordWrap(false);

        gridLayout3->addWidget(lblName, 0, 0, 1, 1);

        Spacer95_3_3_3_11 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout3->addItem(Spacer95_3_3_3_11, 0, 1, 1, 1);

        edName = new QLineEdit(tab_content);
        edName->setObjectName("edName");

        gridLayout3->addWidget(edName, 0, 2, 1, 1);

        cbGenre = new KComboBox(tab_content);
        cbGenre->setObjectName("cbGenre");

        gridLayout3->addWidget(cbGenre, 3, 2, 1, 1);

        Frame3_3 = new QFrame(tab_content);
        Frame3_3->setObjectName("Frame3_3");
        Frame3_3->setMinimumSize(QSize(0, 10));
        Frame3_3->setFrameShape(QFrame::HLine);
        Frame3_3->setFrameShadow(QFrame::Sunken);

        gridLayout3->addWidget(Frame3_3, 4, 0, 1, 3);

        Spacer95_3_3_3_15 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout3->addItem(Spacer95_3_3_3_15, 3, 1, 1, 1);

        lblGenre = new QLabel(tab_content);
        lblGenre->setObjectName("lblGenre");
        lblGenre->setWordWrap(false);

        gridLayout3->addWidget(lblGenre, 3, 0, 1, 1);

        lblSubject = new QLabel(tab_content);
        lblSubject->setObjectName("lblSubject");
        lblSubject->setWordWrap(false);

        gridLayout3->addWidget(lblSubject, 1, 0, 1, 1);

        Spacer95_3_3_3_10 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout3->addItem(Spacer95_3_3_3_10, 1, 1, 1, 1);

        edSubject = new QLineEdit(tab_content);
        edSubject->setObjectName("edSubject");

        gridLayout3->addWidget(edSubject, 1, 2, 1, 1);

        Spacer95_3_3_3_10_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout3->addItem(Spacer95_3_3_3_10_2, 2, 1, 1, 1);

        lblVersion = new QLabel(tab_content);
        lblVersion->setObjectName("lblVersion");
        lblVersion->setWordWrap(false);

        gridLayout3->addWidget(lblVersion, 2, 0, 1, 1);

        edVersion = new QLineEdit(tab_content);
        edVersion->setObjectName("edVersion");

        gridLayout3->addWidget(edVersion, 2, 2, 1, 1);

        Spacer16 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout3->addItem(Spacer16, 10, 2, 1, 1);

        lblDate = new QLabel(tab_content);
        lblDate->setObjectName("lblDate");
        lblDate->setWordWrap(false);

        gridLayout3->addWidget(lblDate, 9, 0, 1, 1);

        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setSpacing(10);
        hboxLayout6->setContentsMargins(0, 0, 0, 0);
        hboxLayout6->setObjectName("hboxLayout6");
        dateEdit = new QDateEdit(tab_content);
        dateEdit->setObjectName("dateEdit");

        hboxLayout6->addWidget(dateEdit);

        btSelectDate = new QPushButton(tab_content);
        btSelectDate->setObjectName("btSelectDate");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(btSelectDate->sizePolicy().hasHeightForWidth());
        btSelectDate->setSizePolicy(sizePolicy3);
        btSelectDate->setAutoDefault(false);
        btSelectDate->setFlat(false);

        hboxLayout6->addWidget(btSelectDate);

        btSelectDateNow = new QPushButton(tab_content);
        btSelectDateNow->setObjectName("btSelectDateNow");
        sizePolicy3.setHeightForWidth(btSelectDateNow->sizePolicy().hasHeightForWidth());
        btSelectDateNow->setSizePolicy(sizePolicy3);
        btSelectDateNow->setAutoDefault(false);
        btSelectDateNow->setFlat(false);

        hboxLayout6->addWidget(btSelectDateNow);

        Spacer35 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout6->addItem(Spacer35);


        gridLayout3->addLayout(hboxLayout6, 9, 2, 1, 1);

        Spacer95_3_3_3_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout3->addItem(Spacer95_3_3_3_4, 9, 1, 1, 1);

        InfoTab->addTab(tab_content, QString());
        tab_source = new QWidget();
        tab_source->setObjectName("tab_source");
        gridLayout4 = new QGridLayout(tab_source);
        gridLayout4->setSpacing(10);
        gridLayout4->setContentsMargins(10, 10, 10, 10);
        gridLayout4->setObjectName("gridLayout4");
        lblCD = new QLabel(tab_source);
        lblCD->setObjectName("lblCD");
        lblCD->setWordWrap(false);

        gridLayout4->addWidget(lblCD, 4, 0, 1, 1);

        lblSourceForm = new QLabel(tab_source);
        lblSourceForm->setObjectName("lblSourceForm");
        lblSourceForm->setWordWrap(false);

        gridLayout4->addWidget(lblSourceForm, 1, 0, 1, 1);

        edSource = new QLineEdit(tab_source);
        edSource->setObjectName("edSource");

        gridLayout4->addWidget(edSource, 0, 2, 1, 1);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setSpacing(0);
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        hboxLayout7->setObjectName("hboxLayout7");
        sbTrack = new QSpinBox(tab_source);
        sbTrack->setObjectName("sbTrack");
        sizePolicy2.setHeightForWidth(sbTrack->sizePolicy().hasHeightForWidth());
        sbTrack->setSizePolicy(sizePolicy2);

        hboxLayout7->addWidget(sbTrack);

        label_2 = new QLabel(tab_source);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy4);

        hboxLayout7->addWidget(label_2);

        sbTracks = new QSpinBox(tab_source);
        sbTracks->setObjectName("sbTracks");
        sizePolicy2.setHeightForWidth(sbTracks->sizePolicy().hasHeightForWidth());
        sbTracks->setSizePolicy(sizePolicy2);

        hboxLayout7->addWidget(sbTracks);


        gridLayout4->addLayout(hboxLayout7, 5, 2, 1, 1);

        Frame3_3_2_2 = new QFrame(tab_source);
        Frame3_3_2_2->setObjectName("Frame3_3_2_2");
        Frame3_3_2_2->setMinimumSize(QSize(0, 10));
        Frame3_3_2_2->setFrameShape(QFrame::HLine);
        Frame3_3_2_2->setFrameShadow(QFrame::Sunken);

        gridLayout4->addWidget(Frame3_3_2_2, 2, 0, 1, 3);

        hboxLayout8 = new QHBoxLayout();
        hboxLayout8->setSpacing(0);
        hboxLayout8->setContentsMargins(0, 0, 0, 0);
        hboxLayout8->setObjectName("hboxLayout8");
        sbCD = new QSpinBox(tab_source);
        sbCD->setObjectName("sbCD");
        sizePolicy2.setHeightForWidth(sbCD->sizePolicy().hasHeightForWidth());
        sbCD->setSizePolicy(sizePolicy2);

        hboxLayout8->addWidget(sbCD);

        label_3 = new QLabel(tab_source);
        label_3->setObjectName("label_3");
        sizePolicy4.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy4);

        hboxLayout8->addWidget(label_3);

        sbCDs = new QSpinBox(tab_source);
        sbCDs->setObjectName("sbCDs");
        sizePolicy2.setHeightForWidth(sbCDs->sizePolicy().hasHeightForWidth());
        sbCDs->setSizePolicy(sizePolicy2);

        hboxLayout8->addWidget(sbCDs);


        gridLayout4->addLayout(hboxLayout8, 4, 2, 1, 1);

        Spacer95_3_3_3_6 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_6, 0, 1, 1, 1);

        lblAlbum = new QLabel(tab_source);
        lblAlbum->setObjectName("lblAlbum");
        lblAlbum->setWordWrap(false);

        gridLayout4->addWidget(lblAlbum, 3, 0, 1, 1);

        lblSource = new QLabel(tab_source);
        lblSource->setObjectName("lblSource");
        lblSource->setWordWrap(false);

        gridLayout4->addWidget(lblSource, 0, 0, 1, 1);

        lblTrack = new QLabel(tab_source);
        lblTrack->setObjectName("lblTrack");
        lblTrack->setWordWrap(false);

        gridLayout4->addWidget(lblTrack, 5, 0, 1, 1);

        edAlbum = new QLineEdit(tab_source);
        edAlbum->setObjectName("edAlbum");

        gridLayout4->addWidget(edAlbum, 3, 2, 1, 1);

        Spacer95_3_3_3_7_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_7_3, 4, 1, 1, 1);

        Spacer95_3_3_3_7_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_7_2, 3, 1, 1, 1);

        edSourceForm = new QLineEdit(tab_source);
        edSourceForm->setObjectName("edSourceForm");

        gridLayout4->addWidget(edSourceForm, 1, 2, 1, 1);

        Spacer95_3_3_3_7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_7, 1, 1, 1, 1);

        Spacer95_3_3_3_7_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_7_4, 5, 1, 1, 1);

        Frame3_3_2_2_2 = new QFrame(tab_source);
        Frame3_3_2_2_2->setObjectName("Frame3_3_2_2_2");
        Frame3_3_2_2_2->setMinimumSize(QSize(0, 10));
        Frame3_3_2_2_2->setFrameShape(QFrame::HLine);
        Frame3_3_2_2_2->setFrameShadow(QFrame::Sunken);

        gridLayout4->addWidget(Frame3_3_2_2_2, 6, 0, 1, 3);

        Spacer16_3 = new QSpacerItem(0, 253, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout4->addItem(Spacer16_3, 10, 2, 1, 1);

        lblSoftware = new QLabel(tab_source);
        lblSoftware->setObjectName("lblSoftware");
        lblSoftware->setWordWrap(false);

        gridLayout4->addWidget(lblSoftware, 7, 0, 1, 1);

        lblEngineer = new QLabel(tab_source);
        lblEngineer->setObjectName("lblEngineer");
        lblEngineer->setWordWrap(false);

        gridLayout4->addWidget(lblEngineer, 8, 0, 1, 1);

        edSoftware = new QLineEdit(tab_source);
        edSoftware->setObjectName("edSoftware");

        gridLayout4->addWidget(edSoftware, 7, 2, 1, 1);

        Spacer95_3_3_3_16 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_16, 9, 1, 1, 1);

        edEngineer = new QLineEdit(tab_source);
        edEngineer->setObjectName("edEngineer");

        gridLayout4->addWidget(edEngineer, 8, 2, 1, 1);

        Spacer95_3_3_3_13 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_13, 7, 1, 1, 1);

        lblTechnican = new QLabel(tab_source);
        lblTechnican->setObjectName("lblTechnican");
        lblTechnican->setWordWrap(false);

        gridLayout4->addWidget(lblTechnican, 9, 0, 1, 1);

        edTechnican = new QLineEdit(tab_source);
        edTechnican->setObjectName("edTechnican");

        gridLayout4->addWidget(edTechnican, 9, 2, 1, 1);

        Spacer95_3_3_3_9 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout4->addItem(Spacer95_3_3_3_9, 8, 1, 1, 1);

        InfoTab->addTab(tab_source, QString());
        tab_author = new QWidget();
        tab_author->setObjectName("tab_author");
        gridLayout5 = new QGridLayout(tab_author);
        gridLayout5->setSpacing(10);
        gridLayout5->setContentsMargins(10, 10, 10, 10);
        gridLayout5->setObjectName("gridLayout5");
        lblAuthor = new QLabel(tab_author);
        lblAuthor->setObjectName("lblAuthor");
        lblAuthor->setWordWrap(false);

        gridLayout5->addWidget(lblAuthor, 0, 0, 1, 1);

        lblOrganization = new QLabel(tab_author);
        lblOrganization->setObjectName("lblOrganization");
        lblOrganization->setWordWrap(false);

        gridLayout5->addWidget(lblOrganization, 1, 0, 1, 1);

        edAuthor = new QLineEdit(tab_author);
        edAuthor->setObjectName("edAuthor");

        gridLayout5->addWidget(edAuthor, 0, 2, 1, 1);

        lblCopyright = new QLabel(tab_author);
        lblCopyright->setObjectName("lblCopyright");
        lblCopyright->setWordWrap(false);

        gridLayout5->addWidget(lblCopyright, 2, 0, 1, 1);

        lblLicense = new QLabel(tab_author);
        lblLicense->setObjectName("lblLicense");
        lblLicense->setWordWrap(false);

        gridLayout5->addWidget(lblLicense, 3, 0, 1, 1);

        Spacer16_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout5->addItem(Spacer16_2, 9, 2, 1, 1);

        edOrganization = new QLineEdit(tab_author);
        edOrganization->setObjectName("edOrganization");

        gridLayout5->addWidget(edOrganization, 1, 2, 1, 1);

        edCopyright = new QLineEdit(tab_author);
        edCopyright->setObjectName("edCopyright");

        gridLayout5->addWidget(edCopyright, 2, 2, 1, 1);

        edLicense = new QLineEdit(tab_author);
        edLicense->setObjectName("edLicense");

        gridLayout5->addWidget(edLicense, 3, 2, 1, 1);

        Spacer95_3_3_3_14_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_14_2, 8, 1, 1, 1);

        Spacer95_3_3_3_14 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_14, 7, 1, 1, 1);

        Frame3_3_2_3 = new QFrame(tab_author);
        Frame3_3_2_3->setObjectName("Frame3_3_2_3");
        Frame3_3_2_3->setMinimumSize(QSize(0, 10));
        Frame3_3_2_3->setFrameShape(QFrame::HLine);
        Frame3_3_2_3->setFrameShadow(QFrame::Sunken);

        gridLayout5->addWidget(Frame3_3_2_3, 5, 0, 1, 3);

        lblContact = new QLabel(tab_author);
        lblContact->setObjectName("lblContact");
        lblContact->setWordWrap(false);

        gridLayout5->addWidget(lblContact, 8, 0, 1, 1);

        edArchival = new QLineEdit(tab_author);
        edArchival->setObjectName("edArchival");

        gridLayout5->addWidget(edArchival, 7, 2, 1, 1);

        edContact = new QLineEdit(tab_author);
        edContact->setObjectName("edContact");

        gridLayout5->addWidget(edContact, 8, 2, 1, 1);

        edProduct = new QLineEdit(tab_author);
        edProduct->setObjectName("edProduct");

        gridLayout5->addWidget(edProduct, 6, 2, 1, 1);

        Spacer95_3_3_3_8 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_8, 6, 1, 1, 1);

        lblProduct = new QLabel(tab_author);
        lblProduct->setObjectName("lblProduct");
        lblProduct->setWordWrap(false);

        gridLayout5->addWidget(lblProduct, 6, 0, 1, 1);

        lblArchival = new QLabel(tab_author);
        lblArchival->setObjectName("lblArchival");
        lblArchival->setWordWrap(false);

        gridLayout5->addWidget(lblArchival, 7, 0, 1, 1);

        edISRC = new QLineEdit(tab_author);
        edISRC->setObjectName("edISRC");
        edISRC->setReadOnly(true);

        gridLayout5->addWidget(edISRC, 4, 2, 1, 1);

        lblISRC = new QLabel(tab_author);
        lblISRC->setObjectName("lblISRC");
        lblISRC->setWordWrap(false);

        gridLayout5->addWidget(lblISRC, 4, 0, 1, 1);

        Spacer95_3_3_3_12_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_12_2, 4, 1, 1, 1);

        Spacer95_3_3_3_2_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_2_2, 3, 1, 1, 1);

        Spacer95_3_3_3_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_3, 2, 1, 1, 1);

        Spacer95_3_3_3_3_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_3_2, 1, 1, 1, 1);

        Spacer95_3_3_3_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout5->addItem(Spacer95_3_3_3_2, 0, 1, 1, 1);

        InfoTab->addTab(tab_author, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout6 = new QGridLayout(tab);
        gridLayout6->setSpacing(10);
        gridLayout6->setContentsMargins(10, 10, 10, 10);
        gridLayout6->setObjectName("gridLayout6");
        Frame3_3_2 = new QFrame(tab);
        Frame3_3_2->setObjectName("Frame3_3_2");
        Frame3_3_2->setMinimumSize(QSize(0, 10));
        Frame3_3_2->setFrameShape(QFrame::HLine);
        Frame3_3_2->setFrameShadow(QFrame::Sunken);

        gridLayout6->addWidget(Frame3_3_2, 1, 0, 1, 3);

        Spacer95_3_3_3_12 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout6->addItem(Spacer95_3_3_3_12, 0, 1, 1, 1);

        Spacer95_3_3_3_5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout6->addItem(Spacer95_3_3_3_5, 2, 1, 1, 1);

        lstKeywords = new Kwave::KeywordWidget(tab);
        lstKeywords->setObjectName("lstKeywords");

        gridLayout6->addWidget(lstKeywords, 2, 2, 1, 1);

        lblKeywords = new QLabel(tab);
        lblKeywords->setObjectName("lblKeywords");
        lblKeywords->setAlignment(Qt::AlignTop);
        lblKeywords->setWordWrap(false);

        gridLayout6->addWidget(lblKeywords, 2, 0, 1, 1);

        lblCommissioned = new QLabel(tab);
        lblCommissioned->setObjectName("lblCommissioned");
        lblCommissioned->setWordWrap(false);

        gridLayout6->addWidget(lblCommissioned, 0, 0, 1, 1);

        edCommissioned = new QLineEdit(tab);
        edCommissioned->setObjectName("edCommissioned");

        gridLayout6->addWidget(edCommissioned, 0, 2, 1, 1);

        InfoTab->addTab(tab, QString());

        vboxLayout->addWidget(InfoTab);

        hboxLayout9 = new QHBoxLayout();
        hboxLayout9->setSpacing(10);
        hboxLayout9->setObjectName("hboxLayout9");
        btHelp = new QDialogButtonBox(FileInfoDlg);
        btHelp->setObjectName("btHelp");
        btHelp->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout9->addWidget(btHelp);

        Spacer1 = new QSpacerItem(500, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout9->addItem(Spacer1);

        buttonBox = new QDialogButtonBox(FileInfoDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout9->addWidget(buttonBox);


        vboxLayout->addLayout(hboxLayout9);

        QWidget::setTabOrder(InfoTab, edFileName);
        QWidget::setTabOrder(edFileName, edFileSize);
        QWidget::setTabOrder(edFileSize, edFileFormat);
        QWidget::setTabOrder(edFileFormat, cbSampleRate);
        QWidget::setTabOrder(cbSampleRate, sbResolution);
        QWidget::setTabOrder(sbResolution, sbChannels);
        QWidget::setTabOrder(sbChannels, txtLength);
        QWidget::setTabOrder(txtLength, cbSampleFormat);
        QWidget::setTabOrder(cbSampleFormat, cbCompression);
        QWidget::setTabOrder(cbCompression, cbMpegLayer);
        QWidget::setTabOrder(cbMpegLayer, cbMpegVersion);
        QWidget::setTabOrder(cbMpegVersion, cbMpegModeExt);
        QWidget::setTabOrder(cbMpegModeExt, chkMpegIntensityStereo);
        QWidget::setTabOrder(chkMpegIntensityStereo, chkMpegMSStereo);
        QWidget::setTabOrder(chkMpegMSStereo, cbMpegEmphasis);
        QWidget::setTabOrder(cbMpegEmphasis, chkMpegCopyrighted);
        QWidget::setTabOrder(chkMpegCopyrighted, chkMpegOriginal);
        QWidget::setTabOrder(chkMpegOriginal, edName);
        QWidget::setTabOrder(edName, edSubject);
        QWidget::setTabOrder(edSubject, edVersion);
        QWidget::setTabOrder(edVersion, cbGenre);
        QWidget::setTabOrder(cbGenre, dateEdit);
        QWidget::setTabOrder(dateEdit, btSelectDate);
        QWidget::setTabOrder(btSelectDate, btSelectDateNow);
        QWidget::setTabOrder(btSelectDateNow, edSource);
        QWidget::setTabOrder(edSource, edSourceForm);
        QWidget::setTabOrder(edSourceForm, edAlbum);
        QWidget::setTabOrder(edAlbum, sbCD);
        QWidget::setTabOrder(sbCD, sbCDs);
        QWidget::setTabOrder(sbCDs, sbTrack);
        QWidget::setTabOrder(sbTrack, sbTracks);
        QWidget::setTabOrder(sbTracks, edSoftware);
        QWidget::setTabOrder(edSoftware, edEngineer);
        QWidget::setTabOrder(edEngineer, edTechnican);
        QWidget::setTabOrder(edTechnican, edAuthor);
        QWidget::setTabOrder(edAuthor, edOrganization);
        QWidget::setTabOrder(edOrganization, edCopyright);
        QWidget::setTabOrder(edCopyright, edLicense);
        QWidget::setTabOrder(edLicense, edISRC);
        QWidget::setTabOrder(edISRC, edProduct);
        QWidget::setTabOrder(edProduct, edArchival);
        QWidget::setTabOrder(edArchival, edContact);
        QWidget::setTabOrder(edContact, edCommissioned);

        retranslateUi(FileInfoDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, FileInfoDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, FileInfoDlg, qOverload<>(&QDialog::reject));

        InfoTab->setCurrentIndex(0);
        cbSampleRate->setCurrentIndex(7);


        QMetaObject::connectSlotsByName(FileInfoDlg);
    } // setupUi

    void retranslateUi(QDialog *FileInfoDlg)
    {
        FileInfoDlg->setWindowTitle(tr2i18n("File Info", nullptr));
        lblFileName->setText(tr2i18n("#", nullptr));
        lblLength->setText(tr2i18n("#", nullptr));
        lblChannels->setText(tr2i18n("#", nullptr));
        lblChannelsVerbose->setText(tr2i18n("%1", nullptr));
        lblResolution->setText(tr2i18n("#", nullptr));
        lblSampleRate->setText(tr2i18n("#", nullptr));
        lblSampleFormat->setText(tr2i18n("#", nullptr));
        lblBits_2->setText(tr2i18n("bit", nullptr));
        cbSampleRate->setItemText(0, tr2i18n("8000", nullptr));
        cbSampleRate->setItemText(1, tr2i18n("10000", nullptr));
        cbSampleRate->setItemText(2, tr2i18n("11025", nullptr));
        cbSampleRate->setItemText(3, tr2i18n("12000", nullptr));
        cbSampleRate->setItemText(4, tr2i18n("16000", nullptr));
        cbSampleRate->setItemText(5, tr2i18n("22050", nullptr));
        cbSampleRate->setItemText(6, tr2i18n("32000", nullptr));
        cbSampleRate->setItemText(7, tr2i18n("44100", nullptr));
        cbSampleRate->setItemText(8, tr2i18n("48000", nullptr));
        cbSampleRate->setItemText(9, tr2i18n("96000", nullptr));

        lblSamplesPerSecond_2->setText(tr2i18n("samples per second", nullptr));
        lblFileSize->setText(tr2i18n("#", nullptr));
        lblFileFormat->setText(tr2i18n("#", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab_file), tr2i18n("File", nullptr));
        lblCompression->setText(tr2i18n("#", nullptr));
        lblCompression_2->setText(tr2i18n("Encoding Mode:", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab_compression), tr2i18n("Compression", nullptr));
        chkMpegIntensityStereo->setText(tr2i18n("Intensity Stereo", nullptr));
        chkMpegMSStereo->setText(tr2i18n("MS Stereo", nullptr));
        chkMpegOriginal->setText(tr2i18n("yes", nullptr));
        lblMpegVersion->setText(tr2i18n("#", nullptr));
        lblMpegEmphasis->setText(tr2i18n("#", nullptr));
        cbMpegModeExt->setItemText(0, tr2i18n("Bands 4 to 31", nullptr));
        cbMpegModeExt->setItemText(1, tr2i18n("Bands 8 to 31", nullptr));
        cbMpegModeExt->setItemText(2, tr2i18n("Bands 12 to 31", nullptr));
        cbMpegModeExt->setItemText(3, tr2i18n("Bands 16 to 31", nullptr));

        chkMpegCopyrighted->setText(tr2i18n("yes", nullptr));
        lblMpegCopyrighted->setText(tr2i18n("#", nullptr));
        lblMpegLayer->setText(tr2i18n("#", nullptr));
        cbMpegEmphasis->setItemText(0, tr2i18n("None", nullptr));
        cbMpegEmphasis->setItemText(1, tr2i18n("50/15ms", nullptr));
        cbMpegEmphasis->setItemText(2, tr2i18n("CCIT J.17", nullptr));

        cbMpegVersion->setItemText(0, tr2i18n("MPEG Version 1 (ISO/IEC 11172-3)", nullptr));
        cbMpegVersion->setItemText(1, tr2i18n("MPEG Version 2 (ISO/IEC 13818-3)", nullptr));
        cbMpegVersion->setItemText(2, tr2i18n("MPEG Version 2.5 (unofficial)", nullptr));

        lblMpegModeExt->setText(tr2i18n("#", nullptr));
        cbMpegLayer->setItemText(0, tr2i18n("Layer I", nullptr));
        cbMpegLayer->setItemText(1, tr2i18n("Layer II", nullptr));
        cbMpegLayer->setItemText(2, tr2i18n("Layer III", nullptr));

        lblMpegOriginal->setText(tr2i18n("#", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab_mpeg), tr2i18n("MPEG", nullptr));
        lblName->setText(tr2i18n("#", nullptr));
        lblGenre->setText(tr2i18n("#", nullptr));
        lblSubject->setText(tr2i18n("#", nullptr));
        lblVersion->setText(tr2i18n("#", nullptr));
        lblDate->setText(tr2i18n("#", nullptr));
#if QT_CONFIG(tooltip)
        btSelectDate->setToolTip(tr2i18n("Select a date from the calendar.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btSelectDate->setWhatsThis(tr2i18n("Opens a dialog for selecting a date from the calendar.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btSelectDate->setText(tr2i18n("&Select...", nullptr));
#if QT_CONFIG(tooltip)
        btSelectDateNow->setToolTip(tr2i18n("Set the date to today.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btSelectDateNow->setWhatsThis(tr2i18n("Set the date to today.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btSelectDateNow->setText(tr2i18n("&Today", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab_content), tr2i18n("Content", nullptr));
        lblCD->setText(tr2i18n("#", nullptr));
        lblSourceForm->setText(tr2i18n("#", nullptr));
        label_2->setText(tr2i18n(" / ", nullptr));
        label_3->setText(tr2i18n(" / ", nullptr));
        lblAlbum->setText(tr2i18n("#", nullptr));
        lblSource->setText(tr2i18n("#", nullptr));
        lblTrack->setText(tr2i18n("#", nullptr));
        lblSoftware->setText(tr2i18n("#", nullptr));
        lblEngineer->setText(tr2i18n("#", nullptr));
        lblTechnican->setText(tr2i18n("#", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab_source), tr2i18n("Source", nullptr));
        lblAuthor->setText(tr2i18n("#", nullptr));
        lblOrganization->setText(tr2i18n("#", nullptr));
        lblCopyright->setText(tr2i18n("#", nullptr));
        lblLicense->setText(tr2i18n("#", nullptr));
        lblContact->setText(tr2i18n("#", nullptr));
        lblProduct->setText(tr2i18n("#", nullptr));
        lblArchival->setText(tr2i18n("#", nullptr));
        lblISRC->setText(tr2i18n("#", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab_author), tr2i18n("Author/Copyright", nullptr));
        lblKeywords->setText(tr2i18n("#", nullptr));
        lblCommissioned->setText(tr2i18n("#", nullptr));
        InfoTab->setTabText(InfoTab->indexOf(tab), tr2i18n("Miscellaneous", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FileInfoDlg: public Ui_FileInfoDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILEINFODLG_H

