/****************************************************************************
** Meta object code from reading C++ file 'OverViewWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/libgui/OverViewWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OverViewWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave14OverViewWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::OverViewWidget::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave14OverViewWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::OverViewWidget",
        "valueChanged",
        "",
        "sample_index_t",
        "new_value",
        "sigCommand",
        "command",
        "newImage",
        "QImage",
        "image",
        "setRange",
        "offset",
        "viewport",
        "total",
        "setSelection",
        "length",
        "metaDataChanged",
        "Kwave::MetaDataList",
        "meta",
        "showCursor",
        "pos",
        "refreshBitmap",
        "overviewChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(sample_index_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigCommand'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'newImage'
        QtMocHelpers::SignalData<void(QImage)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setRange'
        QtMocHelpers::SlotData<void(sample_index_t, sample_index_t, sample_index_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 3, 12 }, { 0x80000000 | 3, 13 },
        }}),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<void(sample_index_t, sample_index_t)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 3, 15 },
        }}),
        // Slot 'metaDataChanged'
        QtMocHelpers::SlotData<void(Kwave::MetaDataList)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'showCursor'
        QtMocHelpers::SlotData<void(sample_index_t)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 20 },
        }}),
        // Slot 'showCursor'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'refreshBitmap'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'overviewChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OverViewWidget, qt_meta_tag_ZN5Kwave14OverViewWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::OverViewWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<Kwave::ImageView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14OverViewWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14OverViewWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave14OverViewWidgetE_t>.metaTypes,
    nullptr
} };

void Kwave::OverViewWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OverViewWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 1: _t->sigCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newImage((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 3: _t->setRange((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 4: _t->setSelection((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2]))); break;
        case 5: _t->metaDataChanged((*reinterpret_cast<std::add_pointer_t<Kwave::MetaDataList>>(_a[1]))); break;
        case 6: _t->showCursor((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 7: _t->showCursor(); break;
        case 8: _t->refreshBitmap(); break;
        case 9: _t->overviewChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OverViewWidget::*)(sample_index_t )>(_a, &OverViewWidget::valueChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OverViewWidget::*)(const QString & )>(_a, &OverViewWidget::sigCommand, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OverViewWidget::*)(QImage )>(_a, &OverViewWidget::newImage, 2))
            return;
    }
}

const QMetaObject *Kwave::OverViewWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::OverViewWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14OverViewWidgetE_t>.strings))
        return static_cast<void*>(this);
    return Kwave::ImageView::qt_metacast(_clname);
}

int Kwave::OverViewWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kwave::ImageView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Kwave::OverViewWidget::valueChanged(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::OverViewWidget::sigCommand(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kwave::OverViewWidget::newImage(QImage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
