/****************************************************************************
** Meta object code from reading C++ file 'SonagramWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwave-26.04.3/plugins/sonagram/SonagramWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SonagramWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave14SonagramWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::SonagramWindow::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave14SonagramWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::SonagramWindow",
        "close",
        "",
        "save",
        "load",
        "toSignal",
        "setName",
        "name",
        "setColorMode",
        "mode",
        "cursorPosChanged",
        "QPoint",
        "pos",
        "setPoints",
        "points",
        "setRate",
        "rate",
        "refresh_view"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toSignal'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'setColorMode'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'cursorPosChanged'
        QtMocHelpers::SlotData<void(const QPoint)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setPoints'
        QtMocHelpers::SlotData<void(unsigned int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Slot 'setRate'
        QtMocHelpers::SlotData<void(double)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'refresh_view'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SonagramWindow, qt_meta_tag_ZN5Kwave14SonagramWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::SonagramWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14SonagramWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14SonagramWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave14SonagramWindowE_t>.metaTypes,
    nullptr
} };

void Kwave::SonagramWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SonagramWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->close(); break;
        case 1: _t->save(); break;
        case 2: _t->load(); break;
        case 3: _t->toSignal(); break;
        case 4: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setColorMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->cursorPosChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 7: _t->setPoints((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: _t->setRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: _t->refresh_view(); break;
        default: ;
        }
    }
}

const QMetaObject *Kwave::SonagramWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::SonagramWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave14SonagramWindowE_t>.strings))
        return static_cast<void*>(this);
    return KMainWindow::qt_metacast(_clname);
}

int Kwave::SonagramWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
