/********************************************************************************
** Form generated from reading UI file 'AboutDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDIALOGBASE_H
#define UI_ABOUTDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kurllabel.h>
#include "KTextEdit"
#include "LogoWidget.h"

QT_BEGIN_NAMESPACE

class Ui_AboutDialogBase
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *header;
    QTabWidget *tabwidget;
    QWidget *about_tab;
    QGridLayout *gridLayout;
    QFrame *logoframe;
    QVBoxLayout *vboxLayout1;
    Kwave::LogoWidget *logo_widget;
    QLabel *kwave_url_label;
    QLabel *abouttext;
    QWidget *authors_tab;
    QVBoxLayout *vboxLayout2;
    QScrollArea *authorframe;
    QWidget *thanks_tab;
    QVBoxLayout *vboxLayout3;
    QScrollArea *thanksframe;
    QWidget *plugins_tab;
    QVBoxLayout *vboxLayout4;
    QLabel *pluginsnumval;
    QScrollArea *pluginsinfoframe;
    QWidget *translations_tab;
    QVBoxLayout *verticalLayout;
    QScrollArea *translatorsframe;
    QWidget *license_tab;
    QVBoxLayout *vboxLayout5;
    KTextEdit *licenseframe;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;
    QSpacerItem *spacerItem1;

    void setupUi(QDialog *AboutDialogBase)
    {
        if (AboutDialogBase->objectName().isEmpty())
            AboutDialogBase->setObjectName("AboutDialogBase");
        AboutDialogBase->resize(734, 586);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AboutDialogBase->sizePolicy().hasHeightForWidth());
        AboutDialogBase->setSizePolicy(sizePolicy);
        AboutDialogBase->setSizeGripEnabled(true);
        vboxLayout = new QVBoxLayout(AboutDialogBase);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        header = new QLabel(AboutDialogBase);
        header->setObjectName("header");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(header->sizePolicy().hasHeightForWidth());
        header->setSizePolicy(sizePolicy1);
        header->setFrameShape(QFrame::NoFrame);
        header->setWordWrap(false);

        vboxLayout->addWidget(header);

        tabwidget = new QTabWidget(AboutDialogBase);
        tabwidget->setObjectName("tabwidget");
        about_tab = new QWidget();
        about_tab->setObjectName("about_tab");
        gridLayout = new QGridLayout(about_tab);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        logoframe = new QFrame(about_tab);
        logoframe->setObjectName("logoframe");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(35);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(logoframe->sizePolicy().hasHeightForWidth());
        logoframe->setSizePolicy(sizePolicy2);
        logoframe->setMinimumSize(QSize(150, 200));
        logoframe->setMaximumSize(QSize(400, 32767));
        logoframe->setFrameShape(QFrame::NoFrame);
        logoframe->setFrameShadow(QFrame::Plain);
        vboxLayout1 = new QVBoxLayout(logoframe);
        vboxLayout1->setSpacing(3);
        vboxLayout1->setContentsMargins(10, 10, 10, 10);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(3, 3, 3, 3);
        logo_widget = new Kwave::LogoWidget(logoframe);
        logo_widget->setObjectName("logo_widget");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(logo_widget->sizePolicy().hasHeightForWidth());
        logo_widget->setSizePolicy(sizePolicy3);
        logo_widget->setMaximumSize(QSize(400, 32767));

        vboxLayout1->addWidget(logo_widget);


        gridLayout->addWidget(logoframe, 0, 0, 2, 1);

        kwave_url_label = new QLabel(about_tab);
        kwave_url_label->setObjectName("kwave_url_label");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kwave_url_label->sizePolicy().hasHeightForWidth());
        kwave_url_label->setSizePolicy(sizePolicy4);
        kwave_url_label->setMinimumSize(QSize(200, 20));

        gridLayout->addWidget(kwave_url_label, 1, 1, 1, 1);

        abouttext = new QLabel(about_tab);
        abouttext->setObjectName("abouttext");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy5.setHorizontalStretch(100);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(abouttext->sizePolicy().hasHeightForWidth());
        abouttext->setSizePolicy(sizePolicy5);
        abouttext->setMinimumSize(QSize(380, 280));
        abouttext->setTextFormat(Qt::RichText);
        abouttext->setScaledContents(false);
        abouttext->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        abouttext->setWordWrap(true);

        gridLayout->addWidget(abouttext, 0, 1, 1, 1);

        tabwidget->addTab(about_tab, QString());
        authors_tab = new QWidget();
        authors_tab->setObjectName("authors_tab");
        vboxLayout2 = new QVBoxLayout(authors_tab);
        vboxLayout2->setSpacing(10);
        vboxLayout2->setContentsMargins(10, 10, 10, 10);
        vboxLayout2->setObjectName("vboxLayout2");
        authorframe = new QScrollArea(authors_tab);
        authorframe->setObjectName("authorframe");
        sizePolicy3.setHeightForWidth(authorframe->sizePolicy().hasHeightForWidth());
        authorframe->setSizePolicy(sizePolicy3);

        vboxLayout2->addWidget(authorframe);

        tabwidget->addTab(authors_tab, QString());
        thanks_tab = new QWidget();
        thanks_tab->setObjectName("thanks_tab");
        vboxLayout3 = new QVBoxLayout(thanks_tab);
        vboxLayout3->setSpacing(10);
        vboxLayout3->setContentsMargins(10, 10, 10, 10);
        vboxLayout3->setObjectName("vboxLayout3");
        thanksframe = new QScrollArea(thanks_tab);
        thanksframe->setObjectName("thanksframe");
        sizePolicy3.setHeightForWidth(thanksframe->sizePolicy().hasHeightForWidth());
        thanksframe->setSizePolicy(sizePolicy3);

        vboxLayout3->addWidget(thanksframe);

        tabwidget->addTab(thanks_tab, QString());
        plugins_tab = new QWidget();
        plugins_tab->setObjectName("plugins_tab");
        vboxLayout4 = new QVBoxLayout(plugins_tab);
        vboxLayout4->setSpacing(10);
        vboxLayout4->setContentsMargins(10, 10, 10, 10);
        vboxLayout4->setObjectName("vboxLayout4");
        pluginsnumval = new QLabel(plugins_tab);
        pluginsnumval->setObjectName("pluginsnumval");
        pluginsnumval->setWordWrap(false);

        vboxLayout4->addWidget(pluginsnumval);

        pluginsinfoframe = new QScrollArea(plugins_tab);
        pluginsinfoframe->setObjectName("pluginsinfoframe");
        sizePolicy3.setHeightForWidth(pluginsinfoframe->sizePolicy().hasHeightForWidth());
        pluginsinfoframe->setSizePolicy(sizePolicy3);

        vboxLayout4->addWidget(pluginsinfoframe);

        tabwidget->addTab(plugins_tab, QString());
        translations_tab = new QWidget();
        translations_tab->setObjectName("translations_tab");
        verticalLayout = new QVBoxLayout(translations_tab);
        verticalLayout->setSpacing(10);
        verticalLayout->setContentsMargins(10, 10, 10, 10);
        verticalLayout->setObjectName("verticalLayout");
        translatorsframe = new QScrollArea(translations_tab);
        translatorsframe->setObjectName("translatorsframe");
        sizePolicy3.setHeightForWidth(translatorsframe->sizePolicy().hasHeightForWidth());
        translatorsframe->setSizePolicy(sizePolicy3);

        verticalLayout->addWidget(translatorsframe);

        tabwidget->addTab(translations_tab, QString());
        license_tab = new QWidget();
        license_tab->setObjectName("license_tab");
        vboxLayout5 = new QVBoxLayout(license_tab);
        vboxLayout5->setSpacing(10);
        vboxLayout5->setContentsMargins(10, 10, 10, 10);
        vboxLayout5->setObjectName("vboxLayout5");
        licenseframe = new KTextEdit(license_tab);
        licenseframe->setObjectName("licenseframe");

        vboxLayout5->addWidget(licenseframe);

        tabwidget->addTab(license_tab, QString());

        vboxLayout->addWidget(tabwidget);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(AboutDialogBase);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy6);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);
        buttonBox->setCenterButtons(true);

        hboxLayout->addWidget(buttonBox);

        spacerItem1 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(AboutDialogBase);
        QObject::connect(buttonBox, &QDialogButtonBox::clicked, AboutDialogBase, qOverload<>(&QDialog::accept));

        tabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AboutDialogBase);
    } // setupUi

    void retranslateUi(QDialog *AboutDialogBase)
    {
        AboutDialogBase->setWindowTitle(tr2i18n("About Kwave", nullptr));
        header->setText(tr2i18n("<h1>Kwave - a sound editor by KDE</h1>", nullptr));
        abouttext->setText(tr2i18n("<html><head/><body><p><span style=\" font-size:x-large; font-weight:600;\">Kwave is a sound editor based on KDE Frameworks. </span></p><p><br/>With Kwave you can edit many sorts of audio files including multi track files. You are able to alter and play back each track on its own.<br/>Kwave also includes many plugins  to transform the audio data in several ways and presents a graphical view with a complete zoom and scroll capability.</p></body></html>", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(about_tab), tr2i18n("About", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(authors_tab), tr2i18n("Authors", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(thanks_tab), tr2i18n("Thanks To", nullptr));
        pluginsnumval->setText(QString());
        tabwidget->setTabText(tabwidget->indexOf(plugins_tab), tr2i18n("Plugins info", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(translations_tab), tr2i18n("Translation", nullptr));
        tabwidget->setTabText(tabwidget->indexOf(license_tab), tr2i18n("License agreement", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutDialogBase: public Ui_AboutDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ABOUTDIALOGBASE_H

