/********************************************************************************
** Form generated from reading UI file 'CompressionWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPRESSIONWIDGETBASE_H
#define UI_COMPRESSIONWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "BitrateWidget.h"

QT_BEGIN_NAMESPACE

class Ui_CompressionWidgetBase
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *ButtonGroup;
    QGridLayout *gridLayout;
    QRadioButton *rbABR;
    QFrame *Line1;
    QCheckBox *chkLowestBitrate;
    QRadioButton *rbVBR;
    QCheckBox *chkHighestBitrate;
    QLabel *lblCompressionNominalBitrate;
    Kwave::BitrateWidget *abrBitrate;
    Kwave::BitrateWidget *abrHighestBitrate;
    Kwave::BitrateWidget *abrLowestBitrate;
    QHBoxLayout *hboxLayout;
    QSpinBox *sbBaseQuality;
    QSlider *slBaseQuality;
    QLabel *lblCompressionBaseQuality;

    void setupUi(QWidget *CompressionWidgetBase)
    {
        if (CompressionWidgetBase->objectName().isEmpty())
            CompressionWidgetBase->setObjectName("CompressionWidgetBase");
        CompressionWidgetBase->resize(398, 191);
        vboxLayout = new QVBoxLayout(CompressionWidgetBase);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        ButtonGroup = new QGroupBox(CompressionWidgetBase);
        ButtonGroup->setObjectName("ButtonGroup");
        gridLayout = new QGridLayout(ButtonGroup);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        rbABR = new QRadioButton(ButtonGroup);
        rbABR->setObjectName("rbABR");
        rbABR->setChecked(true);

        gridLayout->addWidget(rbABR, 0, 0, 1, 1);

        Line1 = new QFrame(ButtonGroup);
        Line1->setObjectName("Line1");
        Line1->setFrameShape(QFrame::HLine);
        Line1->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(Line1, 3, 1, 1, 2);

        chkLowestBitrate = new QCheckBox(ButtonGroup);
        chkLowestBitrate->setObjectName("chkLowestBitrate");
        chkLowestBitrate->setEnabled(false);

        gridLayout->addWidget(chkLowestBitrate, 2, 1, 1, 1);

        rbVBR = new QRadioButton(ButtonGroup);
        rbVBR->setObjectName("rbVBR");

        gridLayout->addWidget(rbVBR, 4, 0, 1, 1);

        chkHighestBitrate = new QCheckBox(ButtonGroup);
        chkHighestBitrate->setObjectName("chkHighestBitrate");
        chkHighestBitrate->setEnabled(false);

        gridLayout->addWidget(chkHighestBitrate, 1, 1, 1, 1);

        lblCompressionNominalBitrate = new QLabel(ButtonGroup);
        lblCompressionNominalBitrate->setObjectName("lblCompressionNominalBitrate");
        lblCompressionNominalBitrate->setEnabled(false);
        lblCompressionNominalBitrate->setWordWrap(false);

        gridLayout->addWidget(lblCompressionNominalBitrate, 0, 1, 1, 1);

        abrBitrate = new Kwave::BitrateWidget(ButtonGroup);
        abrBitrate->setObjectName("abrBitrate");
        abrBitrate->setEnabled(false);
        abrBitrate->setMinimumSize(QSize(0, 20));

        gridLayout->addWidget(abrBitrate, 0, 2, 1, 1);

        abrHighestBitrate = new Kwave::BitrateWidget(ButtonGroup);
        abrHighestBitrate->setObjectName("abrHighestBitrate");
        abrHighestBitrate->setEnabled(false);
        abrHighestBitrate->setMinimumSize(QSize(0, 20));

        gridLayout->addWidget(abrHighestBitrate, 1, 2, 1, 1);

        abrLowestBitrate = new Kwave::BitrateWidget(ButtonGroup);
        abrLowestBitrate->setObjectName("abrLowestBitrate");
        abrLowestBitrate->setEnabled(false);
        abrLowestBitrate->setMinimumSize(QSize(0, 20));

        gridLayout->addWidget(abrLowestBitrate, 2, 2, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setObjectName("hboxLayout");
        sbBaseQuality = new QSpinBox(ButtonGroup);
        sbBaseQuality->setObjectName("sbBaseQuality");
        sbBaseQuality->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sbBaseQuality->sizePolicy().hasHeightForWidth());
        sbBaseQuality->setSizePolicy(sizePolicy);
        sbBaseQuality->setMinimumSize(QSize(40, 20));
        sbBaseQuality->setValue(0);
        sbBaseQuality->setProperty("base", QVariant(10));
        sbBaseQuality->setProperty("maxValue", QVariant(100));
        sbBaseQuality->setProperty("minValue", QVariant(0));
        sbBaseQuality->setProperty("lineStep", QVariant(10));

        hboxLayout->addWidget(sbBaseQuality);

        slBaseQuality = new QSlider(ButtonGroup);
        slBaseQuality->setObjectName("slBaseQuality");
        slBaseQuality->setEnabled(false);
        slBaseQuality->setMinimum(0);
        slBaseQuality->setMaximum(100);
        slBaseQuality->setSingleStep(10);
        slBaseQuality->setPageStep(20);
        slBaseQuality->setValue(0);
        slBaseQuality->setOrientation(Qt::Horizontal);

        hboxLayout->addWidget(slBaseQuality);


        gridLayout->addLayout(hboxLayout, 4, 2, 1, 1);

        lblCompressionBaseQuality = new QLabel(ButtonGroup);
        lblCompressionBaseQuality->setObjectName("lblCompressionBaseQuality");
        lblCompressionBaseQuality->setEnabled(false);
        lblCompressionBaseQuality->setWordWrap(false);

        gridLayout->addWidget(lblCompressionBaseQuality, 4, 1, 1, 1);


        vboxLayout->addWidget(ButtonGroup);


        retranslateUi(CompressionWidgetBase);
        QObject::connect(rbVBR, &QRadioButton::toggled, lblCompressionBaseQuality, &QLabel::setEnabled);
        QObject::connect(rbVBR, &QRadioButton::toggled, sbBaseQuality, &QSpinBox::setEnabled);
        QObject::connect(rbVBR, &QRadioButton::toggled, slBaseQuality, &QSlider::setEnabled);
        QObject::connect(sbBaseQuality, &QSpinBox::valueChanged, slBaseQuality, &QSlider::setValue);
        QObject::connect(slBaseQuality, &QSlider::valueChanged, sbBaseQuality, &QSpinBox::setValue);
        QObject::connect(rbABR, &QRadioButton::toggled, lblCompressionNominalBitrate, &QLabel::setEnabled);
        QObject::connect(rbABR, SIGNAL(toggled(bool)), abrBitrate, SLOT(setEnabled(bool)));
        QObject::connect(rbABR, &QRadioButton::toggled, chkHighestBitrate, &QCheckBox::setEnabled);
        QObject::connect(rbABR, &QRadioButton::toggled, chkLowestBitrate, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(CompressionWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *CompressionWidgetBase)
    {
        ButtonGroup->setTitle(QString());
#if QT_CONFIG(tooltip)
        rbABR->setToolTip(tr2i18n("Average Bitrate Mode", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbABR->setWhatsThis(tr2i18n("<b>Average Bitrate Mode</b><br>\n"
"Bitrate is set to an average value,\n"
"with optional upper and lower limit.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbABR->setText(tr2i18n("ABR:", nullptr));
        chkLowestBitrate->setText(tr2i18n("lowest", nullptr));
#if QT_CONFIG(tooltip)
        rbVBR->setToolTip(tr2i18n("Variable Bitrate Mode", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbVBR->setWhatsThis(tr2i18n("<b>Variable Bitrate Mode</b><br>\n"
"The bitrate is selected by an average quality.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbVBR->setText(tr2i18n("VBR:", nullptr));
        chkHighestBitrate->setText(tr2i18n("highest", nullptr));
        lblCompressionNominalBitrate->setText(tr2i18n("Nominal Bitrate", nullptr));
        sbBaseQuality->setSpecialValueText(tr2i18n("lowest", nullptr));
        sbBaseQuality->setSuffix(tr2i18n(" %", nullptr));
        lblCompressionBaseQuality->setText(tr2i18n("Base Quality", nullptr));
        (void)CompressionWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class CompressionWidgetBase: public Ui_CompressionWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPRESSIONWIDGETBASE_H

