/********************************************************************************
** Form generated from reading UI file 'SelectRangeDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTRANGEDLG_H
#define UI_SELECTRANGEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "libgui/SelectTimeWidget.h"

QT_BEGIN_NAMESPACE

class Ui_SelectRangeDlg
{
public:
    QGridLayout *gridLayout;
    Kwave::SelectTimeWidget *select_start;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *btHelp;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;
    Kwave::SelectTimeWidget *select_range;

    void setupUi(QDialog *SelectRangeDlg)
    {
        if (SelectRangeDlg->objectName().isEmpty())
            SelectRangeDlg->setObjectName("SelectRangeDlg");
        SelectRangeDlg->resize(340, 272);
        gridLayout = new QGridLayout(SelectRangeDlg);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        select_start = new Kwave::SelectTimeWidget(SelectRangeDlg);
        select_start->setObjectName("select_start");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(select_start->sizePolicy().hasHeightForWidth());
        select_start->setSizePolicy(sizePolicy);
        select_start->setMinimumSize(QSize(200, 100));

        gridLayout->addWidget(select_start, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        btHelp = new QDialogButtonBox(SelectRangeDlg);
        btHelp->setObjectName("btHelp");
        btHelp->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout->addWidget(btHelp);

        spacerItem = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(SelectRangeDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 1);

        select_range = new Kwave::SelectTimeWidget(SelectRangeDlg);
        select_range->setObjectName("select_range");
        sizePolicy.setHeightForWidth(select_range->sizePolicy().hasHeightForWidth());
        select_range->setSizePolicy(sizePolicy);
        select_range->setMinimumSize(QSize(200, 100));

        gridLayout->addWidget(select_range, 1, 0, 1, 1);


        retranslateUi(SelectRangeDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SelectRangeDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SelectRangeDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SelectRangeDlg);
    } // setupUi

    void retranslateUi(QDialog *SelectRangeDlg)
    {
        SelectRangeDlg->setWindowTitle(tr2i18n("Select Range", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SelectRangeDlg: public Ui_SelectRangeDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTRANGEDLG_H

