/****************************************************************************
** Meta object code from reading C++ file 'RecordController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwave-26.04.3/plugins/record/RecordController.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RecordController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave16RecordControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::RecordController::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave16RecordControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::RecordController",
        "stateChanged",
        "",
        "Kwave::RecordState",
        "state",
        "sigReset",
        "bool&",
        "accepted",
        "sigStartRecord",
        "sigStopRecord",
        "errorcode",
        "setInitialized",
        "initialized",
        "setEmpty",
        "empty",
        "enablePrerecording",
        "enable",
        "actionReset",
        "actionStop",
        "actionPause",
        "actionStart",
        "deviceRecordStarted",
        "deviceBufferFull",
        "deviceTriggerReached",
        "deviceRecordStopped",
        "enableTrigger"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(Kwave::RecordState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigReset'
        QtMocHelpers::SignalData<void(bool &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigStartRecord'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigStopRecord'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'setInitialized'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'setEmpty'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'enablePrerecording'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'actionReset'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'actionStop'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'actionPause'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'actionStart'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deviceRecordStarted'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deviceBufferFull'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deviceTriggerReached'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deviceRecordStopped'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'enableTrigger'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecordController, qt_meta_tag_ZN5Kwave16RecordControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::RecordController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16RecordControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16RecordControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave16RecordControllerE_t>.metaTypes,
    nullptr
} };

void Kwave::RecordController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecordController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<Kwave::RecordState>>(_a[1]))); break;
        case 1: _t->sigReset((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1]))); break;
        case 2: _t->sigStartRecord(); break;
        case 3: _t->sigStopRecord((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setInitialized((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setEmpty((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->enablePrerecording((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->actionReset(); break;
        case 8: _t->actionStop(); break;
        case 9: _t->actionPause(); break;
        case 10: _t->actionStart(); break;
        case 11: _t->deviceRecordStarted(); break;
        case 12: _t->deviceBufferFull(); break;
        case 13: _t->deviceTriggerReached(); break;
        case 14: _t->deviceRecordStopped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->enableTrigger((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecordController::*)(Kwave::RecordState )>(_a, &RecordController::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordController::*)(bool & )>(_a, &RecordController::sigReset, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordController::*)()>(_a, &RecordController::sigStartRecord, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordController::*)(int )>(_a, &RecordController::sigStopRecord, 3))
            return;
    }
}

const QMetaObject *Kwave::RecordController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::RecordController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave16RecordControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kwave::RecordController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Kwave::RecordController::stateChanged(Kwave::RecordState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::RecordController::sigReset(bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kwave::RecordController::sigStartRecord()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kwave::RecordController::sigStopRecord(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
