/********************************************************************************
** Form generated from reading UI file 'NotchFilterDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOTCHFILTERDLG_H
#define UI_NOTCHFILTERDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>
#include <libgui/ScaleWidget.h>
#include "libgui/FrequencyResponseWidget.h"
#include "libgui/ScaleWidget.h"

QT_BEGIN_NAMESPACE

class Ui_NotchFilterDlg
{
public:
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    Kwave::ScaleWidget *scale_db;
    Kwave::FrequencyResponseWidget *freq_response;
    Kwave::ScaleWidget *scale_freq;
    QSpinBox *spinbox;
    QSlider *slider;
    QSlider *slider_2;
    QSpinBox *spinbox_2;
    QFrame *frame3;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonHelp;
    QPushButton *btListen;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NotchFilterDlg)
    {
        if (NotchFilterDlg->objectName().isEmpty())
            NotchFilterDlg->setObjectName("NotchFilterDlg");
        NotchFilterDlg->resize(557, 388);
        NotchFilterDlg->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(NotchFilterDlg);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(0);
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        scale_db = new Kwave::ScaleWidget(NotchFilterDlg);
        scale_db->setObjectName("scale_db");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scale_db->sizePolicy().hasHeightForWidth());
        scale_db->setSizePolicy(sizePolicy);
        scale_db->setMinimumSize(QSize(30, 0));

        gridLayout1->addWidget(scale_db, 0, 0, 1, 1);

        freq_response = new Kwave::FrequencyResponseWidget(NotchFilterDlg);
        freq_response->setObjectName("freq_response");
        freq_response->setMinimumSize(QSize(400, 200));

        gridLayout1->addWidget(freq_response, 0, 1, 1, 1);

        scale_freq = new Kwave::ScaleWidget(NotchFilterDlg);
        scale_freq->setObjectName("scale_freq");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scale_freq->sizePolicy().hasHeightForWidth());
        scale_freq->setSizePolicy(sizePolicy1);
        scale_freq->setMinimumSize(QSize(0, 30));

        gridLayout1->addWidget(scale_freq, 1, 1, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 2);

        spinbox = new QSpinBox(NotchFilterDlg);
        spinbox->setObjectName("spinbox");
        spinbox->setValue(99);
        spinbox->setProperty("maxValue", QVariant(99999));

        gridLayout->addWidget(spinbox, 1, 0, 1, 1);

        slider = new QSlider(NotchFilterDlg);
        slider->setObjectName("slider");
        slider->setMaximum(44100);
        slider->setOrientation(Qt::Horizontal);
        slider->setTickInterval(2000);

        gridLayout->addWidget(slider, 1, 1, 1, 1);

        slider_2 = new QSlider(NotchFilterDlg);
        slider_2->setObjectName("slider_2");
        slider_2->setMinimum(10);
        slider_2->setMaximum(44100);
        slider_2->setOrientation(Qt::Horizontal);
        slider_2->setTickInterval(2000);

        gridLayout->addWidget(slider_2, 2, 1, 1, 1);

        spinbox_2 = new QSpinBox(NotchFilterDlg);
        spinbox_2->setObjectName("spinbox_2");
        spinbox_2->setValue(99);
        spinbox_2->setProperty("maxValue", QVariant(99999));

        gridLayout->addWidget(spinbox_2, 2, 0, 1, 1);

        frame3 = new QFrame(NotchFilterDlg);
        frame3->setObjectName("frame3");
        frame3->setMinimumSize(QSize(0, 20));
        frame3->setFrameShape(QFrame::NoFrame);
        frame3->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(frame3, 3, 0, 1, 2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        buttonHelp = new QDialogButtonBox(NotchFilterDlg);
        buttonHelp->setObjectName("buttonHelp");
        buttonHelp->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout->addWidget(buttonHelp);

        btListen = new QPushButton(NotchFilterDlg);
        btListen->setObjectName("btListen");
        btListen->setCheckable(true);

        hboxLayout->addWidget(btListen);

        spacerItem = new QSpacerItem(143, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(NotchFilterDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 4, 0, 1, 2);


        retranslateUi(NotchFilterDlg);
        QObject::connect(spinbox, &QSpinBox::valueChanged, slider, &QSlider::setValue);
        QObject::connect(slider, &QSlider::valueChanged, spinbox, &QSpinBox::setValue);
        QObject::connect(slider_2, &QSlider::valueChanged, spinbox_2, &QSpinBox::setValue);
        QObject::connect(spinbox_2, &QSpinBox::valueChanged, slider_2, &QSlider::setValue);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NotchFilterDlg, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NotchFilterDlg, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(NotchFilterDlg);
    } // setupUi

    void retranslateUi(QDialog *NotchFilterDlg)
    {
        NotchFilterDlg->setWindowTitle(tr2i18n("Notch Filter", nullptr));
#if QT_CONFIG(tooltip)
        spinbox->setToolTip(tr2i18n("center frequency", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        spinbox->setWhatsThis(tr2i18n("<b>center frequency</b>\n"
"Determines the center of the frequency range that\n"
"should be removed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        spinbox->setSuffix(tr2i18n(" Hz", nullptr));
#if QT_CONFIG(tooltip)
        slider->setToolTip(tr2i18n("center frequency", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        slider->setWhatsThis(tr2i18n("<b>center frequency</b>\n"
"Determines the center of the frequency range that\n"
"should be removed.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        slider_2->setToolTip(tr2i18n("bandwidth", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        slider_2->setWhatsThis(tr2i18n("<b>bandwidth</b>\n"
"Determines the width of the frequency range that\n"
"should be removed.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        spinbox_2->setToolTip(tr2i18n("bandwidth", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        spinbox_2->setWhatsThis(tr2i18n("<b>bandwidth</b>\n"
"Determines the width of the frequency range that\n"
"should be removed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        spinbox_2->setSuffix(tr2i18n(" Hz", nullptr));
#if QT_CONFIG(tooltip)
        btListen->setToolTip(tr2i18n("start/stop pre-listening", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btListen->setWhatsThis(tr2i18n("Start or stop the pre-listening of the current settings. If pre-listening is enabled, you will nearly immediately hear any change in the selected parameters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btListen->setText(tr2i18n("&Listen", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NotchFilterDlg: public Ui_NotchFilterDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NOTCHFILTERDLG_H

