/****************************************************************************
** Meta object code from reading C++ file 'RecordPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwave-26.04.3/plugins/record/RecordPlugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RecordPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave12RecordPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::RecordPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave12RecordPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::RecordPlugin",
        "sigRecordedSamples",
        "",
        "sample_index_t",
        "samples_recorded",
        "resetRecording",
        "bool&",
        "accepted",
        "startRecording",
        "recordStopped",
        "reason",
        "stateChanged",
        "Kwave::RecordState",
        "state",
        "setMethod",
        "Kwave::record_method_t",
        "method",
        "setDevice",
        "device",
        "changeTracks",
        "new_tracks",
        "changeSampleRate",
        "new_rate",
        "changeCompression",
        "Kwave::Compression::Type",
        "new_compression",
        "changeBitsPerSample",
        "new_bits",
        "changeSampleFormat",
        "Kwave::SampleFormat::Format",
        "new_format",
        "processBuffer",
        "buffersChanged",
        "prerecordingChanged",
        "enable",
        "retryOpen"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigRecordedSamples'
        QtMocHelpers::SignalData<void(sample_index_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'resetRecording'
        QtMocHelpers::SlotData<void(bool &)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'startRecording'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'recordStopped'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'stateChanged'
        QtMocHelpers::SlotData<void(Kwave::RecordState)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setMethod'
        QtMocHelpers::SlotData<void(Kwave::record_method_t)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setDevice'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'changeTracks'
        QtMocHelpers::SlotData<void(unsigned int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
        // Slot 'changeSampleRate'
        QtMocHelpers::SlotData<void(double)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 22 },
        }}),
        // Slot 'changeCompression'
        QtMocHelpers::SlotData<void(Kwave::Compression::Type)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'changeBitsPerSample'
        QtMocHelpers::SlotData<void(unsigned int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 27 },
        }}),
        // Slot 'changeSampleFormat'
        QtMocHelpers::SlotData<void(Kwave::SampleFormat::Format)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'processBuffer'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'buffersChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'prerecordingChanged'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'retryOpen'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecordPlugin, qt_meta_tag_ZN5Kwave12RecordPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::RecordPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<Kwave::Plugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12RecordPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12RecordPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave12RecordPluginE_t>.metaTypes,
    nullptr
} };

void Kwave::RecordPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecordPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigRecordedSamples((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 1: _t->resetRecording((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1]))); break;
        case 2: _t->startRecording(); break;
        case 3: _t->recordStopped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<Kwave::RecordState>>(_a[1]))); break;
        case 5: _t->setMethod((*reinterpret_cast<std::add_pointer_t<Kwave::record_method_t>>(_a[1]))); break;
        case 6: _t->setDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->changeTracks((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: _t->changeSampleRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: _t->changeCompression((*reinterpret_cast<std::add_pointer_t<Kwave::Compression::Type>>(_a[1]))); break;
        case 10: _t->changeBitsPerSample((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 11: _t->changeSampleFormat((*reinterpret_cast<std::add_pointer_t<Kwave::SampleFormat::Format>>(_a[1]))); break;
        case 12: _t->processBuffer(); break;
        case 13: _t->buffersChanged(); break;
        case 14: _t->prerecordingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->retryOpen(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecordPlugin::*)(sample_index_t )>(_a, &RecordPlugin::sigRecordedSamples, 0))
            return;
    }
}

const QMetaObject *Kwave::RecordPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::RecordPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12RecordPluginE_t>.strings))
        return static_cast<void*>(this);
    return Kwave::Plugin::qt_metacast(_clname);
}

int Kwave::RecordPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kwave::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Kwave::RecordPlugin::sigRecordedSamples(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
