/****************************************************************************
** Meta object code from reading C++ file 'RecordDialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwave-26.04.3/plugins/record/RecordDialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RecordDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave12RecordDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::RecordDialog::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave12RecordDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::RecordDialog",
        "sigMethodChanged",
        "",
        "Kwave::record_method_t",
        "method",
        "sigDeviceChanged",
        "device",
        "sigTracksChanged",
        "tracks",
        "sampleRateChanged",
        "rate",
        "sigCompressionChanged",
        "Kwave::Compression::Type",
        "compression",
        "sigBitsPerSampleChanged",
        "bits",
        "sigSampleFormatChanged",
        "Kwave::SampleFormat::Format",
        "sample_format",
        "sigBuffersChanged",
        "sigRecordTimeChanged",
        "limit",
        "sigTriggerChanged",
        "enabled",
        "sigPreRecordingChanged",
        "setDevice",
        "setFileFilter",
        "filter",
        "setRecordedSamples",
        "sample_index_t",
        "samples_recorded",
        "message",
        "methodSelected",
        "index",
        "sourceBufferCountChanged",
        "value",
        "sourceBufferSizeChanged",
        "selectRecordDevice",
        "listEntrySelected",
        "QTreeWidgetItem*",
        "current",
        "previous",
        "listItemExpanded",
        "item",
        "updateListSelection",
        "tracksChanged",
        "compressionChanged",
        "bitsPerSampleChanged",
        "sampleFormatChanged",
        "setState",
        "Kwave::RecordState",
        "state",
        "updateBufferProgressBar",
        "preRecordingChecked",
        "preRecordingTimeChanged",
        "time",
        "recordTimeChecked",
        "limited",
        "recordTimeChanged",
        "record_time",
        "startTimeChecked",
        "startTimeChanged",
        "datetime",
        "triggerChecked",
        "triggerChanged",
        "trigger",
        "invokeHelp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigMethodChanged'
        QtMocHelpers::SignalData<void(Kwave::record_method_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigDeviceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'sigTracksChanged'
        QtMocHelpers::SignalData<void(unsigned int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 },
        }}),
        // Signal 'sampleRateChanged'
        QtMocHelpers::SignalData<void(double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 10 },
        }}),
        // Signal 'sigCompressionChanged'
        QtMocHelpers::SignalData<void(Kwave::Compression::Type)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'sigBitsPerSampleChanged'
        QtMocHelpers::SignalData<void(unsigned int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 15 },
        }}),
        // Signal 'sigSampleFormatChanged'
        QtMocHelpers::SignalData<void(Kwave::SampleFormat::Format)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'sigBuffersChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRecordTimeChanged'
        QtMocHelpers::SignalData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Signal 'sigTriggerChanged'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'sigPreRecordingChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setDevice'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setFileFilter'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setRecordedSamples'
        QtMocHelpers::SlotData<void(sample_index_t)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'message'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'methodSelected'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'sourceBufferCountChanged'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'sourceBufferSizeChanged'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'selectRecordDevice'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'listEntrySelected'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, QTreeWidgetItem *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 }, { 0x80000000 | 39, 41 },
        }}),
        // Slot 'listItemExpanded'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 43 },
        }}),
        // Slot 'updateListSelection'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tracksChanged'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'sampleRateChanged'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'compressionChanged'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'bitsPerSampleChanged'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'sampleFormatChanged'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'setState'
        QtMocHelpers::SlotData<void(Kwave::RecordState)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'updateBufferProgressBar'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'preRecordingChecked'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'preRecordingTimeChanged'
        QtMocHelpers::SlotData<void(int)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'recordTimeChecked'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'recordTimeChanged'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 59 },
        }}),
        // Slot 'startTimeChecked'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'startTimeChanged'
        QtMocHelpers::SlotData<void(const QDateTime &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDateTime, 62 },
        }}),
        // Slot 'triggerChecked'
        QtMocHelpers::SlotData<void(bool)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'triggerChanged'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 65 },
        }}),
        // Slot 'invokeHelp'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecordDialog, qt_meta_tag_ZN5Kwave12RecordDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::RecordDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12RecordDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12RecordDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave12RecordDialogE_t>.metaTypes,
    nullptr
} };

void Kwave::RecordDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecordDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigMethodChanged((*reinterpret_cast<std::add_pointer_t<Kwave::record_method_t>>(_a[1]))); break;
        case 1: _t->sigDeviceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->sigTracksChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->sampleRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->sigCompressionChanged((*reinterpret_cast<std::add_pointer_t<Kwave::Compression::Type>>(_a[1]))); break;
        case 5: _t->sigBitsPerSampleChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->sigSampleFormatChanged((*reinterpret_cast<std::add_pointer_t<Kwave::SampleFormat::Format>>(_a[1]))); break;
        case 7: _t->sigBuffersChanged(); break;
        case 8: _t->sigRecordTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->sigTriggerChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->sigPreRecordingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setFileFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->setRecordedSamples((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 14: _t->message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->methodSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->sourceBufferCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->sourceBufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->selectRecordDevice(); break;
        case 19: _t->listEntrySelected((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[2]))); break;
        case 20: _t->listItemExpanded((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 21: _t->updateListSelection(); break;
        case 22: _t->tracksChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->sampleRateChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->compressionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->bitsPerSampleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->sampleFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setState((*reinterpret_cast<std::add_pointer_t<Kwave::RecordState>>(_a[1]))); break;
        case 28: _t->updateBufferProgressBar(); break;
        case 29: _t->preRecordingChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->preRecordingTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->recordTimeChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->recordTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->startTimeChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->startTimeChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 35: _t->triggerChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->triggerChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->invokeHelp(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(Kwave::record_method_t )>(_a, &RecordDialog::sigMethodChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(const QString & )>(_a, &RecordDialog::sigDeviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(unsigned int )>(_a, &RecordDialog::sigTracksChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(double )>(_a, &RecordDialog::sampleRateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(Kwave::Compression::Type )>(_a, &RecordDialog::sigCompressionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(unsigned int )>(_a, &RecordDialog::sigBitsPerSampleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(Kwave::SampleFormat::Format )>(_a, &RecordDialog::sigSampleFormatChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)()>(_a, &RecordDialog::sigBuffersChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(int )>(_a, &RecordDialog::sigRecordTimeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(bool )>(_a, &RecordDialog::sigTriggerChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecordDialog::*)(bool )>(_a, &RecordDialog::sigPreRecordingChanged, 10))
            return;
    }
}

const QMetaObject *Kwave::RecordDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::RecordDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12RecordDialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::RecordDlg"))
        return static_cast< Ui::RecordDlg*>(this);
    return QDialog::qt_metacast(_clname);
}

int Kwave::RecordDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void Kwave::RecordDialog::sigMethodChanged(Kwave::record_method_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::RecordDialog::sigDeviceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kwave::RecordDialog::sigTracksChanged(unsigned int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kwave::RecordDialog::sampleRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kwave::RecordDialog::sigCompressionChanged(Kwave::Compression::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Kwave::RecordDialog::sigBitsPerSampleChanged(unsigned int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Kwave::RecordDialog::sigSampleFormatChanged(Kwave::SampleFormat::Format _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Kwave::RecordDialog::sigBuffersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Kwave::RecordDialog::sigRecordTimeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Kwave::RecordDialog::sigTriggerChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Kwave::RecordDialog::sigPreRecordingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
