/********************************************************************************
** Form generated from reading UI file 'BitrateWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BITRATEWIDGETBASE_H
#define UI_BITRATEWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "BitrateSpinBox.h"

QT_BEGIN_NAMESPACE

class Ui_BitrateWidgetBase
{
public:
    QHBoxLayout *hboxLayout;
    Kwave::BitrateSpinBox *spinbox;
    QSpacerItem *Spacer58;
    QSlider *slider;

    void setupUi(QWidget *BitrateWidgetBase)
    {
        if (BitrateWidgetBase->objectName().isEmpty())
            BitrateWidgetBase->setObjectName("BitrateWidgetBase");
        BitrateWidgetBase->resize(312, 36);
        hboxLayout = new QHBoxLayout(BitrateWidgetBase);
        hboxLayout->setSpacing(0);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        spinbox = new Kwave::BitrateSpinBox(BitrateWidgetBase);
        spinbox->setObjectName("spinbox");
        spinbox->setMinimumSize(QSize(90, 20));

        hboxLayout->addWidget(spinbox);

        Spacer58 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        hboxLayout->addItem(Spacer58);

        slider = new QSlider(BitrateWidgetBase);
        slider->setObjectName("slider");
        slider->setEnabled(true);
        slider->setMinimumSize(QSize(200, 0));
        slider->setMaximum(100);
        slider->setSingleStep(1000);
        slider->setPageStep(1000);
        slider->setOrientation(Qt::Horizontal);

        hboxLayout->addWidget(slider);


        retranslateUi(BitrateWidgetBase);

        QMetaObject::connectSlotsByName(BitrateWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *BitrateWidgetBase)
    {
        (void)BitrateWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class BitrateWidgetBase: public Ui_BitrateWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BITRATEWIDGETBASE_H

