/********************************************************************************
** Form generated from reading UI file 'VolumeDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VOLUMEDLG_H
#define UI_VOLUMEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "libgui/ImageView.h"
#include "libgui/InvertableSpinBox.h"

QT_BEGIN_NAMESPACE

class Ui_VolumeDlg
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *ButtonGroup1;
    QVBoxLayout *verticalLayout;
    QRadioButton *rbFactor;
    QRadioButton *rbPercentage;
    QRadioButton *rbLogarithmic;
    QSpacerItem *spacer;
    QFrame *Line1_2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QSlider *slider;
    QSpacerItem *spacerItem1;
    Kwave::InvertableSpinBox *spinbox;
    Kwave::ImageView *preview;
    QFrame *Line1;
    QHBoxLayout *_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *VolumeDlg)
    {
        if (VolumeDlg->objectName().isEmpty())
            VolumeDlg->setObjectName("VolumeDlg");
        VolumeDlg->setWindowModality(Qt::ApplicationModal);
        VolumeDlg->resize(343, 321);
        gridLayout = new QGridLayout(VolumeDlg);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(10, 10, 10, -1);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setSizeConstraint(QLayout::SetMinimumSize);
        ButtonGroup1 = new QGroupBox(VolumeDlg);
        ButtonGroup1->setObjectName("ButtonGroup1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ButtonGroup1->sizePolicy().hasHeightForWidth());
        ButtonGroup1->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(ButtonGroup1);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(10, 10, 10, -1);
        rbFactor = new QRadioButton(ButtonGroup1);
        rbFactor->setObjectName("rbFactor");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(rbFactor->sizePolicy().hasHeightForWidth());
        rbFactor->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(rbFactor);

        rbPercentage = new QRadioButton(ButtonGroup1);
        rbPercentage->setObjectName("rbPercentage");
        sizePolicy1.setHeightForWidth(rbPercentage->sizePolicy().hasHeightForWidth());
        rbPercentage->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(rbPercentage);

        rbLogarithmic = new QRadioButton(ButtonGroup1);
        rbLogarithmic->setObjectName("rbLogarithmic");
        sizePolicy1.setHeightForWidth(rbLogarithmic->sizePolicy().hasHeightForWidth());
        rbLogarithmic->setSizePolicy(sizePolicy1);
        rbLogarithmic->setChecked(false);

        verticalLayout->addWidget(rbLogarithmic);


        verticalLayout_2->addWidget(ButtonGroup1);

        spacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacer);


        gridLayout->addLayout(verticalLayout_2, 0, 0, 1, 1);

        Line1_2 = new QFrame(VolumeDlg);
        Line1_2->setObjectName("Line1_2");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(Line1_2->sizePolicy().hasHeightForWidth());
        Line1_2->setSizePolicy(sizePolicy2);
        Line1_2->setMinimumSize(QSize(0, 20));
        Line1_2->setMaximumSize(QSize(100, 500));
        Line1_2->setFrameShape(QFrame::VLine);
        Line1_2->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(Line1_2, 0, 1, 1, 1);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        spacerItem = new QSpacerItem(10, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        slider = new QSlider(VolumeDlg);
        slider->setObjectName("slider");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(100);
        sizePolicy3.setHeightForWidth(slider->sizePolicy().hasHeightForWidth());
        slider->setSizePolicy(sizePolicy3);
        slider->setMinimumSize(QSize(40, 100));
        slider->setMinimum(-42);
        slider->setMaximum(42);
        slider->setPageStep(6);
        slider->setValue(0);
        slider->setInvertedAppearance(true);
        slider->setInvertedControls(true);
        slider->setTickPosition(QSlider::TicksBothSides);
        slider->setTickInterval(6);

        hboxLayout->addWidget(slider);

        spacerItem1 = new QSpacerItem(10, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);

        hboxLayout->setStretch(0, 100);
        hboxLayout->setStretch(1, 100);
        hboxLayout->setStretch(2, 100);

        verticalLayout_3->addLayout(hboxLayout);

        spinbox = new Kwave::InvertableSpinBox(VolumeDlg);
        spinbox->setObjectName("spinbox");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(spinbox->sizePolicy().hasHeightForWidth());
        spinbox->setSizePolicy(sizePolicy4);
        spinbox->setMinimumSize(QSize(40, 30));

        verticalLayout_3->addWidget(spinbox);

        verticalLayout_3->setStretch(0, 5);
        verticalLayout_3->setStretch(1, 5);

        gridLayout->addLayout(verticalLayout_3, 0, 2, 1, 1);

        preview = new Kwave::ImageView(VolumeDlg);
        preview->setObjectName("preview");
        sizePolicy4.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy4);
        preview->setMinimumSize(QSize(0, 51));

        gridLayout->addWidget(preview, 1, 0, 1, 3);

        Line1 = new QFrame(VolumeDlg);
        Line1->setObjectName("Line1");
        sizePolicy4.setHeightForWidth(Line1->sizePolicy().hasHeightForWidth());
        Line1->setSizePolicy(sizePolicy4);
        Line1->setMinimumSize(QSize(0, 20));
        Line1->setFrameShape(QFrame::HLine);
        Line1->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(Line1, 2, 0, 1, 3);

        _2 = new QHBoxLayout();
        _2->setSpacing(10);
        _2->setContentsMargins(0, 0, 0, 0);
        _2->setObjectName("_2");
        buttonBox = new QDialogButtonBox(VolumeDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        _2->addWidget(buttonBox);


        gridLayout->addLayout(_2, 3, 0, 1, 3);

        QWidget::setTabOrder(rbFactor, rbPercentage);
        QWidget::setTabOrder(rbPercentage, rbLogarithmic);
        QWidget::setTabOrder(rbLogarithmic, slider);
        QWidget::setTabOrder(slider, spinbox);

        retranslateUi(VolumeDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, VolumeDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, VolumeDlg, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, SIGNAL(helpRequested()), VolumeDlg, SLOT(invokeHelp()));

        QMetaObject::connectSlotsByName(VolumeDlg);
    } // setupUi

    void retranslateUi(QDialog *VolumeDlg)
    {
        VolumeDlg->setWindowTitle(tr2i18n("Volume", nullptr));
        ButtonGroup1->setTitle(tr2i18n("Mode", nullptr));
#if QT_CONFIG(tooltip)
        rbFactor->setToolTip(tr2i18n("change volume by factor", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbFactor->setWhatsThis(tr2i18n("Increments or decrements the volume by a factor.\n"
"For example: \"x1\", \"x2\", \"/ 4\"", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbFactor->setText(tr2i18n("&Factor", nullptr));
#if QT_CONFIG(tooltip)
        rbPercentage->setToolTip(tr2i18n("change volume by percentage", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbPercentage->setWhatsThis(tr2i18n("Sets the volume to a relative percentage of the original level.\n"
"For example: \"50 %\", \"75%\" or \"125%\"", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbPercentage->setText(tr2i18n("&Percentage", nullptr));
#if QT_CONFIG(tooltip)
        rbLogarithmic->setToolTip(tr2i18n("change volume in dB", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbLogarithmic->setWhatsThis(tr2i18n("Increments or decrements the volume in logarithmic scale (decibel).\n"
"For example: \"+3 dB\", \"+ 6 dB\", \"-3 dB\".", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbLogarithmic->setText(tr2i18n("&Logarithmic", nullptr));
#if QT_CONFIG(tooltip)
        slider->setToolTip(tr2i18n("Volume", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        spinbox->setToolTip(tr2i18n("Volume", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class VolumeDlg: public Ui_VolumeDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VOLUMEDLG_H

