/********************************************************************************
** Form generated from reading UI file 'LabelPropertiesWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LABELPROPERTIESWIDGETBASE_H
#define UI_LABELPROPERTIESWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "libgui/SelectTimeWidget.h"

QT_BEGIN_NAMESPACE

class Ui_LabelPropertiesWidgetBase
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    Kwave::SelectTimeWidget *time;
    QLabel *textLabel1_2;
    QLineEdit *edDescription;
    QLabel *textLabel1;
    QLabel *textLabel1_2_2;
    QLineEdit *lblIndex;
    QFrame *frame5;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *dialogButtonBox_2;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *LabelPropertiesWidgetBase)
    {
        if (LabelPropertiesWidgetBase->objectName().isEmpty())
            LabelPropertiesWidgetBase->setObjectName("LabelPropertiesWidgetBase");
        LabelPropertiesWidgetBase->resize(422, 250);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(LabelPropertiesWidgetBase->sizePolicy().hasHeightForWidth());
        LabelPropertiesWidgetBase->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(LabelPropertiesWidgetBase);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(10);
        gridLayout->setObjectName("gridLayout");
        time = new Kwave::SelectTimeWidget(LabelPropertiesWidgetBase);
        time->setObjectName("time");
        time->setMinimumSize(QSize(0, 100));
        time->setFocusPolicy(Qt::TabFocus);

        gridLayout->addWidget(time, 1, 1, 1, 1);

        textLabel1_2 = new QLabel(LabelPropertiesWidgetBase);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        gridLayout->addWidget(textLabel1_2, 2, 0, 1, 1);

        edDescription = new QLineEdit(LabelPropertiesWidgetBase);
        edDescription->setObjectName("edDescription");

        gridLayout->addWidget(edDescription, 2, 1, 1, 1);

        textLabel1 = new QLabel(LabelPropertiesWidgetBase);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout->addWidget(textLabel1, 1, 0, 1, 1);

        textLabel1_2_2 = new QLabel(LabelPropertiesWidgetBase);
        textLabel1_2_2->setObjectName("textLabel1_2_2");
        textLabel1_2_2->setWordWrap(false);

        gridLayout->addWidget(textLabel1_2_2, 0, 0, 1, 1);

        lblIndex = new QLineEdit(LabelPropertiesWidgetBase);
        lblIndex->setObjectName("lblIndex");
        lblIndex->setEnabled(false);

        gridLayout->addWidget(lblIndex, 0, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        frame5 = new QFrame(LabelPropertiesWidgetBase);
        frame5->setObjectName("frame5");
        frame5->setFrameShape(QFrame::NoFrame);
        frame5->setFrameShadow(QFrame::Plain);

        vboxLayout->addWidget(frame5);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setObjectName("hboxLayout");
        dialogButtonBox_2 = new QDialogButtonBox(LabelPropertiesWidgetBase);
        dialogButtonBox_2->setObjectName("dialogButtonBox_2");
        dialogButtonBox_2->setEnabled(false);
        dialogButtonBox_2->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout->addWidget(dialogButtonBox_2);

        spacerItem = new QSpacerItem(91, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(LabelPropertiesWidgetBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        vboxLayout->addLayout(hboxLayout);

        QWidget::setTabOrder(edDescription, dialogButtonBox_2);
        QWidget::setTabOrder(dialogButtonBox_2, buttonBox);
        QWidget::setTabOrder(buttonBox, lblIndex);
        QWidget::setTabOrder(lblIndex, time);

        retranslateUi(LabelPropertiesWidgetBase);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, LabelPropertiesWidgetBase, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, LabelPropertiesWidgetBase, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(LabelPropertiesWidgetBase);
    } // setupUi

    void retranslateUi(QDialog *LabelPropertiesWidgetBase)
    {
        LabelPropertiesWidgetBase->setWindowTitle(tr2i18n("Label Properties...", nullptr));
#if QT_CONFIG(whatsthis)
        time->setWhatsThis(tr2i18n("<b>label position:</b><br>\n"
"Here you can set the position of the label, either by time, by percentage of the whole file or by an absolute sample position. However, internally Kwave always uses the position in samples.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1_2->setText(tr2i18n("Description:", nullptr));
#if QT_CONFIG(tooltip)
        edDescription->setToolTip(tr2i18n("some description of the label (optional)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        edDescription->setWhatsThis(tr2i18n("<b>label description:</b><br>\n"
"Here you can enter some short text to describe the label.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1->setText(tr2i18n("Position:", nullptr));
        textLabel1_2_2->setText(tr2i18n("Index:", nullptr));
#if QT_CONFIG(tooltip)
        lblIndex->setToolTip(tr2i18n("index of the label", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        lblIndex->setWhatsThis(tr2i18n("<b>label index</b><br>\n"
"This is just a numeric index of the label, starting with zero, sorted by position. Lower index means 'left', higher index means 'right'. You cannot change the index itself, but change the label's position.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class LabelPropertiesWidgetBase: public Ui_LabelPropertiesWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LABELPROPERTIESWIDGETBASE_H

