/****************************************************************************
** Meta object code from reading C++ file 'Track.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/libkwave/Track.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Track.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave5TrackE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::Track::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave5TrackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::Track",
        "sigSamplesInserted",
        "",
        "Kwave::Track*",
        "src",
        "sample_index_t",
        "offset",
        "length",
        "sigSamplesDeleted",
        "sigSamplesModified",
        "sigSelectionChanged",
        "selected",
        "toggleSelection",
        "defragment"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigSamplesInserted'
        QtMocHelpers::SignalData<void(Kwave::Track *, sample_index_t, sample_index_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'sigSamplesDeleted'
        QtMocHelpers::SignalData<void(Kwave::Track *, sample_index_t, sample_index_t)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'sigSamplesModified'
        QtMocHelpers::SignalData<void(Kwave::Track *, sample_index_t, sample_index_t)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'sigSelectionChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'toggleSelection'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defragment'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Track, qt_meta_tag_ZN5Kwave5TrackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::Track::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave5TrackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave5TrackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave5TrackE_t>.metaTypes,
    nullptr
} };

void Kwave::Track::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Track *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigSamplesInserted((*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 1: _t->sigSamplesDeleted((*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 2: _t->sigSamplesModified((*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 3: _t->sigSelectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->toggleSelection(); break;
        case 5: _t->defragment(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::Track* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::Track* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::Track* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Track::*)(Kwave::Track * , sample_index_t , sample_index_t )>(_a, &Track::sigSamplesInserted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Track::*)(Kwave::Track * , sample_index_t , sample_index_t )>(_a, &Track::sigSamplesDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Track::*)(Kwave::Track * , sample_index_t , sample_index_t )>(_a, &Track::sigSamplesModified, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Track::*)(bool )>(_a, &Track::sigSelectionChanged, 3))
            return;
    }
}

const QMetaObject *Kwave::Track::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::Track::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave5TrackE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kwave::Track::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Kwave::Track::sigSamplesInserted(Kwave::Track * _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Kwave::Track::sigSamplesDeleted(Kwave::Track * _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Kwave::Track::sigSamplesModified(Kwave::Track * _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void Kwave::Track::sigSelectionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
