/********************************************************************************
** Form generated from reading UI file 'NewSigDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWSIGDLG_H
#define UI_NEWSIGDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_NewSigDlg
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *GroupBox1_2;
    QGridLayout *gridLayout;
    KComboBox *cbSampleRate;
    QLabel *lblRate;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout;
    QLabel *lblSamplesPerSecond;
    QSpacerItem *spacerItem3;
    QLabel *lblChannels;
    QLabel *lblResolution;
    QHBoxLayout *hboxLayout1;
    QLabel *lblBits;
    QSpacerItem *spacerItem4;
    QHBoxLayout *hboxLayout2;
    QLabel *lblTracksVerbose;
    QSpacerItem *spacerItem5;
    QSpinBox *sbChannels;
    QSpinBox *sbResolution;
    QGroupBox *GroupBox1;
    QVBoxLayout *vboxLayout1;
    QGroupBox *Frame3;
    QGridLayout *gridLayout1;
    QRadioButton *rbTime;
    QRadioButton *rbSamples;
    QSpacerItem *spacerItem6;
    QSpinBox *edSamples;
    QLabel *lblSeconds;
    QSpinBox *sbSeconds;
    QSpinBox *sbMinutes;
    QLabel *lblMinutes;
    QSpinBox *sbHours;
    QLabel *lblHours;
    QFrame *Line3;
    QHBoxLayout *hboxLayout3;
    QLabel *lblMaximumSize_2_2;
    QSpacerItem *spacerItem7;
    QLabel *TextLabel2_2;
    QSpacerItem *spacerItem8;
    QLabel *lblMaximumSize_3;
    QSlider *slideLength;
    QHBoxLayout *hboxLayout4;
    QLabel *TextLabel1;
    QSpacerItem *spacerItem9;
    QLabel *TextLabel3;
    QSpacerItem *spacerItem10;
    QLabel *TextLabel2;
    QHBoxLayout *hboxLayout5;
    QSpacerItem *spacerItem11;
    QHBoxLayout *hboxLayout6;
    QLabel *lblFileSize;
    QSpacerItem *spacerItem12;
    QSpacerItem *spacerItem13;
    QHBoxLayout *hboxLayout7;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NewSigDlg)
    {
        if (NewSigDlg->objectName().isEmpty())
            NewSigDlg->setObjectName("NewSigDlg");
        NewSigDlg->resize(503, 590);
        vboxLayout = new QVBoxLayout(NewSigDlg);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        GroupBox1_2 = new QGroupBox(NewSigDlg);
        GroupBox1_2->setObjectName("GroupBox1_2");
        gridLayout = new QGridLayout(GroupBox1_2);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        cbSampleRate = new KComboBox(GroupBox1_2);
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->addItem(QString());
        cbSampleRate->setObjectName("cbSampleRate");
        cbSampleRate->setEditable(true);

        gridLayout->addWidget(cbSampleRate, 0, 2, 1, 1);

        lblRate = new QLabel(GroupBox1_2);
        lblRate->setObjectName("lblRate");
        lblRate->setWordWrap(false);

        gridLayout->addWidget(lblRate, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 1, 1, 1);

        spacerItem1 = new QSpacerItem(20, 21, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 1, 1, 1);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem2, 2, 1, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        lblSamplesPerSecond = new QLabel(GroupBox1_2);
        lblSamplesPerSecond->setObjectName("lblSamplesPerSecond");
        lblSamplesPerSecond->setWordWrap(false);

        hboxLayout->addWidget(lblSamplesPerSecond);

        spacerItem3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem3);


        gridLayout->addLayout(hboxLayout, 0, 3, 1, 1);

        lblChannels = new QLabel(GroupBox1_2);
        lblChannels->setObjectName("lblChannels");
        lblChannels->setWordWrap(false);

        gridLayout->addWidget(lblChannels, 2, 0, 1, 1);

        lblResolution = new QLabel(GroupBox1_2);
        lblResolution->setObjectName("lblResolution");
        lblResolution->setWordWrap(false);

        gridLayout->addWidget(lblResolution, 1, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(10);
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        lblBits = new QLabel(GroupBox1_2);
        lblBits->setObjectName("lblBits");
        lblBits->setWordWrap(false);

        hboxLayout1->addWidget(lblBits);

        spacerItem4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem4);


        gridLayout->addLayout(hboxLayout1, 1, 3, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(10);
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        lblTracksVerbose = new QLabel(GroupBox1_2);
        lblTracksVerbose->setObjectName("lblTracksVerbose");
        lblTracksVerbose->setWordWrap(false);

        hboxLayout2->addWidget(lblTracksVerbose);

        spacerItem5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem5);


        gridLayout->addLayout(hboxLayout2, 2, 3, 1, 1);

        sbChannels = new QSpinBox(GroupBox1_2);
        sbChannels->setObjectName("sbChannels");
        sbChannels->setMinimum(1);
        sbChannels->setValue(2);

        gridLayout->addWidget(sbChannels, 2, 2, 1, 1);

        sbResolution = new QSpinBox(GroupBox1_2);
        sbResolution->setObjectName("sbResolution");
        sbResolution->setMinimum(8);
        sbResolution->setMaximum(24);
        sbResolution->setSingleStep(8);
        sbResolution->setValue(16);

        gridLayout->addWidget(sbResolution, 1, 2, 1, 1);


        vboxLayout->addWidget(GroupBox1_2);

        GroupBox1 = new QGroupBox(NewSigDlg);
        GroupBox1->setObjectName("GroupBox1");
        vboxLayout1 = new QVBoxLayout(GroupBox1);
        vboxLayout1->setSpacing(10);
        vboxLayout1->setContentsMargins(10, 10, 10, 10);
        vboxLayout1->setObjectName("vboxLayout1");
        Frame3 = new QGroupBox(GroupBox1);
        Frame3->setObjectName("Frame3");
        gridLayout1 = new QGridLayout(Frame3);
        gridLayout1->setSpacing(10);
        gridLayout1->setContentsMargins(10, 10, 10, 10);
        gridLayout1->setObjectName("gridLayout1");
        rbTime = new QRadioButton(Frame3);
        rbTime->setObjectName("rbTime");

        gridLayout1->addWidget(rbTime, 1, 0, 1, 1);

        rbSamples = new QRadioButton(Frame3);
        rbSamples->setObjectName("rbSamples");

        gridLayout1->addWidget(rbSamples, 3, 0, 1, 1);

        spacerItem6 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout1->addItem(spacerItem6, 2, 2, 1, 1);

        edSamples = new QSpinBox(Frame3);
        edSamples->setObjectName("edSamples");
        edSamples->setEnabled(false);

        gridLayout1->addWidget(edSamples, 3, 1, 1, 3);

        lblSeconds = new QLabel(Frame3);
        lblSeconds->setObjectName("lblSeconds");
        lblSeconds->setWordWrap(false);

        gridLayout1->addWidget(lblSeconds, 0, 3, 1, 1);

        sbSeconds = new QSpinBox(Frame3);
        sbSeconds->setObjectName("sbSeconds");
        sbSeconds->setEnabled(false);
        sbSeconds->setWrapping(true);
        sbSeconds->setMinimum(-1);
        sbSeconds->setMaximum(60);
        sbSeconds->setValue(30);

        gridLayout1->addWidget(sbSeconds, 1, 3, 1, 1);

        sbMinutes = new QSpinBox(Frame3);
        sbMinutes->setObjectName("sbMinutes");
        sbMinutes->setEnabled(false);
        sbMinutes->setWrapping(true);
        sbMinutes->setMinimum(-1);
        sbMinutes->setMaximum(60);
        sbMinutes->setValue(4);

        gridLayout1->addWidget(sbMinutes, 1, 2, 1, 1);

        lblMinutes = new QLabel(Frame3);
        lblMinutes->setObjectName("lblMinutes");
        lblMinutes->setWordWrap(false);

        gridLayout1->addWidget(lblMinutes, 0, 2, 1, 1);

        sbHours = new QSpinBox(Frame3);
        sbHours->setObjectName("sbHours");
        sbHours->setEnabled(false);

        gridLayout1->addWidget(sbHours, 1, 1, 1, 1);

        lblHours = new QLabel(Frame3);
        lblHours->setObjectName("lblHours");
        lblHours->setWordWrap(false);

        gridLayout1->addWidget(lblHours, 0, 1, 1, 1);


        vboxLayout1->addWidget(Frame3);

        Line3 = new QFrame(GroupBox1);
        Line3->setObjectName("Line3");
        Line3->setMinimumSize(QSize(0, 20));
        Line3->setFrameShape(QFrame::HLine);
        Line3->setFrameShadow(QFrame::Sunken);

        vboxLayout1->addWidget(Line3);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(10);
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        lblMaximumSize_2_2 = new QLabel(GroupBox1);
        lblMaximumSize_2_2->setObjectName("lblMaximumSize_2_2");
        lblMaximumSize_2_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        lblMaximumSize_2_2->setWordWrap(false);

        hboxLayout3->addWidget(lblMaximumSize_2_2);

        spacerItem7 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem7);

        TextLabel2_2 = new QLabel(GroupBox1);
        TextLabel2_2->setObjectName("TextLabel2_2");
        TextLabel2_2->setAlignment(Qt::AlignCenter);
        TextLabel2_2->setWordWrap(false);

        hboxLayout3->addWidget(TextLabel2_2);

        spacerItem8 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem8);

        lblMaximumSize_3 = new QLabel(GroupBox1);
        lblMaximumSize_3->setObjectName("lblMaximumSize_3");
        lblMaximumSize_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lblMaximumSize_3->setWordWrap(false);

        hboxLayout3->addWidget(lblMaximumSize_3);


        vboxLayout1->addLayout(hboxLayout3);

        slideLength = new QSlider(GroupBox1);
        slideLength->setObjectName("slideLength");
        slideLength->setMinimumSize(QSize(0, 20));
        slideLength->setMinimum(0);
        slideLength->setMaximum(100);
        slideLength->setValue(1);
        slideLength->setOrientation(Qt::Horizontal);
        slideLength->setTickInterval(5);

        vboxLayout1->addWidget(slideLength);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(10);
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        hboxLayout4->setObjectName("hboxLayout4");
        TextLabel1 = new QLabel(GroupBox1);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setWordWrap(false);

        hboxLayout4->addWidget(TextLabel1);

        spacerItem9 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem9);

        TextLabel3 = new QLabel(GroupBox1);
        TextLabel3->setObjectName("TextLabel3");
        TextLabel3->setWordWrap(false);

        hboxLayout4->addWidget(TextLabel3);

        spacerItem10 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem10);

        TextLabel2 = new QLabel(GroupBox1);
        TextLabel2->setObjectName("TextLabel2");
        TextLabel2->setWordWrap(false);

        hboxLayout4->addWidget(TextLabel2);


        vboxLayout1->addLayout(hboxLayout4);


        vboxLayout->addWidget(GroupBox1);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(10);
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        hboxLayout5->setObjectName("hboxLayout5");
        spacerItem11 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout5->addItem(spacerItem11);

        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setSpacing(10);
        hboxLayout6->setContentsMargins(0, 0, 0, 0);
        hboxLayout6->setObjectName("hboxLayout6");
        lblFileSize = new QLabel(NewSigDlg);
        lblFileSize->setObjectName("lblFileSize");
        lblFileSize->setWordWrap(false);

        hboxLayout6->addWidget(lblFileSize);


        hboxLayout5->addLayout(hboxLayout6);

        spacerItem12 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout5->addItem(spacerItem12);


        vboxLayout->addLayout(hboxLayout5);

        spacerItem13 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem13);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setSpacing(10);
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        hboxLayout7->setObjectName("hboxLayout7");
        buttonBox = new QDialogButtonBox(NewSigDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        hboxLayout7->addWidget(buttonBox);


        vboxLayout->addLayout(hboxLayout7);


        retranslateUi(NewSigDlg);
        QObject::connect(rbTime, &QRadioButton::toggled, lblSeconds, &QLabel::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, lblMinutes, &QLabel::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, lblHours, &QLabel::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbSeconds, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbMinutes, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbHours, &QSpinBox::setEnabled);
        QObject::connect(rbSamples, &QRadioButton::toggled, edSamples, &QSpinBox::setEnabled);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NewSigDlg, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NewSigDlg, qOverload<>(&QDialog::accept));

        cbSampleRate->setCurrentIndex(7);


        QMetaObject::connectSlotsByName(NewSigDlg);
    } // setupUi

    void retranslateUi(QDialog *NewSigDlg)
    {
        NewSigDlg->setWindowTitle(tr2i18n("New Signal", nullptr));
        GroupBox1_2->setTitle(tr2i18n("Format", nullptr));
        cbSampleRate->setItemText(0, tr2i18n("8000", nullptr));
        cbSampleRate->setItemText(1, tr2i18n("10000", nullptr));
        cbSampleRate->setItemText(2, tr2i18n("11025", nullptr));
        cbSampleRate->setItemText(3, tr2i18n("12000", nullptr));
        cbSampleRate->setItemText(4, tr2i18n("16000", nullptr));
        cbSampleRate->setItemText(5, tr2i18n("22050", nullptr));
        cbSampleRate->setItemText(6, tr2i18n("32000", nullptr));
        cbSampleRate->setItemText(7, tr2i18n("44100", nullptr));
        cbSampleRate->setItemText(8, tr2i18n("48000", nullptr));
        cbSampleRate->setItemText(9, tr2i18n("96000", nullptr));

#if QT_CONFIG(whatsthis)
        cbSampleRate->setWhatsThis(tr2i18n("<b>Sample rate</b><br>Here you can select one of the predefined well-known sample rates or you can enter any sample rate on your own.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblRate->setText(tr2i18n("Sample rate:", nullptr));
        lblSamplesPerSecond->setText(tr2i18n("Samples per second", nullptr));
        lblChannels->setText(tr2i18n("Tracks:", nullptr));
        lblResolution->setText(tr2i18n("Resolution:", nullptr));
        lblBits->setText(tr2i18n("Bit", nullptr));
        lblTracksVerbose->setText(tr2i18n("%1", nullptr));
#if QT_CONFIG(whatsthis)
        sbChannels->setWhatsThis(tr2i18n("<b>Number of Tracks</b><br>Select a number of tracks of the new signal. If you are not sure now, you can add or delete tracks later in the program.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        sbResolution->setWhatsThis(tr2i18n("<b>Resolution</b><br>Select a resolution in bits in which the file will be saved. However, Kwave always uses 24 bits as its own internal resolution to give the best results when processing the audio data.", nullptr));
#endif // QT_CONFIG(whatsthis)
        GroupBox1->setTitle(tr2i18n("Length", nullptr));
        Frame3->setTitle(QString());
#if QT_CONFIG(tooltip)
        rbTime->setToolTip(tr2i18n("Select this to set the length of the file by time", nullptr));
#endif // QT_CONFIG(tooltip)
        rbTime->setText(tr2i18n("Time", nullptr));
#if QT_CONFIG(tooltip)
        rbSamples->setToolTip(tr2i18n("Select this to enter the number of samples directly", nullptr));
#endif // QT_CONFIG(tooltip)
        rbSamples->setText(tr2i18n("Samples", nullptr));
        lblSeconds->setText(tr2i18n("Seconds", nullptr));
        lblMinutes->setText(tr2i18n("Minutes", nullptr));
        lblHours->setText(tr2i18n("Hours", nullptr));
        lblMaximumSize_2_2->setText(tr2i18n("Minimum", nullptr));
        TextLabel2_2->setText(tr2i18n("(File Size)", nullptr));
        lblMaximumSize_3->setText(tr2i18n("Maximum", nullptr));
#if QT_CONFIG(tooltip)
        slideLength->setToolTip(tr2i18n("Sets the file size by the percentage of the possible maximum", nullptr));
#endif // QT_CONFIG(tooltip)
        TextLabel1->setText(tr2i18n("0%", nullptr));
        TextLabel3->setText(tr2i18n("50%", nullptr));
        TextLabel2->setText(tr2i18n("100%", nullptr));
        lblFileSize->setText(tr2i18n("%1", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewSigDlg: public Ui_NewSigDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWSIGDLG_H

