/********************************************************************************
** Form generated from reading UI file 'PitchShiftDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PITCHSHIFTDLG_H
#define UI_PITCHSHIFTDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "libgui/InvertableSpinBox.h"

QT_BEGIN_NAMESPACE

class Ui_PitchShiftDlg
{
public:
    QGridLayout *gridLayout;
    QFrame *Line1;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *btHelp;
    QPushButton *btListen;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;
    QLabel *textLabel1;
    QSlider *slFrequency;
    QLabel *textLabel2;
    QSpinBox *sbFrequency;
    QSlider *slSpeed;
    Kwave::InvertableSpinBox *sbSpeed;
    QGroupBox *buttonGroup3;
    QVBoxLayout *vboxLayout;
    QRadioButton *rbPercentage;
    QRadioButton *rbFactor;

    void setupUi(QDialog *PitchShiftDlg)
    {
        if (PitchShiftDlg->objectName().isEmpty())
            PitchShiftDlg->setObjectName("PitchShiftDlg");
        PitchShiftDlg->resize(605, 240);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PitchShiftDlg->sizePolicy().hasHeightForWidth());
        PitchShiftDlg->setSizePolicy(sizePolicy);
        PitchShiftDlg->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(PitchShiftDlg);
        gridLayout->setSpacing(10);
        gridLayout->setContentsMargins(10, 10, 10, 10);
        gridLayout->setObjectName("gridLayout");
        Line1 = new QFrame(PitchShiftDlg);
        Line1->setObjectName("Line1");
        Line1->setMinimumSize(QSize(0, 20));
        Line1->setFrameShape(QFrame::HLine);
        Line1->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(Line1, 3, 0, 1, 3);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setObjectName("hboxLayout");
        btHelp = new QDialogButtonBox(PitchShiftDlg);
        btHelp->setObjectName("btHelp");
        btHelp->setStandardButtons(QDialogButtonBox::Help);

        hboxLayout->addWidget(btHelp);

        btListen = new QPushButton(PitchShiftDlg);
        btListen->setObjectName("btListen");
        btListen->setCheckable(true);

        hboxLayout->addWidget(btListen);

        spacerItem = new QSpacerItem(60, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(PitchShiftDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 4, 0, 1, 3);

        textLabel1 = new QLabel(PitchShiftDlg);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout->addWidget(textLabel1, 2, 0, 1, 1);

        slFrequency = new QSlider(PitchShiftDlg);
        slFrequency->setObjectName("slFrequency");
        slFrequency->setMinimum(2);
        slFrequency->setMaximum(10);
        slFrequency->setPageStep(1);
        slFrequency->setValue(5);
        slFrequency->setOrientation(Qt::Horizontal);
        slFrequency->setTickInterval(1);

        gridLayout->addWidget(slFrequency, 2, 2, 1, 1);

        textLabel2 = new QLabel(PitchShiftDlg);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        sbFrequency = new QSpinBox(PitchShiftDlg);
        sbFrequency->setObjectName("sbFrequency");
        sbFrequency->setMinimum(2);
        sbFrequency->setMaximum(10);
        sbFrequency->setValue(5);

        gridLayout->addWidget(sbFrequency, 2, 1, 1, 1);

        slSpeed = new QSlider(PitchShiftDlg);
        slSpeed->setObjectName("slSpeed");
        slSpeed->setMinimumSize(QSize(400, 0));
        slSpeed->setMinimum(1);
        slSpeed->setMaximum(400);
        slSpeed->setValue(100);
        slSpeed->setOrientation(Qt::Horizontal);
        slSpeed->setTickInterval(50);

        gridLayout->addWidget(slSpeed, 1, 2, 1, 1);

        sbSpeed = new Kwave::InvertableSpinBox(PitchShiftDlg);
        sbSpeed->setObjectName("sbSpeed");

        gridLayout->addWidget(sbSpeed, 1, 1, 1, 1);

        buttonGroup3 = new QGroupBox(PitchShiftDlg);
        buttonGroup3->setObjectName("buttonGroup3");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonGroup3->sizePolicy().hasHeightForWidth());
        buttonGroup3->setSizePolicy(sizePolicy1);
        vboxLayout = new QVBoxLayout(buttonGroup3);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        rbPercentage = new QRadioButton(buttonGroup3);
        rbPercentage->setObjectName("rbPercentage");
        rbPercentage->setChecked(true);

        vboxLayout->addWidget(rbPercentage);

        rbFactor = new QRadioButton(buttonGroup3);
        rbFactor->setObjectName("rbFactor");

        vboxLayout->addWidget(rbFactor);


        gridLayout->addWidget(buttonGroup3, 0, 0, 1, 3);

        QWidget::setTabOrder(slSpeed, sbFrequency);
        QWidget::setTabOrder(sbFrequency, slFrequency);
        QWidget::setTabOrder(slFrequency, btListen);
        QWidget::setTabOrder(btListen, rbPercentage);

        retranslateUi(PitchShiftDlg);
        QObject::connect(sbFrequency, &QSpinBox::valueChanged, slFrequency, &QSlider::setValue);
        QObject::connect(slFrequency, &QSlider::valueChanged, sbFrequency, &QSpinBox::setValue);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, PitchShiftDlg, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, PitchShiftDlg, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(PitchShiftDlg);
    } // setupUi

    void retranslateUi(QDialog *PitchShiftDlg)
    {
        PitchShiftDlg->setWindowTitle(tr2i18n("Pitch Shift", nullptr));
#if QT_CONFIG(tooltip)
        btListen->setToolTip(tr2i18n("start/stop pre-listening", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        btListen->setWhatsThis(tr2i18n("Start or stop the pre-listening of the current settings. If pre-listening is enabled, you will nearly immediately hear any change in the selected parameters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btListen->setText(tr2i18n("&Listen", nullptr));
        textLabel1->setText(tr2i18n("Frequency:", nullptr));
#if QT_CONFIG(tooltip)
        slFrequency->setToolTip(tr2i18n("chopper frequency", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        slFrequency->setWhatsThis(tr2i18n("<b>chopper frequency</b><br>This setting determines how small the pieces of audio data are before they get processed by the pitch shift. If your audio data sounds interrupted, you might get better result with higher values.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel2->setText(tr2i18n("Speed:", nullptr));
#if QT_CONFIG(tooltip)
        sbFrequency->setToolTip(tr2i18n("chopper frequency", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sbFrequency->setWhatsThis(tr2i18n("<b>chopper frequency</b><br>This setting determines how small the pieces of audio data are before they get processed by the pitch shift. If your audio data sounds interrupted, you might get better result with higher values.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbFrequency->setSuffix(tr2i18n(" Hz", nullptr));
#if QT_CONFIG(tooltip)
        slSpeed->setToolTip(tr2i18n("Speed", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        sbSpeed->setToolTip(tr2i18n("Speed", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonGroup3->setTitle(tr2i18n("Mode", nullptr));
#if QT_CONFIG(tooltip)
        rbPercentage->setToolTip(tr2i18n("change speed by percentage", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbPercentage->setWhatsThis(tr2i18n("Sets the speed to a relative percentage of the original speed.\n"
"For example: \"50 %\", \"75%\" or \"125%\"", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbPercentage->setText(tr2i18n("by Percentage", nullptr));
#if QT_CONFIG(tooltip)
        rbFactor->setToolTip(tr2i18n("change speed by a factor", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        rbFactor->setWhatsThis(tr2i18n("Increments or decrements the speed by a factor.\n"
"For example: \"x1\", \"x2\", \"/ 4\"", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbFactor->setText(tr2i18n("by Factor", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PitchShiftDlg: public Ui_PitchShiftDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PITCHSHIFTDLG_H

