/********************************************************************************
** Form generated from reading UI file 'MP3EncoderDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MP3ENCODERDIALOGBASE_H
#define UI_MP3ENCODERDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_MP3EncoderDialogBase
{
public:
    QGridLayout *gridLayout_7;
    QGroupBox *grpProgram;
    QGridLayout *gridLayout_2;
    QFrame *frame;
    QPushButton *btSearch;
    QHBoxLayout *horizontalLayout_3;
    KComboBox *cbProgram;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *btDetect;
    QPushButton *btEncoderHelp;
    QLineEdit *edPath;
    QLabel *lblPath;
    QPushButton *btLocate;
    QGroupBox *grpParameters;
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tabInput;
    QGridLayout *gridLayout;
    QLabel *lblSign;
    QLineEdit *edByteOrder;
    QLineEdit *edRawFormat;
    QSpacerItem *verticalSpacer_4;
    QLabel *lblRawFormat;
    QLabel *lblByteOrder;
    QLineEdit *edSign;
    QWidget *tabFormat;
    QGridLayout *gridLayout_5;
    QLabel *lblSampleRate;
    QLineEdit *edSampleRate;
    QLabel *lblBitsPerSample;
    QLineEdit *edBitsPerSample;
    QLabel *lblChannels;
    QLabel *lblMono;
    QLineEdit *edMono;
    QLabel *lblStereo;
    QLineEdit *edStereo;
    QSpacerItem *verticalSpacer_3;
    QWidget *tabQuality;
    QGridLayout *gridLayout_3;
    QLabel *lblBitrateMax;
    QLabel *lblBitrateMin;
    QSpacerItem *verticalSpacer_8;
    QLineEdit *edBitrateMin;
    QLineEdit *edBitrateMax;
    QLabel *lblBitrate;
    QLabel *lblBitrateAvg;
    QLineEdit *edBitrateAvg;
    QWidget *tabEncoding;
    QGridLayout *gridLayout_9;
    QLabel *lblEmphasis;
    QLabel *lblEmphasisNone;
    QLineEdit *edEmphasisNone;
    QLabel *lblEmphasis5015ms;
    QLineEdit *edEmphasis5015ms;
    QLabel *lblEmphasisCCIT_J17;
    QLineEdit *edEmphasisCCIT_J17;
    QLabel *lblNoiseShaping;
    QLineEdit *edNoiseShaping;
    QLabel *lblCompatibility;
    QLineEdit *edCompatibility;
    QSpacerItem *verticalSpacer_9;
    QWidget *tabFlags;
    QGridLayout *gridLayout_4;
    QLabel *lblCopyright;
    QLineEdit *edCopyright;
    QLabel *lblOriginal;
    QLineEdit *edOriginal;
    QLabel *lblProtect;
    QLineEdit *edProtect;
    QFrame *frame_3;
    QLabel *lblPrepend;
    QLineEdit *edPrepend;
    QLabel *lblAppend;
    QLineEdit *edAppend;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab;
    QGridLayout *gridLayout_6;
    QLabel *lblHelp;
    QLineEdit *edEncoderHelp;
    QLabel *lblEncoderInfo;
    QSpacerItem *verticalSpacer_10;
    QLineEdit *edVersionInfo;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox_Help;
    QPushButton *btTest;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *MP3EncoderDialogBase)
    {
        if (MP3EncoderDialogBase->objectName().isEmpty())
            MP3EncoderDialogBase->setObjectName("MP3EncoderDialogBase");
        MP3EncoderDialogBase->resize(678, 564);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MP3EncoderDialogBase->sizePolicy().hasHeightForWidth());
        MP3EncoderDialogBase->setSizePolicy(sizePolicy);
        gridLayout_7 = new QGridLayout(MP3EncoderDialogBase);
        gridLayout_7->setObjectName("gridLayout_7");
        grpProgram = new QGroupBox(MP3EncoderDialogBase);
        grpProgram->setObjectName("grpProgram");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(grpProgram->sizePolicy().hasHeightForWidth());
        grpProgram->setSizePolicy(sizePolicy1);
        gridLayout_2 = new QGridLayout(grpProgram);
        gridLayout_2->setObjectName("gridLayout_2");
        frame = new QFrame(grpProgram);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy2);
        frame->setFrameShape(QFrame::HLine);
        frame->setFrameShadow(QFrame::Raised);

        gridLayout_2->addWidget(frame, 1, 0, 1, 7);

        btSearch = new QPushButton(grpProgram);
        btSearch->setObjectName("btSearch");

        gridLayout_2->addWidget(btSearch, 2, 6, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        cbProgram = new KComboBox(grpProgram);
        cbProgram->setObjectName("cbProgram");

        horizontalLayout_3->addWidget(cbProgram);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        btDetect = new QPushButton(grpProgram);
        btDetect->setObjectName("btDetect");

        horizontalLayout_3->addWidget(btDetect);

        horizontalLayout_3->setStretch(0, 1);

        gridLayout_2->addLayout(horizontalLayout_3, 0, 0, 1, 7);

        btEncoderHelp = new QPushButton(grpProgram);
        btEncoderHelp->setObjectName("btEncoderHelp");

        gridLayout_2->addWidget(btEncoderHelp, 2, 4, 1, 1);

        edPath = new QLineEdit(grpProgram);
        edPath->setObjectName("edPath");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(100);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(edPath->sizePolicy().hasHeightForWidth());
        edPath->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(edPath, 2, 1, 1, 1);

        lblPath = new QLabel(grpProgram);
        lblPath->setObjectName("lblPath");

        gridLayout_2->addWidget(lblPath, 2, 0, 1, 1);

        btLocate = new QPushButton(grpProgram);
        btLocate->setObjectName("btLocate");

        gridLayout_2->addWidget(btLocate, 2, 5, 1, 1);


        gridLayout_7->addWidget(grpProgram, 0, 0, 1, 1);

        grpParameters = new QGroupBox(MP3EncoderDialogBase);
        grpParameters->setObjectName("grpParameters");
        verticalLayout = new QVBoxLayout(grpParameters);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(grpParameters);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy4);
        tabInput = new QWidget();
        tabInput->setObjectName("tabInput");
        gridLayout = new QGridLayout(tabInput);
        gridLayout->setObjectName("gridLayout");
        lblSign = new QLabel(tabInput);
        lblSign->setObjectName("lblSign");

        gridLayout->addWidget(lblSign, 2, 0, 1, 2);

        edByteOrder = new QLineEdit(tabInput);
        edByteOrder->setObjectName("edByteOrder");
        sizePolicy3.setHeightForWidth(edByteOrder->sizePolicy().hasHeightForWidth());
        edByteOrder->setSizePolicy(sizePolicy3);
        edByteOrder->setMinimumSize(QSize(200, 0));

        gridLayout->addWidget(edByteOrder, 1, 2, 1, 1);

        edRawFormat = new QLineEdit(tabInput);
        edRawFormat->setObjectName("edRawFormat");
        sizePolicy3.setHeightForWidth(edRawFormat->sizePolicy().hasHeightForWidth());
        edRawFormat->setSizePolicy(sizePolicy3);
        edRawFormat->setMinimumSize(QSize(200, 0));

        gridLayout->addWidget(edRawFormat, 0, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 85, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_4, 3, 2, 1, 1);

        lblRawFormat = new QLabel(tabInput);
        lblRawFormat->setObjectName("lblRawFormat");

        gridLayout->addWidget(lblRawFormat, 0, 0, 1, 2);

        lblByteOrder = new QLabel(tabInput);
        lblByteOrder->setObjectName("lblByteOrder");

        gridLayout->addWidget(lblByteOrder, 1, 0, 1, 2);

        edSign = new QLineEdit(tabInput);
        edSign->setObjectName("edSign");
        sizePolicy3.setHeightForWidth(edSign->sizePolicy().hasHeightForWidth());
        edSign->setSizePolicy(sizePolicy3);
        edSign->setMinimumSize(QSize(200, 0));

        gridLayout->addWidget(edSign, 2, 2, 1, 1);

        tabWidget->addTab(tabInput, QString());
        tabFormat = new QWidget();
        tabFormat->setObjectName("tabFormat");
        gridLayout_5 = new QGridLayout(tabFormat);
        gridLayout_5->setObjectName("gridLayout_5");
        lblSampleRate = new QLabel(tabFormat);
        lblSampleRate->setObjectName("lblSampleRate");

        gridLayout_5->addWidget(lblSampleRate, 0, 0, 1, 2);

        edSampleRate = new QLineEdit(tabFormat);
        edSampleRate->setObjectName("edSampleRate");
        sizePolicy3.setHeightForWidth(edSampleRate->sizePolicy().hasHeightForWidth());
        edSampleRate->setSizePolicy(sizePolicy3);
        edSampleRate->setMinimumSize(QSize(200, 0));

        gridLayout_5->addWidget(edSampleRate, 0, 2, 1, 1);

        lblBitsPerSample = new QLabel(tabFormat);
        lblBitsPerSample->setObjectName("lblBitsPerSample");

        gridLayout_5->addWidget(lblBitsPerSample, 1, 0, 1, 2);

        edBitsPerSample = new QLineEdit(tabFormat);
        edBitsPerSample->setObjectName("edBitsPerSample");
        sizePolicy3.setHeightForWidth(edBitsPerSample->sizePolicy().hasHeightForWidth());
        edBitsPerSample->setSizePolicy(sizePolicy3);
        edBitsPerSample->setMinimumSize(QSize(200, 0));

        gridLayout_5->addWidget(edBitsPerSample, 1, 2, 1, 1);

        lblChannels = new QLabel(tabFormat);
        lblChannels->setObjectName("lblChannels");

        gridLayout_5->addWidget(lblChannels, 2, 0, 1, 1);

        lblMono = new QLabel(tabFormat);
        lblMono->setObjectName("lblMono");
        sizePolicy1.setHeightForWidth(lblMono->sizePolicy().hasHeightForWidth());
        lblMono->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(lblMono, 2, 1, 1, 1);

        edMono = new QLineEdit(tabFormat);
        edMono->setObjectName("edMono");
        sizePolicy3.setHeightForWidth(edMono->sizePolicy().hasHeightForWidth());
        edMono->setSizePolicy(sizePolicy3);
        edMono->setMinimumSize(QSize(200, 0));

        gridLayout_5->addWidget(edMono, 2, 2, 1, 1);

        lblStereo = new QLabel(tabFormat);
        lblStereo->setObjectName("lblStereo");
        sizePolicy1.setHeightForWidth(lblStereo->sizePolicy().hasHeightForWidth());
        lblStereo->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(lblStereo, 3, 1, 1, 1);

        edStereo = new QLineEdit(tabFormat);
        edStereo->setObjectName("edStereo");
        sizePolicy3.setHeightForWidth(edStereo->sizePolicy().hasHeightForWidth());
        edStereo->setSizePolicy(sizePolicy3);
        edStereo->setMinimumSize(QSize(200, 0));

        gridLayout_5->addWidget(edStereo, 3, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 53, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_3, 4, 2, 1, 1);

        tabWidget->addTab(tabFormat, QString());
        tabQuality = new QWidget();
        tabQuality->setObjectName("tabQuality");
        gridLayout_3 = new QGridLayout(tabQuality);
        gridLayout_3->setObjectName("gridLayout_3");
        lblBitrateMax = new QLabel(tabQuality);
        lblBitrateMax->setObjectName("lblBitrateMax");
        sizePolicy1.setHeightForWidth(lblBitrateMax->sizePolicy().hasHeightForWidth());
        lblBitrateMax->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(lblBitrateMax, 2, 1, 1, 1);

        lblBitrateMin = new QLabel(tabQuality);
        lblBitrateMin->setObjectName("lblBitrateMin");
        sizePolicy1.setHeightForWidth(lblBitrateMin->sizePolicy().hasHeightForWidth());
        lblBitrateMin->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(lblBitrateMin, 1, 1, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 85, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_8, 3, 2, 1, 1);

        edBitrateMin = new QLineEdit(tabQuality);
        edBitrateMin->setObjectName("edBitrateMin");
        sizePolicy3.setHeightForWidth(edBitrateMin->sizePolicy().hasHeightForWidth());
        edBitrateMin->setSizePolicy(sizePolicy3);
        edBitrateMin->setMinimumSize(QSize(100, 0));

        gridLayout_3->addWidget(edBitrateMin, 1, 2, 1, 1);

        edBitrateMax = new QLineEdit(tabQuality);
        edBitrateMax->setObjectName("edBitrateMax");
        sizePolicy3.setHeightForWidth(edBitrateMax->sizePolicy().hasHeightForWidth());
        edBitrateMax->setSizePolicy(sizePolicy3);
        edBitrateMax->setMinimumSize(QSize(100, 0));

        gridLayout_3->addWidget(edBitrateMax, 2, 2, 1, 1);

        lblBitrate = new QLabel(tabQuality);
        lblBitrate->setObjectName("lblBitrate");

        gridLayout_3->addWidget(lblBitrate, 0, 0, 1, 1);

        lblBitrateAvg = new QLabel(tabQuality);
        lblBitrateAvg->setObjectName("lblBitrateAvg");
        sizePolicy1.setHeightForWidth(lblBitrateAvg->sizePolicy().hasHeightForWidth());
        lblBitrateAvg->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(lblBitrateAvg, 0, 1, 1, 1);

        edBitrateAvg = new QLineEdit(tabQuality);
        edBitrateAvg->setObjectName("edBitrateAvg");
        sizePolicy3.setHeightForWidth(edBitrateAvg->sizePolicy().hasHeightForWidth());
        edBitrateAvg->setSizePolicy(sizePolicy3);
        edBitrateAvg->setMinimumSize(QSize(100, 0));

        gridLayout_3->addWidget(edBitrateAvg, 0, 2, 1, 1);

        tabWidget->addTab(tabQuality, QString());
        tabEncoding = new QWidget();
        tabEncoding->setObjectName("tabEncoding");
        gridLayout_9 = new QGridLayout(tabEncoding);
        gridLayout_9->setObjectName("gridLayout_9");
        lblEmphasis = new QLabel(tabEncoding);
        lblEmphasis->setObjectName("lblEmphasis");

        gridLayout_9->addWidget(lblEmphasis, 0, 0, 1, 1);

        lblEmphasisNone = new QLabel(tabEncoding);
        lblEmphasisNone->setObjectName("lblEmphasisNone");
        sizePolicy1.setHeightForWidth(lblEmphasisNone->sizePolicy().hasHeightForWidth());
        lblEmphasisNone->setSizePolicy(sizePolicy1);

        gridLayout_9->addWidget(lblEmphasisNone, 0, 1, 1, 1);

        edEmphasisNone = new QLineEdit(tabEncoding);
        edEmphasisNone->setObjectName("edEmphasisNone");
        sizePolicy3.setHeightForWidth(edEmphasisNone->sizePolicy().hasHeightForWidth());
        edEmphasisNone->setSizePolicy(sizePolicy3);
        edEmphasisNone->setMinimumSize(QSize(100, 0));
        edEmphasisNone->setMaximumSize(QSize(16777215, 16777215));

        gridLayout_9->addWidget(edEmphasisNone, 0, 2, 1, 1);

        lblEmphasis5015ms = new QLabel(tabEncoding);
        lblEmphasis5015ms->setObjectName("lblEmphasis5015ms");
        sizePolicy1.setHeightForWidth(lblEmphasis5015ms->sizePolicy().hasHeightForWidth());
        lblEmphasis5015ms->setSizePolicy(sizePolicy1);

        gridLayout_9->addWidget(lblEmphasis5015ms, 1, 1, 1, 1);

        edEmphasis5015ms = new QLineEdit(tabEncoding);
        edEmphasis5015ms->setObjectName("edEmphasis5015ms");
        sizePolicy3.setHeightForWidth(edEmphasis5015ms->sizePolicy().hasHeightForWidth());
        edEmphasis5015ms->setSizePolicy(sizePolicy3);
        edEmphasis5015ms->setMinimumSize(QSize(100, 0));

        gridLayout_9->addWidget(edEmphasis5015ms, 1, 2, 1, 1);

        lblEmphasisCCIT_J17 = new QLabel(tabEncoding);
        lblEmphasisCCIT_J17->setObjectName("lblEmphasisCCIT_J17");
        sizePolicy1.setHeightForWidth(lblEmphasisCCIT_J17->sizePolicy().hasHeightForWidth());
        lblEmphasisCCIT_J17->setSizePolicy(sizePolicy1);

        gridLayout_9->addWidget(lblEmphasisCCIT_J17, 2, 1, 1, 1);

        edEmphasisCCIT_J17 = new QLineEdit(tabEncoding);
        edEmphasisCCIT_J17->setObjectName("edEmphasisCCIT_J17");
        sizePolicy3.setHeightForWidth(edEmphasisCCIT_J17->sizePolicy().hasHeightForWidth());
        edEmphasisCCIT_J17->setSizePolicy(sizePolicy3);
        edEmphasisCCIT_J17->setMinimumSize(QSize(100, 0));

        gridLayout_9->addWidget(edEmphasisCCIT_J17, 2, 2, 1, 1);

        lblNoiseShaping = new QLabel(tabEncoding);
        lblNoiseShaping->setObjectName("lblNoiseShaping");

        gridLayout_9->addWidget(lblNoiseShaping, 3, 0, 1, 2);

        edNoiseShaping = new QLineEdit(tabEncoding);
        edNoiseShaping->setObjectName("edNoiseShaping");
        sizePolicy3.setHeightForWidth(edNoiseShaping->sizePolicy().hasHeightForWidth());
        edNoiseShaping->setSizePolicy(sizePolicy3);
        edNoiseShaping->setMinimumSize(QSize(200, 0));

        gridLayout_9->addWidget(edNoiseShaping, 3, 2, 1, 1);

        lblCompatibility = new QLabel(tabEncoding);
        lblCompatibility->setObjectName("lblCompatibility");

        gridLayout_9->addWidget(lblCompatibility, 4, 0, 1, 2);

        edCompatibility = new QLineEdit(tabEncoding);
        edCompatibility->setObjectName("edCompatibility");
        sizePolicy3.setHeightForWidth(edCompatibility->sizePolicy().hasHeightForWidth());
        edCompatibility->setSizePolicy(sizePolicy3);
        edCompatibility->setMinimumSize(QSize(200, 0));

        gridLayout_9->addWidget(edCompatibility, 4, 2, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_9, 5, 2, 1, 1);

        tabWidget->addTab(tabEncoding, QString());
        tabFlags = new QWidget();
        tabFlags->setObjectName("tabFlags");
        gridLayout_4 = new QGridLayout(tabFlags);
        gridLayout_4->setObjectName("gridLayout_4");
        lblCopyright = new QLabel(tabFlags);
        lblCopyright->setObjectName("lblCopyright");
        sizePolicy1.setHeightForWidth(lblCopyright->sizePolicy().hasHeightForWidth());
        lblCopyright->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(lblCopyright, 0, 0, 1, 1);

        edCopyright = new QLineEdit(tabFlags);
        edCopyright->setObjectName("edCopyright");
        sizePolicy3.setHeightForWidth(edCopyright->sizePolicy().hasHeightForWidth());
        edCopyright->setSizePolicy(sizePolicy3);
        edCopyright->setMinimumSize(QSize(200, 0));

        gridLayout_4->addWidget(edCopyright, 0, 1, 1, 1);

        lblOriginal = new QLabel(tabFlags);
        lblOriginal->setObjectName("lblOriginal");
        sizePolicy1.setHeightForWidth(lblOriginal->sizePolicy().hasHeightForWidth());
        lblOriginal->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(lblOriginal, 1, 0, 1, 1);

        edOriginal = new QLineEdit(tabFlags);
        edOriginal->setObjectName("edOriginal");
        sizePolicy3.setHeightForWidth(edOriginal->sizePolicy().hasHeightForWidth());
        edOriginal->setSizePolicy(sizePolicy3);
        edOriginal->setMinimumSize(QSize(200, 0));

        gridLayout_4->addWidget(edOriginal, 1, 1, 1, 1);

        lblProtect = new QLabel(tabFlags);
        lblProtect->setObjectName("lblProtect");
        sizePolicy1.setHeightForWidth(lblProtect->sizePolicy().hasHeightForWidth());
        lblProtect->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(lblProtect, 2, 0, 1, 1);

        edProtect = new QLineEdit(tabFlags);
        edProtect->setObjectName("edProtect");
        sizePolicy3.setHeightForWidth(edProtect->sizePolicy().hasHeightForWidth());
        edProtect->setSizePolicy(sizePolicy3);
        edProtect->setMinimumSize(QSize(200, 0));

        gridLayout_4->addWidget(edProtect, 2, 1, 1, 1);

        frame_3 = new QFrame(tabFlags);
        frame_3->setObjectName("frame_3");
        sizePolicy2.setHeightForWidth(frame_3->sizePolicy().hasHeightForWidth());
        frame_3->setSizePolicy(sizePolicy2);
        frame_3->setFrameShape(QFrame::HLine);
        frame_3->setFrameShadow(QFrame::Raised);

        gridLayout_4->addWidget(frame_3, 3, 0, 1, 2);

        lblPrepend = new QLabel(tabFlags);
        lblPrepend->setObjectName("lblPrepend");

        gridLayout_4->addWidget(lblPrepend, 4, 0, 1, 1);

        edPrepend = new QLineEdit(tabFlags);
        edPrepend->setObjectName("edPrepend");
        sizePolicy3.setHeightForWidth(edPrepend->sizePolicy().hasHeightForWidth());
        edPrepend->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(edPrepend, 4, 1, 1, 1);

        lblAppend = new QLabel(tabFlags);
        lblAppend->setObjectName("lblAppend");

        gridLayout_4->addWidget(lblAppend, 5, 0, 1, 1);

        edAppend = new QLineEdit(tabFlags);
        edAppend->setObjectName("edAppend");
        sizePolicy3.setHeightForWidth(edAppend->sizePolicy().hasHeightForWidth());
        edAppend->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(edAppend, 5, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_2, 6, 1, 1, 1);

        tabWidget->addTab(tabFlags, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_6 = new QGridLayout(tab);
        gridLayout_6->setObjectName("gridLayout_6");
        lblHelp = new QLabel(tab);
        lblHelp->setObjectName("lblHelp");

        gridLayout_6->addWidget(lblHelp, 0, 0, 1, 1);

        edEncoderHelp = new QLineEdit(tab);
        edEncoderHelp->setObjectName("edEncoderHelp");
        sizePolicy3.setHeightForWidth(edEncoderHelp->sizePolicy().hasHeightForWidth());
        edEncoderHelp->setSizePolicy(sizePolicy3);
        edEncoderHelp->setMinimumSize(QSize(100, 0));
        edEncoderHelp->setMaximumSize(QSize(16777215, 16777215));

        gridLayout_6->addWidget(edEncoderHelp, 0, 1, 2, 1);

        lblEncoderInfo = new QLabel(tab);
        lblEncoderInfo->setObjectName("lblEncoderInfo");

        gridLayout_6->addWidget(lblEncoderInfo, 1, 0, 2, 1);

        verticalSpacer_10 = new QSpacerItem(20, 116, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_10, 3, 1, 1, 1);

        edVersionInfo = new QLineEdit(tab);
        edVersionInfo->setObjectName("edVersionInfo");
        sizePolicy3.setHeightForWidth(edVersionInfo->sizePolicy().hasHeightForWidth());
        edVersionInfo->setSizePolicy(sizePolicy3);
        edVersionInfo->setMinimumSize(QSize(100, 0));
        edVersionInfo->setMaximumSize(QSize(16777215, 16777215));

        gridLayout_6->addWidget(edVersionInfo, 2, 1, 1, 1);

        tabWidget->addTab(tab, QString());

        verticalLayout->addWidget(tabWidget);


        gridLayout_7->addWidget(grpParameters, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout_7->addItem(verticalSpacer, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonBox_Help = new QDialogButtonBox(MP3EncoderDialogBase);
        buttonBox_Help->setObjectName("buttonBox_Help");
        buttonBox_Help->setStandardButtons(QDialogButtonBox::Help);

        horizontalLayout->addWidget(buttonBox_Help);

        btTest = new QPushButton(MP3EncoderDialogBase);
        btTest->setObjectName("btTest");

        horizontalLayout->addWidget(btTest);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(MP3EncoderDialogBase);
        buttonBox->setObjectName("buttonBox");
        sizePolicy2.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy2);
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset|QDialogButtonBox::RestoreDefaults);

        horizontalLayout->addWidget(buttonBox);


        gridLayout_7->addLayout(horizontalLayout, 3, 0, 1, 1);

        QWidget::setTabOrder(cbProgram, btDetect);
        QWidget::setTabOrder(btDetect, edPath);
        QWidget::setTabOrder(edPath, btEncoderHelp);
        QWidget::setTabOrder(btEncoderHelp, btLocate);
        QWidget::setTabOrder(btLocate, btSearch);
        QWidget::setTabOrder(btSearch, tabWidget);
        QWidget::setTabOrder(tabWidget, edRawFormat);
        QWidget::setTabOrder(edRawFormat, edByteOrder);
        QWidget::setTabOrder(edByteOrder, edSign);
        QWidget::setTabOrder(edSign, edSampleRate);
        QWidget::setTabOrder(edSampleRate, edBitsPerSample);
        QWidget::setTabOrder(edBitsPerSample, edMono);
        QWidget::setTabOrder(edMono, edStereo);
        QWidget::setTabOrder(edStereo, edBitrateAvg);
        QWidget::setTabOrder(edBitrateAvg, edBitrateMin);
        QWidget::setTabOrder(edBitrateMin, edBitrateMax);
        QWidget::setTabOrder(edBitrateMax, edEmphasisNone);
        QWidget::setTabOrder(edEmphasisNone, edEmphasis5015ms);
        QWidget::setTabOrder(edEmphasis5015ms, edEmphasisCCIT_J17);
        QWidget::setTabOrder(edEmphasisCCIT_J17, edNoiseShaping);
        QWidget::setTabOrder(edNoiseShaping, edCompatibility);
        QWidget::setTabOrder(edCompatibility, edCopyright);
        QWidget::setTabOrder(edCopyright, edOriginal);
        QWidget::setTabOrder(edOriginal, edProtect);
        QWidget::setTabOrder(edProtect, edPrepend);
        QWidget::setTabOrder(edPrepend, edAppend);
        QWidget::setTabOrder(edAppend, edEncoderHelp);
        QWidget::setTabOrder(edEncoderHelp, edVersionInfo);
        QWidget::setTabOrder(edVersionInfo, btTest);

        retranslateUi(MP3EncoderDialogBase);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, MP3EncoderDialogBase, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, MP3EncoderDialogBase, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(5);


        QMetaObject::connectSlotsByName(MP3EncoderDialogBase);
    } // setupUi

    void retranslateUi(QDialog *MP3EncoderDialogBase)
    {
        MP3EncoderDialogBase->setWindowTitle(tr2i18n("MP3 Encoder Settings", nullptr));
        grpProgram->setTitle(tr2i18n("Program", nullptr));
#if QT_CONFIG(tooltip)
        btSearch->setToolTip(tr2i18n("manually browse for the encoder", nullptr));
#endif // QT_CONFIG(tooltip)
        btSearch->setText(tr2i18n("&Select...", nullptr));
#if QT_CONFIG(tooltip)
        cbProgram->setToolTip(tr2i18n("select one of the predefined encoder setups", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        btDetect->setToolTip(tr2i18n("auto-detect the installed encoder", nullptr));
#endif // QT_CONFIG(tooltip)
        btDetect->setText(tr2i18n("&Auto Detect...", nullptr));
#if QT_CONFIG(tooltip)
        btEncoderHelp->setToolTip(tr2i18n("show the usage information of the encoder", nullptr));
#endif // QT_CONFIG(tooltip)
        btEncoderHelp->setText(tr2i18n("&Usage", nullptr));
#if QT_CONFIG(tooltip)
        edPath->setToolTip(tr2i18n("path to the encoder", nullptr));
#endif // QT_CONFIG(tooltip)
        edPath->setText(QString());
        lblPath->setText(tr2i18n("Path:", nullptr));
#if QT_CONFIG(tooltip)
        btLocate->setToolTip(tr2i18n("find the full path to the encoder", nullptr));
#endif // QT_CONFIG(tooltip)
        btLocate->setText(tr2i18n("&Locate", nullptr));
        grpParameters->setTitle(tr2i18n("Parameters", nullptr));
        lblSign->setText(tr2i18n("Sign:", nullptr));
#if QT_CONFIG(tooltip)
        edByteOrder->setToolTip(tr2i18n("parameter for switching the byte order", nullptr));
#endif // QT_CONFIG(tooltip)
        edByteOrder->setText(QString());
#if QT_CONFIG(tooltip)
        edRawFormat->setToolTip(tr2i18n("parameter for telling the encoder to use raw data as input format", nullptr));
#endif // QT_CONFIG(tooltip)
        edRawFormat->setText(QString());
        lblRawFormat->setText(tr2i18n("Raw Format:", nullptr));
        lblByteOrder->setText(tr2i18n("Byte Order:", nullptr));
#if QT_CONFIG(tooltip)
        edSign->setToolTip(tr2i18n("parameter to use signed sample format", nullptr));
#endif // QT_CONFIG(tooltip)
        edSign->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabInput), tr2i18n("Input", nullptr));
        lblSampleRate->setText(tr2i18n("Sample Rate:", nullptr));
        edSampleRate->setText(QString());
        lblBitsPerSample->setText(tr2i18n("Bits per Sample:", nullptr));
        edBitsPerSample->setText(QString());
        lblChannels->setText(tr2i18n("Channels:", nullptr));
        lblMono->setText(tr2i18n("mono:", nullptr));
#if QT_CONFIG(tooltip)
        edMono->setToolTip(tr2i18n("parameter for single channel files (mono)", nullptr));
#endif // QT_CONFIG(tooltip)
        edMono->setText(QString());
        lblStereo->setText(tr2i18n("stereo:", nullptr));
#if QT_CONFIG(tooltip)
        edStereo->setToolTip(tr2i18n("parameter for multi channel files\n"
"(stereo or more channels)", nullptr));
#endif // QT_CONFIG(tooltip)
        edStereo->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabFormat), tr2i18n("Format", nullptr));
        lblBitrateMax->setText(tr2i18n("max", nullptr));
        lblBitrateMin->setText(tr2i18n("min", nullptr));
        edBitrateMin->setText(QString());
        edBitrateMax->setText(QString());
        lblBitrate->setText(tr2i18n("Bitrate:", nullptr));
        lblBitrateAvg->setText(tr2i18n("avg", nullptr));
        edBitrateAvg->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabQuality), tr2i18n("Quality", nullptr));
        lblEmphasis->setText(tr2i18n("Emphasis:", nullptr));
        lblEmphasisNone->setText(tr2i18n("none", nullptr));
#if QT_CONFIG(tooltip)
        edEmphasisNone->setToolTip(tr2i18n("parameter for no emphasis", nullptr));
#endif // QT_CONFIG(tooltip)
        edEmphasisNone->setText(QString());
        lblEmphasis5015ms->setText(tr2i18n("50/15ms", nullptr));
#if QT_CONFIG(tooltip)
        edEmphasis5015ms->setToolTip(tr2i18n("parameter for 50/15ms emphasis", nullptr));
#endif // QT_CONFIG(tooltip)
        edEmphasis5015ms->setText(QString());
        lblEmphasisCCIT_J17->setText(tr2i18n("CCIT J17", nullptr));
#if QT_CONFIG(tooltip)
        edEmphasisCCIT_J17->setToolTip(tr2i18n("parameter for CCIT J17 emphasis", nullptr));
#endif // QT_CONFIG(tooltip)
        edEmphasisCCIT_J17->setText(QString());
        lblNoiseShaping->setText(tr2i18n("Noise Shaping:", nullptr));
#if QT_CONFIG(tooltip)
        edNoiseShaping->setToolTip(tr2i18n("parameters for configuring noise shaping", nullptr));
#endif // QT_CONFIG(tooltip)
        edNoiseShaping->setText(QString());
        lblCompatibility->setText(tr2i18n("Compatibility:", nullptr));
#if QT_CONFIG(tooltip)
        edCompatibility->setToolTip(tr2i18n("parameters for compatibility settings", nullptr));
#endif // QT_CONFIG(tooltip)
        edCompatibility->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabEncoding), tr2i18n("Encoding", nullptr));
        lblCopyright->setText(tr2i18n("Copyright:", nullptr));
#if QT_CONFIG(tooltip)
        edCopyright->setToolTip(tr2i18n("parameter for marking the file as copyrighted", nullptr));
#endif // QT_CONFIG(tooltip)
        edCopyright->setText(QString());
        lblOriginal->setText(tr2i18n("Original:", nullptr));
#if QT_CONFIG(tooltip)
        edOriginal->setToolTip(tr2i18n("parameter for marking the signal as original (not a copy)", nullptr));
#endif // QT_CONFIG(tooltip)
        edOriginal->setText(QString());
        lblProtect->setText(tr2i18n("Protect:", nullptr));
#if QT_CONFIG(tooltip)
        edProtect->setToolTip(tr2i18n("parameter to enable CRC protection", nullptr));
#endif // QT_CONFIG(tooltip)
        edProtect->setText(QString());
        lblPrepend->setText(tr2i18n("Prepend:", nullptr));
#if QT_CONFIG(tooltip)
        edPrepend->setToolTip(tr2i18n("additional parameters to put at the start of the encoder command line", nullptr));
#endif // QT_CONFIG(tooltip)
        edPrepend->setText(QString());
        lblAppend->setText(tr2i18n("Append:", nullptr));
#if QT_CONFIG(tooltip)
        edAppend->setToolTip(tr2i18n("additional parameters to append at the end of the encoder command line", nullptr));
#endif // QT_CONFIG(tooltip)
        edAppend->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tabFlags), tr2i18n("Flags", nullptr));
        lblHelp->setText(tr2i18n("Encoder Help:", nullptr));
#if QT_CONFIG(tooltip)
        edEncoderHelp->setToolTip(tr2i18n("parameter for getting usage information of the encoder", nullptr));
#endif // QT_CONFIG(tooltip)
        edEncoderHelp->setText(QString());
        lblEncoderInfo->setText(tr2i18n("Version Info:", nullptr));
#if QT_CONFIG(tooltip)
        edVersionInfo->setToolTip(tr2i18n("parameter for getting the encoder version information", nullptr));
#endif // QT_CONFIG(tooltip)
        edVersionInfo->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Info", nullptr));
#if QT_CONFIG(tooltip)
        btTest->setToolTip(tr2i18n("try to encode some short test signal with the current settings", nullptr));
#endif // QT_CONFIG(tooltip)
        btTest->setText(tr2i18n("Test...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MP3EncoderDialogBase: public Ui_MP3EncoderDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MP3ENCODERDIALOGBASE_H

