/****************************************************************************
** Meta object code from reading C++ file 'ZoomToolBar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/kwave/ZoomToolBar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ZoomToolBar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave11ZoomToolBarE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::ZoomToolBar::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave11ZoomToolBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::ZoomToolBar",
        "sigCommand",
        "",
        "command",
        "contextSwitched",
        "Kwave::FileContext*",
        "context",
        "contextDestroyed",
        "updateToolbar",
        "setZoomInfo",
        "zoom",
        "selectZoom",
        "index",
        "zoomSelection",
        "zoomIn",
        "zoomOut",
        "zoomNormal",
        "zoomAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigCommand'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'contextSwitched'
        QtMocHelpers::SlotData<void(Kwave::FileContext *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'contextDestroyed'
        QtMocHelpers::SlotData<void(Kwave::FileContext *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'updateToolbar'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setZoomInfo'
        QtMocHelpers::SlotData<void(Kwave::FileContext *, double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Double, 10 },
        }}),
        // Slot 'selectZoom'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'zoomSelection'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomNormal'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomAll'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ZoomToolBar, qt_meta_tag_ZN5Kwave11ZoomToolBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::ZoomToolBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KToolBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave11ZoomToolBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave11ZoomToolBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave11ZoomToolBarE_t>.metaTypes,
    nullptr
} };

void Kwave::ZoomToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ZoomToolBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->contextSwitched((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 2: _t->contextDestroyed((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 3: _t->updateToolbar(); break;
        case 4: _t->setZoomInfo((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 5: _t->selectZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->zoomSelection(); break;
        case 7: _t->zoomIn(); break;
        case 8: _t->zoomOut(); break;
        case 9: _t->zoomNormal(); break;
        case 10: _t->zoomAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ZoomToolBar::*)(const QString & )>(_a, &ZoomToolBar::sigCommand, 0))
            return;
    }
}

const QMetaObject *Kwave::ZoomToolBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::ZoomToolBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave11ZoomToolBarE_t>.strings))
        return static_cast<void*>(this);
    return KToolBar::qt_metacast(_clname);
}

int Kwave::ZoomToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KToolBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Kwave::ZoomToolBar::sigCommand(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
