/****************************************************************************
** Meta object code from reading C++ file 'PlayerToolBar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/kwave/PlayerToolBar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PlayerToolBar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave13PlayerToolBarE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::PlayerToolBar::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave13PlayerToolBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::PlayerToolBar",
        "sigCommand",
        "",
        "command",
        "sigSetMenuItemEnabled",
        "uid",
        "enable",
        "contextSwitched",
        "Kwave::FileContext*",
        "context",
        "contextDestroyed",
        "executeCommand",
        "metaDataChanged",
        "Kwave::MetaDataList",
        "meta_data",
        "visibleRangeChanged",
        "sample_index_t",
        "offset",
        "visible",
        "total",
        "toolbarRewindPrev",
        "toolbarRewind",
        "toolbarRecord",
        "toolbarStart",
        "toolbarLoop",
        "toolbarPause",
        "toolbarStop",
        "toolbarForward",
        "toolbarForwardNext",
        "updateState",
        "updatePlaybackPos",
        "pos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigCommand'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'sigSetMenuItemEnabled'
        QtMocHelpers::SignalData<void(const QString &, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'contextSwitched'
        QtMocHelpers::SlotData<void(Kwave::FileContext *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'contextDestroyed'
        QtMocHelpers::SlotData<void(Kwave::FileContext *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'executeCommand'
        QtMocHelpers::SlotData<int(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'metaDataChanged'
        QtMocHelpers::SlotData<void(Kwave::MetaDataList)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'visibleRangeChanged'
        QtMocHelpers::SlotData<void(sample_index_t, sample_index_t, sample_index_t)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { 0x80000000 | 16, 18 }, { 0x80000000 | 16, 19 },
        }}),
        // Slot 'toolbarRewindPrev'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarRewind'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarRecord'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarStart'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarLoop'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarPause'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarStop'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarForward'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarForwardNext'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateState'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePlaybackPos'
        QtMocHelpers::SlotData<void(sample_index_t)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlayerToolBar, qt_meta_tag_ZN5Kwave13PlayerToolBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::PlayerToolBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KToolBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave13PlayerToolBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave13PlayerToolBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave13PlayerToolBarE_t>.metaTypes,
    nullptr
} };

void Kwave::PlayerToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlayerToolBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->sigSetMenuItemEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->contextSwitched((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 3: _t->contextDestroyed((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 4: { int _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->metaDataChanged((*reinterpret_cast<std::add_pointer_t<Kwave::MetaDataList>>(_a[1]))); break;
        case 6: _t->visibleRangeChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 7: _t->toolbarRewindPrev(); break;
        case 8: _t->toolbarRewind(); break;
        case 9: _t->toolbarRecord(); break;
        case 10: _t->toolbarStart(); break;
        case 11: _t->toolbarLoop(); break;
        case 12: _t->toolbarPause(); break;
        case 13: _t->toolbarStop(); break;
        case 14: _t->toolbarForward(); break;
        case 15: _t->toolbarForwardNext(); break;
        case 16: _t->updateState(); break;
        case 17: _t->updatePlaybackPos((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlayerToolBar::*)(const QString & )>(_a, &PlayerToolBar::sigCommand, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerToolBar::*)(const QString & , bool )>(_a, &PlayerToolBar::sigSetMenuItemEnabled, 1))
            return;
    }
}

const QMetaObject *Kwave::PlayerToolBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::PlayerToolBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave13PlayerToolBarE_t>.strings))
        return static_cast<void*>(this);
    return KToolBar::qt_metacast(_clname);
}

int Kwave::PlayerToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KToolBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Kwave::PlayerToolBar::sigCommand(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kwave::PlayerToolBar::sigSetMenuItemEnabled(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
