/********************************************************************************
** Form generated from reading UI file 'SelectTimeWidgetBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTTIMEWIDGETBASE_H
#define UI_SELECTTIMEWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SelectTimeWidgetBase
{
public:
    QGridLayout *gridLayout;
    QRadioButton *rbSamples;
    QRadioButton *rbTime;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QRadioButton *rbPercents;
    QGridLayout *gridLayout1;
    QSpinBox *sbHours;
    QSpinBox *sbMilliseconds;
    QLabel *lblMinutes;
    QSpinBox *sbSeconds;
    QLabel *lblMilliSeconds;
    QLabel *lblSeconds;
    QSpinBox *sbMinutes;
    QLabel *lblHours;
    QSpinBox *edSamples;
    QGridLayout *gridLayout2;
    QSpinBox *sbPercents;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout;
    QLabel *TextLabel1_2;
    QSpacerItem *spacerItem3;
    QLabel *TextLabel3_2;
    QSpacerItem *spacerItem4;
    QLabel *TextLabel2_2;
    QSlider *slidePercents;

    void setupUi(QGroupBox *SelectTimeWidgetBase)
    {
        if (SelectTimeWidgetBase->objectName().isEmpty())
            SelectTimeWidgetBase->setObjectName("SelectTimeWidgetBase");
        SelectTimeWidgetBase->resize(481, 200);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SelectTimeWidgetBase->sizePolicy().hasHeightForWidth());
        SelectTimeWidgetBase->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(SelectTimeWidgetBase);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        rbSamples = new QRadioButton(SelectTimeWidgetBase);
        rbSamples->setObjectName("rbSamples");
        rbSamples->setFocusPolicy(Qt::NoFocus);
        rbSamples->setChecked(false);

        gridLayout->addWidget(rbSamples, 2, 0, 1, 1);

        rbTime = new QRadioButton(SelectTimeWidgetBase);
        rbTime->setObjectName("rbTime");
        rbTime->setFocusPolicy(Qt::NoFocus);
        rbTime->setChecked(false);

        gridLayout->addWidget(rbTime, 1, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 4, 0, 1, 1);

        rbPercents = new QRadioButton(SelectTimeWidgetBase);
        rbPercents->setObjectName("rbPercents");
        rbPercents->setChecked(true);

        gridLayout->addWidget(rbPercents, 3, 0, 1, 1);

        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(10);
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        sbHours = new QSpinBox(SelectTimeWidgetBase);
        sbHours->setObjectName("sbHours");
        sbHours->setEnabled(false);
        sbHours->setValue(99);

        gridLayout1->addWidget(sbHours, 1, 0, 1, 1);

        sbMilliseconds = new QSpinBox(SelectTimeWidgetBase);
        sbMilliseconds->setObjectName("sbMilliseconds");
        sbMilliseconds->setEnabled(false);
        sbMilliseconds->setWrapping(false);
        sbMilliseconds->setMinimum(-1);
        sbMilliseconds->setMaximum(1000);
        sbMilliseconds->setValue(0);

        gridLayout1->addWidget(sbMilliseconds, 1, 3, 1, 1);

        lblMinutes = new QLabel(SelectTimeWidgetBase);
        lblMinutes->setObjectName("lblMinutes");
        lblMinutes->setEnabled(false);
        sizePolicy.setHeightForWidth(lblMinutes->sizePolicy().hasHeightForWidth());
        lblMinutes->setSizePolicy(sizePolicy);
        lblMinutes->setWordWrap(false);

        gridLayout1->addWidget(lblMinutes, 0, 1, 1, 1);

        sbSeconds = new QSpinBox(SelectTimeWidgetBase);
        sbSeconds->setObjectName("sbSeconds");
        sbSeconds->setEnabled(false);
        sbSeconds->setWrapping(false);
        sbSeconds->setMinimum(-1);
        sbSeconds->setMaximum(60);
        sbSeconds->setValue(0);

        gridLayout1->addWidget(sbSeconds, 1, 2, 1, 1);

        lblMilliSeconds = new QLabel(SelectTimeWidgetBase);
        lblMilliSeconds->setObjectName("lblMilliSeconds");
        lblMilliSeconds->setEnabled(false);
        sizePolicy.setHeightForWidth(lblMilliSeconds->sizePolicy().hasHeightForWidth());
        lblMilliSeconds->setSizePolicy(sizePolicy);
        lblMilliSeconds->setWordWrap(false);

        gridLayout1->addWidget(lblMilliSeconds, 0, 3, 1, 1);

        lblSeconds = new QLabel(SelectTimeWidgetBase);
        lblSeconds->setObjectName("lblSeconds");
        lblSeconds->setEnabled(false);
        sizePolicy.setHeightForWidth(lblSeconds->sizePolicy().hasHeightForWidth());
        lblSeconds->setSizePolicy(sizePolicy);
        lblSeconds->setWordWrap(false);

        gridLayout1->addWidget(lblSeconds, 0, 2, 1, 1);

        sbMinutes = new QSpinBox(SelectTimeWidgetBase);
        sbMinutes->setObjectName("sbMinutes");
        sbMinutes->setEnabled(false);
        sbMinutes->setWrapping(false);
        sbMinutes->setMinimum(-1);
        sbMinutes->setMaximum(60);
        sbMinutes->setValue(0);

        gridLayout1->addWidget(sbMinutes, 1, 1, 1, 1);

        lblHours = new QLabel(SelectTimeWidgetBase);
        lblHours->setObjectName("lblHours");
        lblHours->setEnabled(false);
        sizePolicy.setHeightForWidth(lblHours->sizePolicy().hasHeightForWidth());
        lblHours->setSizePolicy(sizePolicy);
        lblHours->setWordWrap(false);

        gridLayout1->addWidget(lblHours, 0, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 1, 2, 1);

        edSamples = new QSpinBox(SelectTimeWidgetBase);
        edSamples->setObjectName("edSamples");
        edSamples->setEnabled(false);
        edSamples->setFocusPolicy(Qt::StrongFocus);

        gridLayout->addWidget(edSamples, 2, 1, 1, 1);

        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(10);
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout2->setObjectName("gridLayout2");
        sbPercents = new QSpinBox(SelectTimeWidgetBase);
        sbPercents->setObjectName("sbPercents");
        sbPercents->setMaximum(100);

        gridLayout2->addWidget(sbPercents, 0, 0, 1, 1);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(spacerItem2, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        TextLabel1_2 = new QLabel(SelectTimeWidgetBase);
        TextLabel1_2->setObjectName("TextLabel1_2");
        TextLabel1_2->setWordWrap(false);

        hboxLayout->addWidget(TextLabel1_2);

        spacerItem3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout->addItem(spacerItem3);

        TextLabel3_2 = new QLabel(SelectTimeWidgetBase);
        TextLabel3_2->setObjectName("TextLabel3_2");
        TextLabel3_2->setWordWrap(false);

        hboxLayout->addWidget(TextLabel3_2);

        spacerItem4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        hboxLayout->addItem(spacerItem4);

        TextLabel2_2 = new QLabel(SelectTimeWidgetBase);
        TextLabel2_2->setObjectName("TextLabel2_2");
        TextLabel2_2->setWordWrap(false);

        hboxLayout->addWidget(TextLabel2_2);


        gridLayout2->addLayout(hboxLayout, 1, 1, 1, 1);

        slidePercents = new QSlider(SelectTimeWidgetBase);
        slidePercents->setObjectName("slidePercents");
        slidePercents->setMinimumSize(QSize(0, 20));
        slidePercents->setFocusPolicy(Qt::TabFocus);
        slidePercents->setMinimum(0);
        slidePercents->setMaximum(100);
        slidePercents->setValue(1);
        slidePercents->setOrientation(Qt::Horizontal);
        slidePercents->setTickInterval(5);

        gridLayout2->addWidget(slidePercents, 0, 1, 1, 1);


        gridLayout->addLayout(gridLayout2, 3, 1, 2, 1);

        QWidget::setTabOrder(rbPercents, sbHours);
        QWidget::setTabOrder(sbHours, sbMinutes);
        QWidget::setTabOrder(sbMinutes, sbSeconds);
        QWidget::setTabOrder(sbSeconds, sbMilliseconds);
        QWidget::setTabOrder(sbMilliseconds, edSamples);
        QWidget::setTabOrder(edSamples, sbPercents);
        QWidget::setTabOrder(sbPercents, slidePercents);

        retranslateUi(SelectTimeWidgetBase);
        QObject::connect(rbPercents, &QRadioButton::toggled, slidePercents, &QSlider::setEnabled);
        QObject::connect(rbPercents, &QRadioButton::toggled, TextLabel1_2, &QLabel::setEnabled);
        QObject::connect(rbPercents, &QRadioButton::toggled, TextLabel3_2, &QLabel::setEnabled);
        QObject::connect(rbPercents, &QRadioButton::toggled, TextLabel2_2, &QLabel::setEnabled);
        QObject::connect(rbPercents, &QRadioButton::toggled, sbPercents, &QSpinBox::setEnabled);
        QObject::connect(rbSamples, &QRadioButton::toggled, edSamples, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbHours, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbMinutes, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbSeconds, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, lblHours, &QLabel::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, lblMinutes, &QLabel::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, lblSeconds, &QLabel::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, sbMilliseconds, &QSpinBox::setEnabled);
        QObject::connect(rbTime, &QRadioButton::toggled, lblMilliSeconds, &QLabel::setEnabled);
        QObject::connect(sbPercents, &QSpinBox::valueChanged, slidePercents, &QSlider::setValue);
        QObject::connect(slidePercents, &QSlider::valueChanged, sbPercents, &QSpinBox::setValue);

        QMetaObject::connectSlotsByName(SelectTimeWidgetBase);
    } // setupUi

    void retranslateUi(QGroupBox *SelectTimeWidgetBase)
    {
        SelectTimeWidgetBase->setWindowTitle(tr2i18n("frmLength", nullptr));
        SelectTimeWidgetBase->setTitle(tr2i18n("Length", nullptr));
#if QT_CONFIG(tooltip)
        rbSamples->setToolTip(tr2i18n("select by number of samples", nullptr));
#endif // QT_CONFIG(tooltip)
        rbSamples->setText(tr2i18n("&Samples", nullptr));
#if QT_CONFIG(tooltip)
        rbTime->setToolTip(tr2i18n("select by time", nullptr));
#endif // QT_CONFIG(tooltip)
        rbTime->setText(tr2i18n("&Time", nullptr));
#if QT_CONFIG(tooltip)
        rbPercents->setToolTip(tr2i18n("select by percentage of the signal's length", nullptr));
#endif // QT_CONFIG(tooltip)
        rbPercents->setText(tr2i18n("&Percent", nullptr));
        lblMinutes->setText(tr2i18n("Minutes", nullptr));
        lblMilliSeconds->setText(tr2i18n("Milliseconds", nullptr));
        lblSeconds->setText(tr2i18n("Seconds", nullptr));
        lblHours->setText(tr2i18n("Hours", nullptr));
        TextLabel1_2->setText(tr2i18n("0%", nullptr));
        TextLabel3_2->setText(tr2i18n("50%", nullptr));
        TextLabel2_2->setText(tr2i18n("100%", nullptr));
#if QT_CONFIG(tooltip)
        slidePercents->setToolTip(tr2i18n("sets the selection by the percentage of the whole signal", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class SelectTimeWidgetBase: public Ui_SelectTimeWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTTIMEWIDGETBASE_H

