/****************************************************************************
** Meta object code from reading C++ file 'TopWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/kwave/TopWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TopWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave9TopWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::TopWidget::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave9TopWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::TopWidget",
        "sigFileContextSwitched",
        "",
        "Kwave::FileContext*",
        "context",
        "updateRecentFiles",
        "executeCommand",
        "command",
        "forwardCommand",
        "closeEvent",
        "QCloseEvent*",
        "e",
        "dragEnterEvent",
        "QDragEnterEvent*",
        "event",
        "dropEvent",
        "QDropEvent*",
        "metaDataChanged",
        "Kwave::MetaDataList",
        "meta_data",
        "selectionChanged",
        "sample_index_t",
        "offset",
        "length",
        "setUndoRedoInfo",
        "undo",
        "redo",
        "clipboardChanged",
        "data_available",
        "updateMenu",
        "resetToolbarToDefaults",
        "updateToolbar",
        "toolbarRecord",
        "toolbarFileNew",
        "toolbarFileOpen",
        "toolbarFileSave",
        "toolbarFileSaveAs",
        "toolbarFileClose",
        "toolbarEditUndo",
        "toolbarEditRedo",
        "toolbarEditCut",
        "toolbarEditCopy",
        "toolbarEditPaste",
        "toolbarEditErase",
        "toolbarEditDelete",
        "modifiedChanged",
        "showInSplashSreen",
        "message",
        "showStatusBarMessage",
        "msg",
        "ms",
        "subWindowActivated",
        "QMdiSubWindow*",
        "sub",
        "subWindowDeleted",
        "obj"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigFileContextSwitched'
        QtMocHelpers::SignalData<void(Kwave::FileContext *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateRecentFiles'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'executeCommand'
        QtMocHelpers::SlotData<int(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'forwardCommand'
        QtMocHelpers::SlotData<int(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'closeEvent'
        QtMocHelpers::SlotData<void(QCloseEvent *)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'dragEnterEvent'
        QtMocHelpers::SlotData<void(QDragEnterEvent *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'dropEvent'
        QtMocHelpers::SlotData<void(QDropEvent *)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 16, 14 },
        }}),
        // Slot 'metaDataChanged'
        QtMocHelpers::SlotData<void(Kwave::MetaDataList)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(sample_index_t, sample_index_t)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { 0x80000000 | 21, 23 },
        }}),
        // Slot 'setUndoRedoInfo'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'clipboardChanged'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'updateMenu'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetToolbarToDefaults'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateToolbar'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarRecord'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarFileNew'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarFileOpen'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarFileSave'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarFileSaveAs'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarFileClose'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditUndo'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditRedo'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditCut'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditCopy'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditPaste'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditErase'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toolbarEditDelete'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'modifiedChanged'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showInSplashSreen'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'showStatusBarMessage'
        QtMocHelpers::SlotData<void(const QString &, unsigned int)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 49 }, { QMetaType::UInt, 50 },
        }}),
        // Slot 'subWindowActivated'
        QtMocHelpers::SlotData<void(QMdiSubWindow *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'subWindowDeleted'
        QtMocHelpers::SlotData<void(QObject *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 55 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TopWidget, qt_meta_tag_ZN5Kwave9TopWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::TopWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<KMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave9TopWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave9TopWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave9TopWidgetE_t>.metaTypes,
    nullptr
} };

void Kwave::TopWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TopWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigFileContextSwitched((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 1: _t->updateRecentFiles(); break;
        case 2: { int _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->forwardCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->closeEvent((*reinterpret_cast<std::add_pointer_t<QCloseEvent*>>(_a[1]))); break;
        case 5: _t->dragEnterEvent((*reinterpret_cast<std::add_pointer_t<QDragEnterEvent*>>(_a[1]))); break;
        case 6: _t->dropEvent((*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[1]))); break;
        case 7: _t->metaDataChanged((*reinterpret_cast<std::add_pointer_t<Kwave::MetaDataList>>(_a[1]))); break;
        case 8: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2]))); break;
        case 9: _t->setUndoRedoInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->clipboardChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->updateMenu(); break;
        case 12: _t->resetToolbarToDefaults(); break;
        case 13: _t->updateToolbar(); break;
        case 14: _t->toolbarRecord(); break;
        case 15: _t->toolbarFileNew(); break;
        case 16: _t->toolbarFileOpen(); break;
        case 17: _t->toolbarFileSave(); break;
        case 18: _t->toolbarFileSaveAs(); break;
        case 19: _t->toolbarFileClose(); break;
        case 20: _t->toolbarEditUndo(); break;
        case 21: _t->toolbarEditRedo(); break;
        case 22: _t->toolbarEditCut(); break;
        case 23: _t->toolbarEditCopy(); break;
        case 24: _t->toolbarEditPaste(); break;
        case 25: _t->toolbarEditErase(); break;
        case 26: _t->toolbarEditDelete(); break;
        case 27: _t->modifiedChanged(); break;
        case 28: _t->showInSplashSreen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->showStatusBarMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 30: _t->subWindowActivated((*reinterpret_cast<std::add_pointer_t<QMdiSubWindow*>>(_a[1]))); break;
        case 31: _t->subWindowDeleted((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::FileContext* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TopWidget::*)(Kwave::FileContext * )>(_a, &TopWidget::sigFileContextSwitched, 0))
            return;
    }
}

const QMetaObject *Kwave::TopWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::TopWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave9TopWidgetE_t>.strings))
        return static_cast<void*>(this);
    return KMainWindow::qt_metacast(_clname);
}

int Kwave::TopWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void Kwave::TopWidget::sigFileContextSwitched(Kwave::FileContext * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
