/****************************************************************************
** Meta object code from reading C++ file 'SignalWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/libgui/SignalWidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SignalWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave12SignalWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::SignalWidget::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave12SignalWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::SignalWidget",
        "sigRepaint",
        "",
        "selectedTimeInfo",
        "sample_index_t",
        "offset",
        "length",
        "rate",
        "sigCommand",
        "command",
        "sigCursorChanged",
        "pos",
        "requestRepaint",
        "Kwave::SignalView*",
        "view",
        "forwardCommand",
        "contextMenuEvent",
        "QContextMenuEvent*",
        "e",
        "repaintTimerElapsed",
        "slotTrackInserted",
        "index",
        "Kwave::Track*",
        "track",
        "slotTrackDeleted",
        "contextMenuEditUndo",
        "contextMenuEditRedo",
        "contextMenuEditCut",
        "contextMenuEditCopy",
        "contextMenuEditPaste",
        "contextMenuSaveSelection",
        "contextMenuSelectionExpandToLabels",
        "contextMenuSelectionNextLabels",
        "contextMenuSelectionPrevLabels",
        "updateMinimumHeight"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigRepaint'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedTimeInfo'
        QtMocHelpers::SignalData<void(sample_index_t, sample_index_t, double)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 }, { QMetaType::Double, 7 },
        }}),
        // Signal 'sigCommand'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'sigCursorChanged'
        QtMocHelpers::SignalData<void(sample_index_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 11 },
        }}),
        // Slot 'requestRepaint'
        QtMocHelpers::SlotData<void(Kwave::SignalView *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'forwardCommand'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'contextMenuEvent'
        QtMocHelpers::SlotData<void(QContextMenuEvent *)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'repaintTimerElapsed'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTrackInserted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'slotTrackDeleted'
        QtMocHelpers::SlotData<void(unsigned int, Kwave::Track *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'contextMenuEditUndo'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuEditRedo'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuEditCut'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuEditCopy'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuEditPaste'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuSaveSelection'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuSelectionExpandToLabels'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuSelectionNextLabels'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuSelectionPrevLabels'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMinimumHeight'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignalWidget, qt_meta_tag_ZN5Kwave12SignalWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::SignalWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12SignalWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12SignalWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave12SignalWidgetE_t>.metaTypes,
    nullptr
} };

void Kwave::SignalWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignalWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigRepaint(); break;
        case 1: _t->selectedTimeInfo((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 2: _t->sigCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->sigCursorChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 4: _t->requestRepaint((*reinterpret_cast<std::add_pointer_t<Kwave::SignalView*>>(_a[1]))); break;
        case 5: _t->forwardCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->contextMenuEvent((*reinterpret_cast<std::add_pointer_t<QContextMenuEvent*>>(_a[1]))); break;
        case 7: _t->repaintTimerElapsed(); break;
        case 8: _t->slotTrackInserted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 9: _t->slotTrackDeleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kwave::Track*>>(_a[2]))); break;
        case 10: _t->contextMenuEditUndo(); break;
        case 11: _t->contextMenuEditRedo(); break;
        case 12: _t->contextMenuEditCut(); break;
        case 13: _t->contextMenuEditCopy(); break;
        case 14: _t->contextMenuEditPaste(); break;
        case 15: _t->contextMenuSaveSelection(); break;
        case 16: _t->contextMenuSelectionExpandToLabels(); break;
        case 17: _t->contextMenuSelectionNextLabels(); break;
        case 18: _t->contextMenuSelectionPrevLabels(); break;
        case 19: _t->updateMinimumHeight(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::SignalView* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SignalWidget::*)()>(_a, &SignalWidget::sigRepaint, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalWidget::*)(sample_index_t , sample_index_t , double )>(_a, &SignalWidget::selectedTimeInfo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalWidget::*)(const QString & )>(_a, &SignalWidget::sigCommand, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalWidget::*)(sample_index_t )>(_a, &SignalWidget::sigCursorChanged, 3))
            return;
    }
}

const QMetaObject *Kwave::SignalWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::SignalWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave12SignalWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Kwave::ViewManager"))
        return static_cast< Kwave::ViewManager*>(this);
    return QWidget::qt_metacast(_clname);
}

int Kwave::SignalWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Kwave::SignalWidget::sigRepaint()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kwave::SignalWidget::selectedTimeInfo(sample_index_t _t1, sample_index_t _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Kwave::SignalWidget::sigCommand(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kwave::SignalWidget::sigCursorChanged(sample_index_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
