/********************************************************************************
** Form generated from reading UI file 'SelectDateDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTDATEDLG_H
#define UI_SELECTDATEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kdatepicker.h"

QT_BEGIN_NAMESPACE

class Ui_SelectDateDlg
{
public:
    QVBoxLayout *vboxLayout;
    KDatePicker *datePicker;
    QHBoxLayout *hboxLayout;
    QSpacerItem *Spacer1;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SelectDateDlg)
    {
        if (SelectDateDlg->objectName().isEmpty())
            SelectDateDlg->setObjectName("SelectDateDlg");
        SelectDateDlg->resize(400, 300);
        SelectDateDlg->setMinimumSize(QSize(400, 300));
        SelectDateDlg->setSizeGripEnabled(true);
        vboxLayout = new QVBoxLayout(SelectDateDlg);
        vboxLayout->setSpacing(10);
        vboxLayout->setContentsMargins(10, 10, 10, 10);
        vboxLayout->setObjectName("vboxLayout");
        datePicker = new KDatePicker(SelectDateDlg);
        datePicker->setObjectName("datePicker");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(datePicker->sizePolicy().hasHeightForWidth());
        datePicker->setSizePolicy(sizePolicy);
        datePicker->setMinimumSize(QSize(300, 200));

        vboxLayout->addWidget(datePicker);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        Spacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(Spacer1);

        buttonBox = new QDialogButtonBox(SelectDateDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(SelectDateDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SelectDateDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SelectDateDlg, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SelectDateDlg);
    } // setupUi

    void retranslateUi(QDialog *SelectDateDlg)
    {
        SelectDateDlg->setWindowTitle(tr2i18n("Select Date", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SelectDateDlg: public Ui_SelectDateDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTDATEDLG_H

