/********************************************************************************
** Form generated from reading UI file 'SaveBlocksDialogBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SAVEBLOCKSDIALOGBASE_H
#define UI_SAVEBLOCKSDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SaveBlocksDialogBase
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    KComboBox *cbPattern;
    QLabel *lblPattern;
    QLabel *lblNumbering;
    KComboBox *cbNumbering;
    QLabel *lblExtension;
    KComboBox *cbExtension;
    KUrlRequester *urlRequester;
    QLabel *lblLocation;
    QLabel *txtExample;
    QLabel *lblExample;
    QCheckBox *chkSelectionOnly;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SaveBlocksDialogBase)
    {
        if (SaveBlocksDialogBase->objectName().isEmpty())
            SaveBlocksDialogBase->setObjectName("SaveBlocksDialogBase");
        SaveBlocksDialogBase->resize(429, 252);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SaveBlocksDialogBase->sizePolicy().hasHeightForWidth());
        SaveBlocksDialogBase->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(SaveBlocksDialogBase);
        verticalLayout->setSpacing(10);
        verticalLayout->setContentsMargins(10, 10, 10, 10);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setSpacing(10);
        formLayout->setObjectName("formLayout");
        cbPattern = new KComboBox(SaveBlocksDialogBase);
        cbPattern->setObjectName("cbPattern");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbPattern->sizePolicy().hasHeightForWidth());
        cbPattern->setSizePolicy(sizePolicy1);
        cbPattern->setEditable(true);
        cbPattern->setDuplicatesEnabled(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, cbPattern);

        lblPattern = new QLabel(SaveBlocksDialogBase);
        lblPattern->setObjectName("lblPattern");
        lblPattern->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lblPattern);

        lblNumbering = new QLabel(SaveBlocksDialogBase);
        lblNumbering->setObjectName("lblNumbering");
        lblNumbering->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lblNumbering);

        cbNumbering = new KComboBox(SaveBlocksDialogBase);
        cbNumbering->addItem(QString());
        cbNumbering->addItem(QString());
        cbNumbering->setObjectName("cbNumbering");
        sizePolicy1.setHeightForWidth(cbNumbering->sizePolicy().hasHeightForWidth());
        cbNumbering->setSizePolicy(sizePolicy1);
        cbNumbering->setEditable(false);
        cbNumbering->setDuplicatesEnabled(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, cbNumbering);

        lblExtension = new QLabel(SaveBlocksDialogBase);
        lblExtension->setObjectName("lblExtension");
        lblExtension->setWordWrap(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lblExtension);

        cbExtension = new KComboBox(SaveBlocksDialogBase);
        cbExtension->setObjectName("cbExtension");
        sizePolicy1.setHeightForWidth(cbExtension->sizePolicy().hasHeightForWidth());
        cbExtension->setSizePolicy(sizePolicy1);
        cbExtension->setEditable(false);
        cbExtension->setDuplicatesEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, cbExtension);

        urlRequester = new KUrlRequester(SaveBlocksDialogBase);
        urlRequester->setObjectName("urlRequester");
        urlRequester->setMode(KFile::Mode::Directory|KFile::Mode::LocalOnly);
        urlRequester->setAcceptMode(QFileDialog::AcceptMode::AcceptSave);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, urlRequester);

        lblLocation = new QLabel(SaveBlocksDialogBase);
        lblLocation->setObjectName("lblLocation");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, lblLocation);

        txtExample = new QLabel(SaveBlocksDialogBase);
        txtExample->setObjectName("txtExample");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, txtExample);

        lblExample = new QLabel(SaveBlocksDialogBase);
        lblExample->setObjectName("lblExample");
        sizePolicy.setHeightForWidth(lblExample->sizePolicy().hasHeightForWidth());
        lblExample->setSizePolicy(sizePolicy);
        lblExample->setWordWrap(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, lblExample);

        chkSelectionOnly = new QCheckBox(SaveBlocksDialogBase);
        chkSelectionOnly->setObjectName("chkSelectionOnly");
        sizePolicy1.setHeightForWidth(chkSelectionOnly->sizePolicy().hasHeightForWidth());
        chkSelectionOnly->setSizePolicy(sizePolicy1);
        chkSelectionOnly->setChecked(true);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, chkSelectionOnly);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(SaveBlocksDialogBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SaveBlocksDialogBase);

        QMetaObject::connectSlotsByName(SaveBlocksDialogBase);
    } // setupUi

    void retranslateUi(QDialog *SaveBlocksDialogBase)
    {
#if QT_CONFIG(whatsthis)
        cbPattern->setWhatsThis(tr2i18n("<p>Select the pattern that is used to create the filename of each saved block. It currently understands the following placeholders:</p>\n"
"<ul>\n"
"<li><tt><b>[%filename]</b></tt>name of the file, without the path</li>\n"
"<li><tt><b>[</b>%<i>0</i></tt><i>N</i><tt><b>nr]</b></tt>the index of the file, optionally with leading zeroes (if <tt>'0</tt>' prepended) and optionally a fixed number of digits (<tt>N</tt>)</li>\n"
"<li><tt><b>[%</b><i>0</i><i>N</i><b>count]</b></tt>the number of files that will be saved</li>\n"
"<li><tt><b>[%</b><i>0</i><i>N</i><b>total]</b></tt>the highest index within the files that will be saved</li>\n"
"</ul>", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblPattern->setText(tr2i18n("Filename pattern:", nullptr));
        lblNumbering->setText(tr2i18n("Numbering:", nullptr));
        cbNumbering->setItemText(0, tr2i18n("Continue after highest index", nullptr));
        cbNumbering->setItemText(1, tr2i18n("Always start with 1, overwrite if necessary", nullptr));

#if QT_CONFIG(whatsthis)
        cbNumbering->setWhatsThis(tr2i18n("Determines how the <b>numbering of the files</b> should happen:<ul>\n"
"<li>Continue after the <b>highest index</b> that can be found, avoiding collisions with existing files</li>\n"
"<li>Always start numbering from <b>one</b>, possibly colliding with already existing files</li>\n"
"</ul>", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblExtension->setText(tr2i18n("Extension:", nullptr));
#if QT_CONFIG(whatsthis)
        cbExtension->setWhatsThis(tr2i18n("Choose what encoding to save the blocks with.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        urlRequester->setWhatsThis(tr2i18n("Location to save the files", nullptr));
#endif // QT_CONFIG(whatsthis)
        urlRequester->setPlaceholderText(tr2i18n("Choose where to save the files", nullptr));
        lblLocation->setText(tr2i18n("Export Location:", nullptr));
#if QT_CONFIG(whatsthis)
        txtExample->setWhatsThis(tr2i18n("Example of the first file name that will be saved, using the file name pattern, extension, and numbering", nullptr));
#endif // QT_CONFIG(whatsthis)
        txtExample->setText(tr2i18n("TextLabel", nullptr));
        lblExample->setText(tr2i18n("Example file name:", nullptr));
#if QT_CONFIG(whatsthis)
        chkSelectionOnly->setWhatsThis(tr2i18n("If checked, <b>save only the blocks that overlap with the current selection</b>, otherwise the whole file. <br><i>Please note that this option is disabled if nothing is selected or the selection already covers the whole file.</i>", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkSelectionOnly->setText(tr2i18n("Save selection only", nullptr));
        (void)SaveBlocksDialogBase;
    } // retranslateUi

};

namespace Ui {
    class SaveBlocksDialogBase: public Ui_SaveBlocksDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SAVEBLOCKSDIALOGBASE_H

