/********************************************************************************
** Form generated from reading UI file 'StringEnterDlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STRINGENTERDLG_H
#define UI_STRINGENTERDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StringEnterDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *grpCommand;
    QHBoxLayout *horizontalLayout;
    QLabel *lblCommand;
    QSpacerItem *spacerItem;
    QLineEdit *edCommand;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *StringEnterDlg)
    {
        if (StringEnterDlg->objectName().isEmpty())
            StringEnterDlg->setObjectName("StringEnterDlg");
        StringEnterDlg->resize(514, 111);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(StringEnterDlg->sizePolicy().hasHeightForWidth());
        StringEnterDlg->setSizePolicy(sizePolicy);
        StringEnterDlg->setModal(true);
        verticalLayout = new QVBoxLayout(StringEnterDlg);
        verticalLayout->setSpacing(10);
        verticalLayout->setContentsMargins(10, 10, 10, 10);
        verticalLayout->setObjectName("verticalLayout");
        grpCommand = new QGroupBox(StringEnterDlg);
        grpCommand->setObjectName("grpCommand");
        horizontalLayout = new QHBoxLayout(grpCommand);
        horizontalLayout->setSpacing(10);
        horizontalLayout->setContentsMargins(10, 10, 10, 10);
        horizontalLayout->setObjectName("horizontalLayout");
        lblCommand = new QLabel(grpCommand);
        lblCommand->setObjectName("lblCommand");
        lblCommand->setWordWrap(false);

        horizontalLayout->addWidget(lblCommand);

        spacerItem = new QSpacerItem(10, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem);

        edCommand = new QLineEdit(grpCommand);
        edCommand->setObjectName("edCommand");
        edCommand->setMinimumSize(QSize(300, 0));

        horizontalLayout->addWidget(edCommand);


        verticalLayout->addWidget(grpCommand);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(10);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        buttonBox = new QDialogButtonBox(StringEnterDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        verticalLayout->addLayout(hboxLayout);

        QWidget::setTabOrder(edCommand, buttonBox);

        retranslateUi(StringEnterDlg);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, StringEnterDlg, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, StringEnterDlg, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, SIGNAL(helpRequested()), StringEnterDlg, SLOT(invokeHelp()));

        QMetaObject::connectSlotsByName(StringEnterDlg);
    } // setupUi

    void retranslateUi(QDialog *StringEnterDlg)
    {
        StringEnterDlg->setWindowTitle(tr2i18n("Enter Command...", nullptr));
        lblCommand->setText(tr2i18n("Enter Command:", nullptr));
#if QT_CONFIG(tooltip)
        edCommand->setToolTip(tr2i18n("please enter a text command here...", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class StringEnterDlg: public Ui_StringEnterDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STRINGENTERDLG_H

