/****************************************************************************
** Meta object code from reading C++ file 'FileContext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwave-26.04.3/kwave/FileContext.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FileContext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Kwave11FileContextE_t {};
} // unnamed namespace

template <> constexpr inline auto Kwave::FileContext::qt_create_metaobjectdata<qt_meta_tag_ZN5Kwave11FileContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kwave::FileContext",
        "sigStatusBarMessage",
        "",
        "message",
        "ms",
        "sigZoomChanged",
        "Kwave::FileContext*",
        "context",
        "zoom",
        "sigMetaDataChanged",
        "Kwave::MetaDataList",
        "meta_data",
        "sigSelectionChanged",
        "sample_index_t",
        "offset",
        "length",
        "sigUndoRedoInfo",
        "undo",
        "redo",
        "sigVisibleRangeChanged",
        "visible",
        "total",
        "sigModified",
        "destroyed",
        "executeCommand",
        "command",
        "contextSwitched",
        "forwardZoomChanged",
        "updatePlaybackPos",
        "metaDataChanged",
        "selectionChanged",
        "setUndoRedoInfo",
        "visibleRangeChanged",
        "modifiedChanged",
        "processDelayedCommand"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigStatusBarMessage'
        QtMocHelpers::SignalData<void(const QString &, unsigned int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'sigZoomChanged'
        QtMocHelpers::SignalData<void(Kwave::FileContext *, double)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Double, 8 },
        }}),
        // Signal 'sigMetaDataChanged'
        QtMocHelpers::SignalData<void(Kwave::MetaDataList)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'sigSelectionChanged'
        QtMocHelpers::SignalData<void(sample_index_t, sample_index_t)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
        }}),
        // Signal 'sigUndoRedoInfo'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'sigVisibleRangeChanged'
        QtMocHelpers::SignalData<void(sample_index_t, sample_index_t, sample_index_t)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 20 }, { 0x80000000 | 13, 21 },
        }}),
        // Signal 'sigModified'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'destroyed'
        QtMocHelpers::SignalData<void(Kwave::FileContext *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'executeCommand'
        QtMocHelpers::SlotData<int(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'contextSwitched'
        QtMocHelpers::SlotData<void(Kwave::FileContext *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'forwardZoomChanged'
        QtMocHelpers::SlotData<void(double)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 8 },
        }}),
        // Slot 'updatePlaybackPos'
        QtMocHelpers::SlotData<void(sample_index_t)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'metaDataChanged'
        QtMocHelpers::SlotData<void(Kwave::MetaDataList)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(sample_index_t, sample_index_t)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
        }}),
        // Slot 'setUndoRedoInfo'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'visibleRangeChanged'
        QtMocHelpers::SlotData<void(sample_index_t, sample_index_t, sample_index_t)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 20 }, { 0x80000000 | 13, 21 },
        }}),
        // Slot 'modifiedChanged'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processDelayedCommand'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileContext, qt_meta_tag_ZN5Kwave11FileContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kwave::FileContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave11FileContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave11FileContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Kwave11FileContextE_t>.metaTypes,
    nullptr
} };

void Kwave::FileContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigStatusBarMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 1: _t->sigZoomChanged((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 2: _t->sigMetaDataChanged((*reinterpret_cast<std::add_pointer_t<Kwave::MetaDataList>>(_a[1]))); break;
        case 3: _t->sigSelectionChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2]))); break;
        case 4: _t->sigUndoRedoInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->sigVisibleRangeChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 6: _t->sigModified(); break;
        case 7: _t->destroyed((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 8: { int _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->contextSwitched((*reinterpret_cast<std::add_pointer_t<Kwave::FileContext*>>(_a[1]))); break;
        case 10: _t->forwardZoomChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->updatePlaybackPos((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1]))); break;
        case 12: _t->metaDataChanged((*reinterpret_cast<std::add_pointer_t<Kwave::MetaDataList>>(_a[1]))); break;
        case 13: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2]))); break;
        case 14: _t->setUndoRedoInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->visibleRangeChanged((*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<sample_index_t>>(_a[3]))); break;
        case 16: _t->modifiedChanged(); break;
        case 17: _t->processDelayedCommand(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::FileContext* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::FileContext* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kwave::FileContext* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(const QString & , unsigned int )>(_a, &FileContext::sigStatusBarMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(Kwave::FileContext * , double )>(_a, &FileContext::sigZoomChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(Kwave::MetaDataList )>(_a, &FileContext::sigMetaDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(sample_index_t , sample_index_t )>(_a, &FileContext::sigSelectionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(const QString & , const QString & )>(_a, &FileContext::sigUndoRedoInfo, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(sample_index_t , sample_index_t , sample_index_t )>(_a, &FileContext::sigVisibleRangeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)()>(_a, &FileContext::sigModified, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileContext::*)(Kwave::FileContext * )>(_a, &FileContext::destroyed, 7))
            return;
    }
}

const QMetaObject *Kwave::FileContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kwave::FileContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Kwave11FileContextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kwave::FileContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Kwave::FileContext::sigStatusBarMessage(const QString & _t1, unsigned int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Kwave::FileContext::sigZoomChanged(Kwave::FileContext * _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Kwave::FileContext::sigMetaDataChanged(Kwave::MetaDataList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kwave::FileContext::sigSelectionChanged(sample_index_t _t1, sample_index_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Kwave::FileContext::sigUndoRedoInfo(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Kwave::FileContext::sigVisibleRangeChanged(sample_index_t _t1, sample_index_t _t2, sample_index_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Kwave::FileContext::sigModified()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Kwave::FileContext::destroyed(Kwave::FileContext * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
